@@ -164,7 +164,7 @@ event_roll_get_layout (GxkScrollCanvas       *scc,
 }
 
 static void
-event_roll_reallocate_children (GxkScrollCanvas *scc,
+event_roll_reallocate_contents (GxkScrollCanvas *scc,
                                 gint             xdiff,
                                 gint             ydiff)
 {
@@ -465,8 +465,8 @@ event_roll_update_adjustments (GxkScrollCanvas *scc,
       scc->hadjustment->lower = 0;
       // FIXME: self->hadjustment->upper = self->max_ticks;
       // self->hadjustment->page_size = pixels_to_ticks (self, CANVAS_WIDTH (self));
-      scc->hadjustment->step_increment = self->ppqn;
-      scc->hadjustment->page_increment = self->ppqn * self->qnpt;
+      // scc->hadjustment->step_increment = self->ppqn;
+      // scc->hadjustment->page_increment = self->ppqn * self->qnpt;
     }
   GXK_SCROLL_CANVAS_CLASS (bst_event_roll_parent_class)->update_adjustments (scc, hadj, vadj);
 }
@@ -584,15 +584,17 @@ event_roll_update (BstEventRoll *self,
   guint tick_end = tick_start + MAX (duration, 1) - 1;
   gint x1 = tick_to_coord (self, tick_start);
   gint x2 = tick_to_coord (self, tick_end);
-  gint width, height;
-  GdkRectangle area;
-  gdk_window_get_size (CANVAS (self), &width, &height);
-
-  area.x = x1 - 3;		/* add fudge */
-  area.y = 0;
-  area.width = x2 - x1 + 3 + 3;	/* add fudge */
-  area.height = height;
-  gdk_window_invalidate_rect (CANVAS (self), &area, TRUE);
+  if (GTK_WIDGET_DRAWABLE (self))
+    {
+      gint width, height;
+      GdkRectangle area;
+      gdk_window_get_size (CANVAS (self), &width, &height);
+      area.x = x1 - 3;		/* add fudge */
+      area.y = 0;
+      area.width = x2 - x1 + 3 + 3;	/* add fudge */
+      area.height = height;
+      gdk_window_invalidate_rect (CANVAS (self), &area, TRUE);
+    }
 }
 
 static void
@@ -629,7 +631,8 @@ bst_event_roll_set_proxy (BstEventRoll *self,
 			 // "swapped_signal::property-notify::uname", event_roll_update_name, self,
 			 "swapped_signal::range-changed", event_roll_update, self,
 			 NULL);
-      self->max_ticks = bse_part_get_max_tick (self->proxy);
+      bse_proxy_get (self->proxy, "last-tick", &self->max_ticks, NULL);
+      self->max_ticks = MAX (self->max_ticks, 1);
       bst_event_roll_hsetup (self, self->ppqn, self->qnpt, self->max_ticks, self->hzoom);
     }
   gtk_widget_queue_resize (GTK_WIDGET (self));
@@ -811,7 +814,7 @@ bst_event_roll_class_init (BstEventRollClass *class)
   scroll_canvas_class->hscrollable = TRUE;
   scroll_canvas_class->get_layout = event_roll_get_layout;
   scroll_canvas_class->update_adjustments = event_roll_update_adjustments;
-  scroll_canvas_class->reallocate_children = event_roll_reallocate_children;
+  scroll_canvas_class->reallocate_contents = event_roll_reallocate_contents;
   scroll_canvas_class->draw_left_panel = event_roll_draw_vpanel;
   scroll_canvas_class->draw_canvas = event_roll_draw_canvas;
   scroll_canvas_class->handle_drag = event_roll_handle_drag;
