@@ -21,6 +21,7 @@
 #include "bstsplash.h"
 #include "bstxkb.h"
 #include "bstgconfig.h"
+#include "bstkeybindings.h"
 #include "bstskinconfig.h"
 #include "bstusermessage.h"
 #include "bstparam.h"
@@ -29,6 +30,8 @@
 #include "data/beast-images.h"
 #include <unistd.h>
 #include <string.h>
+#include <sys/time.h>
+#include <sys/resource.h>
 #include "sfi/toyprof-mem.h"
 
 
@@ -82,7 +85,6 @@ main (int   argc,
   SfiRec *bseconfig;
   gchar *string;
   GSource *source;
-  gboolean parse_rc_file = TRUE;
   gboolean save_rc_file = TRUE;
   guint i;
 
@@ -110,22 +112,19 @@ main (int   argc,
   bseconfig = sfi_rec_new ();
   bst_early_parse_args (&argc, &argv, bseconfig);
 
-  /* initialize Gtk+ and go into threading mode
-   */
+  /* initialize Gtk+ and go into threading mode */
   gtk_init (&argc, &argv);
   g_set_prgname ("BEAST");	/* overriding Gdk's program name */
   GDK_THREADS_ENTER ();
 
-  /* initialize Gtk+ Extension Kit
-   */
+  /* initialize Gtk+ Extension Kit */
   gxk_init ();
   /* documentation search paths */
   gxk_text_add_tsm_path (BST_PATH_DOCS);
   gxk_text_add_tsm_path (BST_PATH_IMAGES);
   gxk_text_add_tsm_path (".");
 
-  /* now, we can popup the splash screen
-   */
+  /* now, we can popup the splash screen */
   beast_splash = bst_splash_new ("BEAST-Splash", BST_SPLASH_WIDTH, BST_SPLASH_HEIGHT, 15);
   bst_splash_set_title (beast_splash, _("BEAST Startup"));
   gtk_object_set_user_data (GTK_OBJECT (beast_splash), NULL);	/* fix for broken user_data in 2.2 */
@@ -137,29 +136,18 @@ main (int   argc,
   bst_splash_update_entity (beast_splash, _("Startup"));
   bst_splash_show_grab (beast_splash);
 
-  /* BEAST initialization
-   */
-  bst_splash_update_item (beast_splash, _("Objects"));
+  /* BEAST initialization */
+  bst_splash_update_item (beast_splash, _("Initializers"));
   _bst_init_utils ();
   _bst_init_params ();
   _bst_gconfig_init ();
   _bst_skin_config_init ();
-  bst_splash_update_item (beast_splash, _("Language"));
 
-  /* parse rc file
-   */
-  if (parse_rc_file)
-    {
-      gchar *file_name = BST_STRDUP_RC_FILE ();
-      bst_splash_update_item (beast_splash, _("RC File"));
-      bst_rc_parse (file_name);
-      g_free (file_name);
-      bst_splash_update_item (beast_splash, _("Skin RC"));
-      bst_skin_parse (bst_skin_config_rcfile ());
-    }
+  /* parse rc file */
+  bst_splash_update_item (beast_splash, _("RC Files"));
+  bst_preferences_load_rc_files();
 
-  /* show splash images
-   */
+  /* show splash images */
   bst_splash_update_item (beast_splash, _("Splash Image"));
   string = g_strconcat (BST_PATH_IMAGES, G_DIR_SEPARATOR_S, BST_SPLASH_IMAGE, NULL);
   anim = gdk_pixbuf_animation_new_from_file (string, NULL);
@@ -183,6 +171,9 @@ main (int   argc,
   g_source_attach (source, NULL);
   g_source_unref (source);
 
+  /* now that the BSE thread runs, drop scheduling priorities if we have any */
+  setpriority (PRIO_PROCESS, getpid(), 0);
+
   /* watch registration notifications on server */
   bse_proxy_connect (BSE_SERVER,
 		     "signal::registration", server_registration, beast_splash,
@@ -534,6 +525,8 @@ bst_early_parse_args (int    *argc_p,
 	    g_print ("%s\n", BST_PATH_LOCALE);
 	  else if (strcmp (arg, "skins") == 0)
 	    g_print ("%s\n", freeme = BST_STRDUP_SKIN_PATH ());
+	  else if (strcmp (arg, "keys") == 0)
+	    g_print ("%s\n", BST_PATH_KEYS);
 	  else if (strcmp (arg, "ladspa") == 0)
 	    g_print ("%s\n", BSE_PATH_LADSPA);
 	  else if (strcmp (arg, "plugins") == 0)
@@ -552,7 +545,7 @@ bst_early_parse_args (int    *argc_p,
 	    {
 	      if (arg[0])
                 g_message ("no such resource path: %s", arg);
-	      g_message ("supported resource paths: docs, images, locale, skins, ladspa, plugins, scripts, effects, instruments, demo, samples");
+	      g_message ("supported resource paths: docs, images, locale, keys, skins, ladspa, plugins, scripts, effects, instruments, demo, samples");
 	    }
           g_free (freeme);
 	  exit (0);
@@ -607,6 +600,7 @@ bst_exit_print_version (void)
   g_print ("Doc Path:        %s\n", BST_PATH_DOCS);
   g_print ("Image Path:      %s\n", BST_PATH_IMAGES);
   g_print ("Locale Path:     %s\n", BST_PATH_LOCALE);
+  g_print ("Keyrc Path:      %s\n", BST_PATH_KEYS);
   g_print ("Skin Path:       %s\n", freeme = BST_STRDUP_SKIN_PATH());
   g_print ("Sample Path:     %s\n", bse_server_get_sample_path (BSE_SERVER));
   g_print ("Script Path:     %s\n", bse_server_get_script_path (BSE_SERVER));
@@ -685,6 +679,7 @@ beast_show_about_box (void)
     "Ben Collver",
     "Tim Janik",
     "Stefan Westerfeld",
+    "Rasmus Kaj",
     /* plugins */
     "David A. Bartold",
     //"Tim Janik",
