@@ -18,10 +18,7 @@
 
 
 /* --- choice parameters --- */
-enum {
-  CHOICE_PARAM_MENU_BUTTON,
-  CHOICE_PARAM_OPTION_MENU
-};
+#define CHOICE_PARAM_OPTION_MENU        GXK_MENU_BUTTON_POPUP_MODE
 
 static void
 param_choice_change_value (GtkWidget *widget,
@@ -37,7 +34,7 @@ param_choice_change_value (GtkWidget *widget,
       if (item)
 	{
           SfiChoiceValue *cv = g_object_get_qdata (G_OBJECT (item), quark_param_choice_values);
-	  sfi_value_set_choice (&param->value, cv->choice_name);
+	  sfi_value_set_choice (&param->value, cv->choice_ident);
 	}
       gxk_param_apply_value (param);
     }
@@ -70,20 +67,21 @@ param_choice_create (GxkParam    *param,
   gchar *str;
   guint i;
 
-  if (variant == CHOICE_PARAM_MENU_BUTTON)
-    widget = g_object_new (GXK_TYPE_MENU_BUTTON,
-                           "visible", TRUE,
-                           "push_in", TRUE,
-                           NULL);
-  else
+  if (variant == CHOICE_PARAM_OPTION_MENU)
     widget = g_object_new (GTK_TYPE_OPTION_MENU,
                            "visible", TRUE,
                            NULL);
+  else
+    widget = g_object_new (GXK_TYPE_MENU_BUTTON,
+                           "visible", TRUE,
+                           "mode", variant,
+                           NULL);
 
   menu = g_object_new (GTK_TYPE_MENU, NULL);
   for (i = 0; i < cvalues.n_values; i++)
     {
-      GtkWidget *item = gtk_menu_item_new_with_label (cvalues.values[i].choice_blurb);
+      GtkWidget *item = gtk_menu_item_new_with_label (cvalues.values[i].choice_label);
+      gxk_widget_set_latent_tooltip (item, cvalues.values[i].choice_blurb);
       gtk_widget_show (item);
       g_object_connect (item, "signal::activate", param_choice_item_activated, widget, NULL);
       g_object_set_qdata (G_OBJECT (item), quark_param_choice_values, (gpointer) &cvalues.values[i]);
@@ -131,7 +129,7 @@ param_choice_update (GxkParam  *param,
 	{
 	  GtkWidget *item = list->data;
 	  SfiChoiceValue *cv = g_object_get_qdata (G_OBJECT (item), quark_param_choice_values);
-	  if (sfi_choice_match (cv->choice_name, string))
+	  if (sfi_choice_match (cv->choice_ident, string))
             {
               param_choice_item_activated (item, widget);
               break;
@@ -141,16 +139,28 @@ param_choice_update (GxkParam  *param,
 }
 
 static GxkParamEditor param_choice1 = {
-  { "choice-menu",      N_("Drop Down Box (Option Menu)"), },
+  { "option-button",    N_("Popup Options"), },
   { G_TYPE_STRING,      "SfiChoice", },
-  { NULL,       +6,     TRUE, },        /* options, rating, editing */
-  param_choice_create,  param_choice_update,    CHOICE_PARAM_OPTION_MENU
+  { NULL,       +8,     TRUE, },        /* options, rating, editing */
+  param_choice_create,  param_choice_update,    GXK_MENU_BUTTON_OPTION_MODE
 };
 static GxkParamEditor param_choice2 = {
-  { "choice-button",    N_("Drop Down Button"), },
+  { "combo-button",     N_("Drop Down Combo"), },
+  { G_TYPE_STRING,      "SfiChoice", },
+  { NULL,       +7,     TRUE, },        /* options, rating, editing */
+  param_choice_create,  param_choice_update,    GXK_MENU_BUTTON_COMBO_MODE
+};
+static GxkParamEditor param_choice3 = {
+  { "tool-button",      N_("Drop Down Button"), },
+  { G_TYPE_STRING,      "SfiChoice", },
+  { NULL,       +6,     TRUE, },        /* options, rating, editing */
+  param_choice_create,  param_choice_update,    GXK_MENU_BUTTON_TOOL_MODE
+};
+static GxkParamEditor param_choice4 = {
+  { "option-menu",      N_("Standard Option Menu"), },
   { G_TYPE_STRING,      "SfiChoice", },
   { NULL,       +5,     TRUE, },        /* options, rating, editing */
-  param_choice_create,  param_choice_update,    CHOICE_PARAM_MENU_BUTTON
+  param_choice_create,  param_choice_update,    CHOICE_PARAM_OPTION_MENU
 };
 static const gchar *param_choice_aliases1[] = {
   "choice",
