@@ -41,6 +41,9 @@ static void     part_dialog_action_exec         (gpointer                data,
                                                  gulong                  action);
 static gboolean part_dialog_action_check        (gpointer                data,
                                                  gulong                  action);
+static void     part_dialog_run_script_proc     (gpointer                data,
+                                                 gulong                  category_id);
+static GtkAdjustment* resizer_adjustment_create (GtkAdjustment          *client);
 
 
 /* --- track actions --- */
@@ -113,9 +116,13 @@ eparam_changed (gpointer  data,
 static void
 bst_part_dialog_init (BstPartDialog *self)
 {
-  GtkWidget *hscroll, *vscroll, *eb, *child;
+  GtkWidget *eb, *child, *box;
+  GtkRange *srange;
+  BseCategorySeq *cseq;
+  GxkActionList *al1;
   GtkPaned *paned;
   GtkObject *adjustment;
+  GtkAdjustment *adj;
   GParamSpec *pspec;
   GxkGadget *gadget;
 
@@ -130,8 +137,6 @@ bst_part_dialog_init (BstPartDialog *self)
   /* gadget-complete GUI */
   gadget = gxk_gadget_create ("beast", "piano-roll-box", NULL);
   gtk_container_add (GTK_CONTAINER (GXK_DIALOG (self)->vbox), gadget);
-  hscroll = gxk_gadget_find (gadget, "piano-roll-hscrollbar");
-  vscroll = gxk_gadget_find (gadget, "piano-roll-vscrollbar");
 
   /* publish actions */
   gxk_widget_publish_actions (self, "piano-edit-actions",
@@ -144,6 +149,12 @@ bst_part_dialog_init (BstPartDialog *self)
     gxk_widget_publish_actions (self, "piano-clear-undo", G_N_ELEMENTS (piano_clear_undo), piano_clear_undo,
                                 NULL, part_dialog_action_check, part_dialog_action_exec);
 
+  /* publish /Part/ scripts */
+  cseq = bse_categories_match ("/Part/*");
+  al1 = bst_action_list_from_cats (cseq, 1, BST_STOCK_EXECUTE, NULL, part_dialog_run_script_proc, self);
+  gxk_action_list_sort (al1);
+  gxk_widget_publish_action_list (self, "part-scripts", al1);
+
   /* FIXME: use paned child-properties after gtk+-2.4 */
   paned = gxk_gadget_find (gadget, "piano-paned");
   child = g_object_ref (paned->child1);
@@ -154,26 +165,65 @@ bst_part_dialog_init (BstPartDialog *self)
   gtk_container_remove (GTK_CONTAINER (paned), child);
   gtk_paned_pack2 (paned, child, FALSE, TRUE);
   g_object_unref (child);
-  
+
   /* piano roll */
   self->proll = gxk_gadget_find (gadget, "piano-roll");
   gxk_nullify_in_object (self, &self->proll);
   g_signal_connect (self->proll, "canvas-clicked", G_CALLBACK (piano_canvas_clicked), self);
-  gxk_scroll_canvas_set_hadjustment (GXK_SCROLL_CANVAS (self->proll), gtk_range_get_adjustment (GTK_RANGE (hscroll)));
-  gxk_scroll_canvas_set_vadjustment (GXK_SCROLL_CANVAS (self->proll), gtk_range_get_adjustment (GTK_RANGE (vscroll)));
-  self->pctrl = bst_piano_roll_controller_new (self->proll);
-  gxk_widget_publish_action_list (self, "pctrl-canvas-tools", bst_piano_roll_controller_canvas_actions (self->pctrl));
-  gxk_widget_publish_action_list (self, "pctrl-note-tools", bst_piano_roll_controller_note_actions (self->pctrl));
-  gxk_widget_publish_action_list (self, "pctrl-quant-tools", bst_piano_roll_controller_quant_actions (self->pctrl));
+  srange = gxk_gadget_find (gadget, "piano-roll-vscrollbar");
+  gxk_scroll_canvas_set_vadjustment (GXK_SCROLL_CANVAS (self->proll), gtk_range_get_adjustment (srange));
+  srange = gxk_gadget_find (gadget, "piano-roll-hscrollbar");
+  adj = gtk_range_get_adjustment (srange);
+  gxk_scroll_canvas_set_hadjustment (GXK_SCROLL_CANVAS (self->proll), adj);
+  adj = resizer_adjustment_create (adj);
+  srange = gxk_gadget_find (gadget, "piano-roll-hscale");
+  gtk_range_set_adjustment (srange, adj);
+  // g_object_unref (adj);
+  self->pictrl = bst_piano_roll_controller_new (self->proll);
+  gxk_widget_publish_action_list (self, "pctrl-canvas-tools", bst_piano_roll_controller_canvas_actions (self->pictrl));
+  gxk_widget_publish_action_list (self, "pctrl-note-tools", bst_piano_roll_controller_note_actions (self->pictrl));
+  gxk_widget_publish_action_list (self, "pctrl-quant-tools", bst_piano_roll_controller_quant_actions (self->pictrl));
 
   /* event roll */
   self->eroll = gxk_gadget_find (gadget, "event-roll");
   gxk_nullify_in_object (self, &self->eroll);
   g_signal_connect (self->eroll, "canvas-clicked", G_CALLBACK (event_canvas_clicked), self);
-  self->ectrl = bst_event_roll_controller_new (self->eroll, self->pctrl->quant_rtools, self->pctrl->canvas_rtools);
-  gxk_scroll_canvas_set_hadjustment (GXK_SCROLL_CANVAS (self->eroll), gtk_range_get_adjustment (GTK_RANGE (hscroll)));
+  self->ectrl = bst_event_roll_controller_new (self->eroll, self->pictrl->quant_rtools, self->pictrl->canvas_rtools);
+  srange = gxk_gadget_find (gadget, "piano-roll-hscrollbar");
+  gxk_scroll_canvas_set_hadjustment (GXK_SCROLL_CANVAS (self->eroll), gtk_range_get_adjustment (srange));
   bst_event_roll_set_vpanel_width_hook (self->eroll, (gpointer) bst_piano_roll_get_vpanel_width, self->proll);
 
+  /* pattern view */
+  self->pview = gxk_gadget_find (gadget, "pattern-view");
+  gxk_nullify_in_object (self, &self->pview);
+  srange = gxk_gadget_find (gadget, "pattern-view-hscrollbar");
+  gxk_scroll_canvas_set_hadjustment (GXK_SCROLL_CANVAS (self->pview), gtk_range_get_adjustment (srange));
+  srange = gxk_gadget_find (gadget, "pattern-view-vscrollbar");
+  adj = gtk_range_get_adjustment (srange);
+  gxk_scroll_canvas_set_vadjustment (GXK_SCROLL_CANVAS (self->pview), adj);
+  adj = resizer_adjustment_create (adj);
+  srange = gxk_gadget_find (gadget, "pattern-view-vscale");
+  gtk_range_set_adjustment (srange, adj);
+  self->pvctrl = bst_pattern_controller_new (self->pview, self->pictrl->quant_rtools);
+
+  /* pattern view controls */
+  g_signal_connect_swapped (gxk_gadget_find (gadget, "configure-button"), "clicked",
+                            G_CALLBACK (bst_pattern_column_layouter_popup), self->pview);
+  box = gxk_gadget_find (gadget, "pattern-control-box");
+  gxk_gadget_add (gadget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->vraster, "name"));
+  gxk_gadget_add (gadget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->vraster, "combo-button"));
+  gxk_gadget_add (gadget, "pattern-control-box", gxk_vseparator_space_new (TRUE));
+  gxk_gadget_add (gadget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->steps, "name"));
+  gxk_gadget_add (gadget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->steps, NULL));
+  gxk_gadget_add (gadget, "pattern-control-box", gxk_vseparator_space_new (FALSE));
+  gxk_gadget_add (gadget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->step_dir, "name"));
+  gxk_gadget_add (gadget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->step_dir, "combo-button"));
+  gxk_gadget_add (gadget, "pattern-control-box", gxk_vseparator_space_new (FALSE));
+  gxk_gadget_add (gadget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->hwrap, NULL));
+  gxk_gadget_add (gadget, "pattern-control-box", gxk_vseparator_space_new (TRUE));
+  gxk_gadget_add (gadget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->base_octave, "name"));
+  gxk_gadget_add (gadget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->base_octave, NULL));
+
   /* event roll children */
   g_object_new (GTK_TYPE_LABEL, "visible", TRUE, "label", "C", "parent", self->eroll, NULL);
 
@@ -196,6 +246,8 @@ bst_part_dialog_init (BstPartDialog *self)
   g_object_connect (adjustment,
 		    "swapped_signal_after::value_changed", hzoom_changed, self,
 		    NULL);
+  srange = gxk_gadget_find (gadget, "piano-roll-hzoom-scale");
+  gtk_range_set_adjustment (srange, GTK_ADJUSTMENT (adjustment));
   gxk_gadget_add (self, "hzoom-area",
                   g_object_new (GTK_TYPE_SPIN_BUTTON,
                                 "visible", TRUE,
@@ -224,7 +276,7 @@ bst_part_dialog_finalize (GObject *object)
 
   bst_part_dialog_set_proxy (self, 0);
 
-  bst_piano_roll_controller_unref (self->pctrl);
+  bst_piano_roll_controller_unref (self->pictrl);
   bst_event_roll_controller_unref (self->ectrl);
   
   G_OBJECT_CLASS (bst_part_dialog_parent_class)->finalize (object);
@@ -253,6 +305,8 @@ bst_part_dialog_set_proxy (BstPartDialog *self,
   if (project)
     {
       bst_window_sync_title_to_proxy (GXK_DIALOG (self), part, "%s");
+      if (self->pview)
+        bst_pattern_view_set_proxy (self->pview, part);
       if (self->proll)
         bst_piano_roll_set_proxy (self->proll, part);
       if (self->eroll)
@@ -294,6 +348,70 @@ event_canvas_clicked (BstEventRoll           *eroll,
                     event->button.button, event->button.time);
 }
 
+static void
+part_dialog_run_script_proc (gpointer                data,
+                             gulong                  category_id)
+{
+  BstPartDialog *self = BST_PART_DIALOG (data);
+  BseCategory *cat = bse_category_from_id (category_id);
+  SfiProxy part = self->proll->proxy;
+
+  bst_procedure_exec_auto (cat->type,
+                           "project", SFI_TYPE_PROXY, bse_item_get_project (part),
+                           "part", SFI_TYPE_PROXY, part,
+                           NULL);
+}
+
+static void
+resizer_adjustment_client_changed (GtkAdjustment *adj)
+{
+  GtkAdjustment *client = g_object_get_data (adj, "client");
+  gdouble f, u = client->upper;
+  gdouble l = client->lower;
+  gdouble v = client->value + client->page_size;
+  f = (v - l) / (u - l);
+  f = 1.0 - f;
+  if (f != adj->value)
+    {
+      g_object_steal_data (adj, "client");
+      gtk_adjustment_set_value (adj, f);
+      g_object_set_data_full (adj, "client", g_object_ref (client), g_object_unref);
+    }
+}
+
+static void
+resizer_adjustment_value_changed (GtkAdjustment *adj)
+{
+  GtkAdjustment *client = g_object_get_data (adj, "client");
+  if (!client)
+    return;
+  gdouble f, u;
+  gdouble v = client->value + client->page_size;
+  /* calculate new client upper based on client->lower,
+   * client->value (>=50%) and adj->value, which indicates
+   * client->value position within 100%..50%
+   */
+  f = 1.0 - adj->value;
+  u = v / f;
+  if (u != client->upper)
+    {
+      client->upper = u;
+      gtk_adjustment_changed (client);
+    }
+}
+
+static GtkAdjustment*
+resizer_adjustment_create (GtkAdjustment *client)
+{
+  GtkAdjustment *adj = (GtkAdjustment*) gtk_adjustment_new (0, 0, 1 - 0.1, 0.0001, 0.1, 0);
+  g_object_set_data_full (adj, "client", g_object_ref (client), g_object_unref);
+  resizer_adjustment_client_changed (adj);
+  g_signal_connect_object (client, "changed", G_CALLBACK (resizer_adjustment_client_changed), adj, G_CONNECT_SWAPPED);
+  g_signal_connect_object (client, "value-changed", G_CALLBACK (resizer_adjustment_client_changed), adj, G_CONNECT_SWAPPED);
+  g_signal_connect (adj, "value-changed", G_CALLBACK (resizer_adjustment_value_changed), NULL);
+  return adj;
+}
+
 static void
 part_dialog_action_exec (gpointer data,
                          gulong   action)
@@ -305,19 +423,19 @@ part_dialog_action_exec (gpointer data,
   switch (action)
     {
     case ACTION_CLEAR:
-      bst_piano_roll_controller_clear (self->pctrl);
+      bst_piano_roll_controller_clear (self->pictrl);
       bst_event_roll_controller_clear (self->ectrl);
       break;
     case ACTION_CUT:
-      bst_piano_roll_controller_cut (self->pctrl);
+      bst_piano_roll_controller_cut (self->pictrl);
       bst_event_roll_controller_cut (self->ectrl);
       break;
     case ACTION_COPY:
-      if (!bst_piano_roll_controller_copy (self->pctrl))
+      if (!bst_piano_roll_controller_copy (self->pictrl))
         bst_event_roll_controller_copy (self->ectrl);
       break;
     case ACTION_PASTE:
-      bst_piano_roll_controller_paste (self->pctrl);
+      bst_piano_roll_controller_paste (self->pictrl);
       bst_event_roll_controller_paste (self->ectrl);
       break;
     case ACTION_UNDO:
@@ -350,7 +468,7 @@ part_dialog_action_check (gpointer data,
     case ACTION_COPY:
       return TRUE;
     case ACTION_PASTE:
-      return (bst_piano_roll_controler_clipboard_full (self->pctrl) ||
+      return (bst_piano_roll_controler_clipboard_full (self->pictrl) ||
               bst_event_roll_controler_clipboard_full (self->ectrl));
     case ACTION_UNDO:
       return self->project && bse_project_undo_depth (self->project) > 0;
