@@ -33,8 +33,6 @@ enum {
 
 
 /* --- prototypes --- */
-static void	bst_qsampler_class_init		(BstQSamplerClass	*class);
-static void	bst_qsampler_init		(BstQSampler		*qsampler);
 static void	bst_qsampler_destroy		(GtkObject		*object);
 static void	bst_qsampler_finalize		(GObject		*object);
 static void	bst_qsampler_set_property	(GObject		*object,
@@ -72,39 +70,13 @@ static void	bst_qsampler_queue_refresh	(BstQSampler		*qsampler);
 
 
 /* --- static variables --- */
-static gpointer	parent_class = NULL;
 static GSList  *refresh_widgets = NULL;
 static GSList  *tmp_refresh_widgets = NULL;
 static gint     refresh_handler = 0;
 
 
 /* --- functions --- */
-GType
-bst_qsampler_get_type (void)
-{
-  static GType type = 0;
-
-  if (!type)
-    {
-      static const GTypeInfo type_info = {
-	sizeof (BstQSamplerClass),
-	(GBaseInitFunc) NULL,
-	(GBaseFinalizeFunc) NULL,
-	(GClassInitFunc) bst_qsampler_class_init,
-	NULL,   /* class_finalize */
-	NULL,   /* class_data */
-	sizeof (BstQSampler),
-	0,      /* n_preallocs */
-	(GInstanceInitFunc) bst_qsampler_init,
-      };
-
-      type = g_type_register_static (GTK_TYPE_WIDGET,
-				     "BstQSampler",
-				     &type_info, 0);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE (BstQSampler, bst_qsampler, GTK_TYPE_WIDGET);
 
 static void
 bst_qsampler_class_init (BstQSamplerClass *class)
@@ -113,8 +85,6 @@ bst_qsampler_class_init (BstQSamplerClass *class)
   GtkObjectClass *object_class = GTK_OBJECT_CLASS (class);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
 
-  parent_class = gtk_type_class (GTK_TYPE_WIDGET);
-
   gobject_class->finalize = bst_qsampler_finalize;
   gobject_class->set_property = bst_qsampler_set_property;
   gobject_class->get_property = bst_qsampler_get_property;
@@ -193,7 +163,7 @@ bst_qsampler_size_allocate (GtkWidget     *widget,
 {
   BstQSampler *qsampler = BST_QSAMPLER (widget);
   
-  GTK_WIDGET_CLASS (parent_class)->size_allocate (widget, allocation);
+  GTK_WIDGET_CLASS (bst_qsampler_parent_class)->size_allocate (widget, allocation);
 
   if (GTK_WIDGET_REALIZED (widget))
     gdk_window_move_resize (qsampler->canvas,
@@ -264,7 +234,7 @@ bst_qsampler_style_set (GtkWidget *widget,
 {
   BstQSampler *qsampler = BST_QSAMPLER (widget);
 
-  GTK_WIDGET_CLASS (parent_class)->style_set (widget, previous_style);
+  GTK_WIDGET_CLASS (bst_qsampler_parent_class)->style_set (widget, previous_style);
 
   if (GTK_WIDGET_REALIZED (qsampler))
     {
@@ -311,7 +281,7 @@ bst_qsampler_unrealize (GtkWidget *widget)
   gdk_window_set_user_data (qsampler->canvas, NULL);
   gdk_window_destroy (qsampler->canvas);
   qsampler->canvas = NULL;
-  GTK_WIDGET_CLASS (parent_class)->unrealize (widget);
+  GTK_WIDGET_CLASS (bst_qsampler_parent_class)->unrealize (widget);
 }
 
 static gint
@@ -387,7 +357,7 @@ bst_qsampler_destroy (GtkObject *object)
   bst_qsampler_set_source (qsampler, 0, NULL, NULL, NULL);
   bst_qsampler_set_adjustment (qsampler, NULL);
 
-  GTK_OBJECT_CLASS (parent_class)->destroy (object);
+  GTK_OBJECT_CLASS (bst_qsampler_parent_class)->destroy (object);
 }
 
 static void
@@ -406,7 +376,7 @@ bst_qsampler_finalize (GObject *object)
   else
     qsampler->refresh_queued = TRUE;
 
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  G_OBJECT_CLASS (bst_qsampler_parent_class)->finalize (object);
 }
 
 static void
