@@ -211,8 +211,8 @@ bst_snet_router_init (BstSNetRouter      *self)
             else
               stock_id = stock_fallback;
             gxk_action_list_add_translated (toolbar_modules, cat->type,
-                                            T_(toolbar_types[n].name), NULL,
-                                            T_(toolbar_types[n].tip),
+                                            _(toolbar_types[n].name), NULL,
+                                            _(toolbar_types[n].tip),
                                             cat->category_id,
                                             stock_id,
                                             NULL, bst_router_popup_select, self);
@@ -416,7 +416,7 @@ bst_snet_router_update (BstSNetRouter *self)
 {
   GnomeCanvasItem *csource;
   GnomeCanvas *canvas;
-  BseProxySeq *pseq;
+  BseItemSeq *iseq;
   GSList *slist, *csources = NULL;
   guint i;
   
@@ -439,10 +439,10 @@ bst_snet_router_update (BstSNetRouter *self)
     }
   
   /* walk all child sources */
-  pseq = bse_container_list_items (self->snet);
-  for (i = 0; i < pseq->n_proxies; i++)
+  iseq = bse_container_list_items (self->snet);
+  for (i = 0; i < iseq->n_items; i++)
     {
-      SfiProxy item = pseq->proxies[i];
+      SfiProxy item = iseq->items[i];
       
       if (BSE_IS_SOURCE (item))
 	{
