@@ -337,19 +337,20 @@ static void
 controller_update_hpanel_cursor (BstTrackRollController *self,
 				 guint                  tool_id)
 {
+  GxkScrollCanvas *scc = GXK_SCROLL_CANVAS (self->troll);
   switch (tool_id)
     {
     case BST_GENERIC_ROLL_TOOL_MOVE_TICK_POINTER:
-      bst_track_roll_set_hpanel_cursor (self->troll, GDK_SB_DOWN_ARROW);
+      gxk_scroll_canvas_set_top_panel_cursor (scc, GDK_SB_DOWN_ARROW);
       break;
     case BST_GENERIC_ROLL_TOOL_MOVE_TICK_LEFT:
-      bst_track_roll_set_hpanel_cursor (self->troll, GDK_LEFT_SIDE);
+      gxk_scroll_canvas_set_top_panel_cursor (scc, GDK_LEFT_SIDE);
       break;
     case BST_GENERIC_ROLL_TOOL_MOVE_TICK_RIGHT:
-      bst_track_roll_set_hpanel_cursor (self->troll, GDK_RIGHT_SIDE);
+      gxk_scroll_canvas_set_top_panel_cursor (scc, GDK_RIGHT_SIDE);
       break;
     default:
-      bst_track_roll_set_hpanel_cursor (self->troll, GXK_DEFAULT_CURSOR);
+      gxk_scroll_canvas_set_top_panel_cursor (scc, GXK_DEFAULT_CURSOR);
       break;
     }
 }
@@ -358,28 +359,29 @@ static void
 controller_update_canvas_cursor (BstTrackRollController *self,
 				 guint                  tool_id)
 {
+  GxkScrollCanvas *scc = GXK_SCROLL_CANVAS (self->troll);
   switch (tool_id)
     {
     case BST_GENERIC_ROLL_TOOL_INSERT:
-      bst_track_roll_set_canvas_cursor (self->troll, GDK_PENCIL);
+      gxk_scroll_canvas_set_canvas_cursor (scc, GDK_PENCIL);
       break;
     case BST_GENERIC_ROLL_TOOL_LINK:
-      bst_track_roll_set_canvas_cursor (self->troll, GDK_DIAMOND_CROSS);
+      gxk_scroll_canvas_set_canvas_cursor (scc, GDK_DIAMOND_CROSS);
       break;
     case BST_GENERIC_ROLL_TOOL_RENAME:
-      bst_track_roll_set_canvas_cursor (self->troll, GXK_DEFAULT_CURSOR);
+      gxk_scroll_canvas_set_canvas_cursor (scc, GXK_DEFAULT_CURSOR);
       break;
     case BST_GENERIC_ROLL_TOOL_MOVE:
-      bst_track_roll_set_canvas_cursor (self->troll, GDK_FLEUR);
+      gxk_scroll_canvas_set_canvas_cursor (scc, GDK_FLEUR);
       break;
     case BST_GENERIC_ROLL_TOOL_DELETE:
-      bst_track_roll_set_canvas_cursor (self->troll, GDK_TARGET);
+      gxk_scroll_canvas_set_canvas_cursor (scc, GDK_TARGET);
       break;
     case BST_GENERIC_ROLL_TOOL_EDITOR:
-      bst_track_roll_set_canvas_cursor (self->troll, GDK_HAND2);
+      gxk_scroll_canvas_set_canvas_cursor (scc, GDK_HAND2);
       break;
     default:
-      bst_track_roll_set_canvas_cursor (self->troll, GXK_DEFAULT_CURSOR);
+      gxk_scroll_canvas_set_canvas_cursor (scc, GXK_DEFAULT_CURSOR);
       break;
     }
 }
@@ -406,7 +408,7 @@ edit_name_start (BstTrackRollController *self,
     }
   else
     gxk_status_set (GXK_STATUS_ERROR, _("Edit Part"), _("No Part"));
-  drag->state = BST_DRAG_HANDLED;
+  drag->state = GXK_DRAG_HANDLED;
 }
 
 static void
@@ -440,7 +442,7 @@ insert_start (BstTrackRollController *self,
 	  else
 	    gxk_status_set (GXK_STATUS_ERROR, _("Insert Part"), _("Lost Part"));
           bse_item_ungroup_undo (song);
-	  drag->state = BST_DRAG_HANDLED;
+	  drag->state = GXK_DRAG_HANDLED;
 	}
       else
 	gxk_status_set (GXK_STATUS_ERROR, _("Insert Part"), _("Position taken"));
@@ -451,7 +453,7 @@ insert_start (BstTrackRollController *self,
 	gxk_status_set (GXK_STATUS_ERROR, _("Insert Part"), _("Position taken"));
       else
 	gxk_status_set (GXK_STATUS_ERROR, _("Insert part"), _("No Track"));
-      drag->state = BST_DRAG_HANDLED;
+      drag->state = GXK_DRAG_HANDLED;
     }
 }
 
@@ -466,7 +468,7 @@ delete_start (BstTrackRollController *self,
     }
   else
     gxk_status_set (GXK_STATUS_ERROR, _("Delete Part"), _("No target"));
-  drag->state = BST_DRAG_HANDLED;
+  drag->state = GXK_DRAG_HANDLED;
 }
 
 static void
@@ -480,13 +482,13 @@ move_link_start (BstTrackRollController *self,
       self->xoffset = drag->start_tick - self->obj_tick;	/* drag offset */
       controller_update_canvas_cursor (self, link_pending ? BST_GENERIC_ROLL_TOOL_LINK : BST_GENERIC_ROLL_TOOL_MOVE);
       gxk_status_set (GXK_STATUS_PROGRESS, action, NULL);
-      drag->state = BST_DRAG_CONTINUE;
+      drag->state = GXK_DRAG_CONTINUE;
       self->skip_deletion = link_pending;
     }
   else
     {
       gxk_status_set (GXK_STATUS_ERROR, action, _("No target"));
-      drag->state = BST_DRAG_HANDLED;
+      drag->state = GXK_DRAG_HANDLED;
     }
 }
 
@@ -558,7 +560,7 @@ editor_create (BstTrackRollController *self,
     }
   else
     gxk_status_set (GXK_STATUS_ERROR, _("Start Editor"), _("No target"));
-  drag->state = BST_DRAG_HANDLED;
+  drag->state = GXK_DRAG_HANDLED;
 }
 
 static void
@@ -566,11 +568,11 @@ pointer_move (BstTrackRollController *self,
 	      BstTrackRollDrag       *drag)
 {
   if (self->song &&
-      drag->type != BST_DRAG_DONE) /* skip release events */
+      drag->type != GXK_DRAG_DONE) /* skip release events */
     {
       guint tick = bst_track_roll_controller_quantize (self, drag->current_tick);
       bse_proxy_set (self->song, "tick-pointer", tick, NULL);
-      drag->state = BST_DRAG_CONTINUE;
+      drag->state = GXK_DRAG_CONTINUE;
     }
 }
 
@@ -582,7 +584,7 @@ tick_left_move (BstTrackRollController *self,
     {
       guint tick = bst_track_roll_controller_quantize (self, drag->current_tick);
       bse_proxy_set (self->song, "loop-left", tick, NULL);
-      drag->state = BST_DRAG_CONTINUE;
+      drag->state = GXK_DRAG_CONTINUE;
     }
 }
 
@@ -594,7 +596,7 @@ tick_right_move (BstTrackRollController *self,
     {
       guint tick = bst_track_roll_controller_quantize (self, drag->current_tick);
       bse_proxy_set (self->song, "loop-right", tick, NULL);
-      drag->state = BST_DRAG_CONTINUE;
+      drag->state = GXK_DRAG_CONTINUE;
     }
 }
 
@@ -625,7 +627,7 @@ controller_drag (BstTrackRollController *self,
   };
 
   /* initial drag handling */
-  if (drag->type == BST_DRAG_START)
+  if (drag->type == GXK_DRAG_START)
     {
       BstGenericRollTool obj_tool, tool;
       BseTrackPart *tpart = NULL;
@@ -643,7 +645,7 @@ controller_drag (BstTrackRollController *self,
 	  obj_tool = canvas_button_tool (self, drag->button, HAVE_OBJECT);
 	  tool = canvas_button_tool (self, drag->button, 0);
 	}
-      else if (drag->hpanel_drag)
+      else if (drag->top_panel_drag)
 	{
 	  tool_table = hpanel_tool_table;
 	  n_tools = G_N_ELEMENTS (hpanel_tool_table);
@@ -691,21 +693,21 @@ controller_drag (BstTrackRollController *self,
   /* generic drag handling */
   switch (drag->type)
     {
-    case BST_DRAG_START:
+    case GXK_DRAG_START:
       if (self->current_tool->start)
 	self->current_tool->start (self, drag);
       break;
-    case BST_DRAG_MOTION:
-    case BST_DRAG_DONE:
+    case GXK_DRAG_MOTION:
+    case GXK_DRAG_DONE:
       if (self->current_tool->motion)
 	self->current_tool->motion (self, drag);
       break;
-    case BST_DRAG_ABORT:
+    case GXK_DRAG_ABORT:
       if (self->current_tool->abort)
 	self->current_tool->abort (self, drag);
       break;
     }
-  if (drag->type == BST_DRAG_DONE || drag->type == BST_DRAG_ABORT)
+  if (drag->type == GXK_DRAG_DONE || drag->type == GXK_DRAG_ABORT)
     {
       self->current_tool = NULL;
       controller_reset_canvas_cursor (self);
