@@ -1,5 +1,5 @@
 /* GXK - Gtk+ Extension Kit
- * Copyright (C) 1998-2002 Tim Janik
+ * Copyright (C) 1998-2004 Tim Janik
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -16,12 +16,12 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include	"gxkdialog.h"
-
-#include	"gxkstock.h"
-#include	"gxkstatusbar.h"
-#include	<gdk/gdkkeysyms.h>
-#include	<string.h>
+#include "gxkdialog.h"
+#include "gxkgadget.h"
+#include "gxkstock.h"
+#include "gxkstatusbar.h"
+#include <gdk/gdkkeysyms.h>
+#include <string.h>
 
 #define	DEFAULT_TITLE	"Auxillary Dialog"
 
@@ -356,6 +356,21 @@ gxk_dialog_new (gpointer       pointer_loc,
   return dialog;
 }
 
+gpointer
+gxk_dialog_new_gadget (gpointer        pointer_loc,
+                       GtkObject      *alive_object,
+                       GxkDialogFlags  flags,
+                       const gchar    *title,
+                       const gchar    *domain_name,
+                       const gchar    *gadget_name)
+{
+  GxkGadget *gadget = gxk_gadget_create (domain_name, gadget_name, NULL);
+  if (gadget)
+    return gxk_dialog_new (pointer_loc, alive_object, flags, title, gadget);
+  else
+    return NULL;
+}
+
 /**
  * gxk_dialog_set_title
  * @dialog: valid GxkDialog
@@ -559,24 +574,34 @@ gxk_dialog_key_press_event (GtkWidget   *widget,
       return TRUE;
     }
 
-#if defined (__linux__)         // FIXME: use gtk_window_activate_key() once exposed
   /* we're overriding the GtkWindow implementation here to give
    * the focus widget precedence over unmodified accelerators
    * before the accelerator activation scheme.
    */
-
+#if     GTK_CHECK_VERSION (2, 3, 4)
   /* invoke control/alt accelerators */
   if (!handled && event->state & (GDK_CONTROL_MASK | GDK_MOD1_MASK))
-    handled = _gtk_window_activate_key (window, event);
+    handled = gtk_window_activate_key (window, event);
+  /* invoke focus widget handlers */
+  if (!handled)
+    handled = gtk_window_propagate_key_event (window, event);
+  /* invoke non-(control/alt) accelerators */
+  if (!handled && !(event->state & (GDK_CONTROL_MASK | GDK_MOD1_MASK)))
+    handled = gtk_window_activate_key (window, event);
+  /* chain up, bypassing gtk_window_key_press(), to invoke binding set */
+  if (!handled)
+    handled = GTK_WIDGET_CLASS (g_type_class_peek (g_type_parent (GTK_TYPE_WINDOW)))->key_press_event (widget, event);
+#elif   defined (__linux__)     /* on linux we can circumvent gtk+-2.2 also */
+  /* invoke control/alt accelerators */
+  if (!handled && event->state & (GDK_CONTROL_MASK | GDK_MOD1_MASK))
+    handled = _gtk_window_activate_key (window, event); /* available due to broken libtool */
   /* invoke focus widget handlers */
   if (!handled)
     {
       GtkWidget *focus = window->focus_widget;
       if (focus)
         g_object_ref (focus);
-      while (!handled &&
-             focus && focus != widget &&
-             gtk_widget_get_toplevel (focus) == widget)
+      while (!handled && focus && focus != widget && gtk_widget_get_toplevel (focus) == widget)
         {
           GtkWidget *parent;
           if (GTK_WIDGET_IS_SENSITIVE (focus))
@@ -596,7 +621,7 @@ gxk_dialog_key_press_event (GtkWidget   *widget,
   /* chain up, bypassing gtk_window_key_press(), to invoke binding set */
   if (!handled)
     handled = GTK_WIDGET_CLASS (g_type_class_peek (g_type_parent (GTK_TYPE_WINDOW)))->key_press_event (widget, event);
-#else
+#else   /* gtk+ <= 2.2, non-linux */
   handled = GTK_WIDGET_CLASS (parent_class)->key_press_event (widget, event);
 #endif
 
