@@ -18,7 +18,7 @@
  */
 #include "gxkutils.h"
 #include "glewidgets.h"
-#include "gxkauxwidgets.h"
+#include "gxkmenubutton.h"
 #include "gxkcellrendererpopup.h"
 #include <string.h>
 
@@ -240,7 +240,11 @@ gxk_factory_path_unescape_uline (const gchar *path)
   while (*p)
     {
       if (*p == '_')
-        p++;
+        {
+          p++;
+          if (*p == '_')
+            *d++ = *p++;
+        }
       *d++ = *p++;
     }
   *d = 0;
@@ -623,6 +627,34 @@ gxk_notebook_set_current_page_widget (GtkNotebook *notebook,
     gtk_notebook_set_current_page (notebook, num);
 }
 
+static void
+vseparator_space_request (GtkWidget      *widget,
+                          GtkRequisition *requisition,
+                          gpointer        data)
+{
+  guint i = GPOINTER_TO_INT (data);
+  requisition->width = i * widget->style->xthickness;
+}
+
+/**
+ * gxk_vseparator_space_new
+ * @draw_seperator: enable visible vertical seperator
+ * @RETURNS:        visible vertical space/seperator widget
+ *
+ * Create a vertical seperator widget. @draw_seperator indicates
+ * whether the seperator should be amount to simple space or not.
+ */
+GtkWidget*
+gxk_vseparator_space_new (gboolean draw_seperator)
+{
+  GtkWidget *widget = g_object_new (draw_seperator ? GTK_TYPE_VSEPARATOR : GTK_TYPE_ALIGNMENT,
+                                    "visible", TRUE,
+                                    NULL);
+  g_signal_connect (widget, "size-request", G_CALLBACK (vseparator_space_request),
+                    GUINT_TO_POINTER (draw_seperator ? 2 + 1 + 2 : 3));
+  return widget;
+}
+
 /**
  * gtk_notebook_current_widget
  * @notebook: valid #GtkNotebook
@@ -749,11 +781,14 @@ static void
 style_modify_bg_as_base (GtkWidget *widget)
 {
   GtkRcStyle *rc_style = gtk_widget_get_modifier_style (widget);
-
-  rc_style->color_flags[GTK_STATE_NORMAL] = GTK_RC_BG;
-  rc_style->bg[GTK_STATE_NORMAL].red = widget->style->base[GTK_STATE_NORMAL].red;
-  rc_style->bg[GTK_STATE_NORMAL].green = widget->style->base[GTK_STATE_NORMAL].green;
-  rc_style->bg[GTK_STATE_NORMAL].blue = widget->style->base[GTK_STATE_NORMAL].blue;
+  guint i;
+  for (i = GTK_STATE_NORMAL; i <= GTK_STATE_INSENSITIVE; i++)
+    {
+      rc_style->color_flags[i] = GTK_RC_BG;
+      rc_style->bg[i].red = widget->style->base[i].red;
+      rc_style->bg[i].green = widget->style->base[i].green;
+      rc_style->bg[i].blue = widget->style->base[i].blue;
+    }
   gtk_widget_modify_style (widget, rc_style);
 }
 
@@ -840,6 +875,42 @@ gxk_widget_force_bg_clear (GtkWidget *widget)
     g_signal_connect (widget, "expose_event", G_CALLBACK (expose_bg_clear), NULL);
 }
 
+/**
+ * gxk_widget_set_latent_tooltip
+ * @widget:  a valid GtkWidget
+ * @tooltip: descriptive tooltip
+ *
+ * Set the latent tooltip for this widget. A latent tooltip
+ * will not be shown on mouse over for this widget. Instead
+ * it can be querried by other widgets via
+ * gxk_widget_get_latent_tooltip() to be shown when appropriate.
+ * For instance, GxkMenuButton shows the latent tooltip of its
+ * currently selected menu item.
+ */
+void
+gxk_widget_set_latent_tooltip (GtkWidget   *widget,
+                               const gchar *tooltip)
+{
+  if (tooltip && !tooltip[0])
+    tooltip = NULL;
+  g_object_set_data_full (widget, "gxk-widget-latent-tooltip", g_strdup (tooltip), g_free);
+}
+
+/**
+ * gxk_widget_get_latent_tooltip
+ * @widget:  a valid GtkWidget
+ * @RETUSN: descriptive tooltip
+ *
+ * Retrieve the latent tooltip for @widget. See
+ * gxk_widget_set_latent_tooltip() for the purpose of latent
+ * tooltips.
+ */
+const gchar*
+gxk_widget_get_latent_tooltip (GtkWidget *widget)
+{
+  return g_object_get_data (widget, "gxk-widget-latent-tooltip");
+}
+
 static gboolean
 gxk_activate_accel_group (GtkWidget     *widget,
 			  GdkEventKey   *event,
@@ -1516,6 +1587,25 @@ gxk_tree_selection_unselect_ipath (GtkTreeSelection *selection,
   gtk_tree_path_free (path);
 }
 
+void
+gxk_tree_view_select_index (GtkTreeView           *tview,
+                            guint                  index)
+{
+  GtkTreeSelection *tsel;
+  GtkTreePath *path;
+  g_return_if_fail (GTK_IS_TREE_VIEW (tview));
+  tsel = gtk_tree_view_get_selection (tview);
+  path = gtk_tree_path_new ();
+  gtk_tree_path_append_index (path, index);
+  gtk_tree_selection_select_path (tsel, path);
+  if (gtk_tree_selection_path_is_selected (tsel, path))
+    {
+      /* GTKFIX: this can trigger an assertion on empty sort models */
+      gtk_tree_view_set_cursor (tview, path, NULL, FALSE);
+    }
+  gtk_tree_path_free (path);
+}
+
 static GSList           *browse_selection_queue = NULL;
 static guint             browse_selection_handler_id = 0;
 static GtkTreeSelection *browse_selection_ignore = NULL;
@@ -1624,8 +1714,6 @@ gxk_tree_selection_force_browse (GtkTreeSelection *selection,
   g_return_if_fail (GTK_IS_TREE_SELECTION (selection));
   if (model)
     g_return_if_fail (GTK_IS_TREE_MODEL (model));
-  return; // FIXME: hack disabled
-
   if (!gxk_signal_handler_pending (selection, "changed", G_CALLBACK (browse_selection_changed), selection))
     g_signal_connect_data (selection, "changed", G_CALLBACK (browse_selection_changed), selection, NULL, 0);
   if (model && !gxk_signal_handler_pending (model, "row-inserted", G_CALLBACK (browse_selection_changed), selection))
@@ -2494,18 +2582,30 @@ gxk_menu_check_sensitive (GtkMenu *menu)
   for (list = shell->children; list; list = list->next)
     {
       GtkWidget *child = list->data;
-      if (GTK_WIDGET_VISIBLE (child) && GTK_WIDGET_IS_SENSITIVE (child))
+      if (GTK_WIDGET_VISIBLE (child) &&
+          GTK_WIDGET_IS_SENSITIVE (child) &&
+          !GTK_IS_TEAROFF_MENU_ITEM (child))
         return TRUE;
     }
   return FALSE;
 }
 
 static void
-submenu_check_sensitive (GtkMenu *menu)
+submenu_adjust_sensitivity (GtkMenu *menu)
 {
   GtkWidget *widget = gtk_menu_get_attach_widget (menu);
   if (GTK_IS_MENU_ITEM (widget))
-    gtk_widget_set_sensitive (widget, gxk_menu_check_sensitive (menu));
+    {
+      gboolean sensitive = gxk_menu_check_sensitive (menu);
+      if (sensitive != GTK_WIDGET_SENSITIVE (widget))
+        {
+          GtkWidget *parent = widget->parent;
+          gtk_widget_set_sensitive (widget, sensitive);
+          /* push change along to parent if necessary */
+          if (parent && gxk_signal_handler_pending (parent, "parent-set", G_CALLBACK (submenu_adjust_sensitivity), NULL))
+            submenu_adjust_sensitivity (GTK_MENU (parent));
+        }
+    }
 }
 
 static void
@@ -2536,7 +2636,7 @@ menu_item_propagate_hierarchy_changed (GtkMenuItem *menu_item)
  * the necessary hooks on the @menu to automatically
  * update sensitivity of @menu_item in response
  * to children being deleted or added to the @menu.
- * The rationality behind this is to avoid empty menus
+ * The rationale behind this is to avoid empty menus
  * being presented to the user.
  * Also, a propagation mechanism is set up, so @menu
  * and submenus thereof automatically fetch their
@@ -2556,13 +2656,13 @@ gxk_menu_attach_as_submenu (GtkMenu     *menu,
     g_signal_connect_after (menu_item, "hierarchy-changed", G_CALLBACK (menu_item_propagate_hierarchy_changed), NULL);
   menu_item_propagate_hierarchy_changed (menu_item);
 
-  if (!gxk_signal_handler_pending (menu, "parent-set", G_CALLBACK (submenu_check_sensitive), NULL))
+  if (!gxk_signal_handler_pending (menu, "parent-set", G_CALLBACK (submenu_adjust_sensitivity), NULL))
     g_object_connect (menu,
-                      "signal_after::parent-set", submenu_check_sensitive, NULL,
-                      "signal_after::add", submenu_check_sensitive, NULL,
-                      "signal_after::remove", submenu_check_sensitive, NULL,
+                      "signal_after::parent-set", submenu_adjust_sensitivity, NULL,
+                      "signal_after::add", submenu_adjust_sensitivity, NULL,
+                      "signal_after::remove", submenu_adjust_sensitivity, NULL,
                       NULL);
-  submenu_check_sensitive (menu);
+  submenu_adjust_sensitivity (menu);
 }
 
 static void
