@@ -5,8 +5,8 @@
   bse__builtin_init_bseeditablesample_gen_proc_c,
   bse__builtin_init_bsemidinotifier_gen_proc_c,
   bse__builtin_init_bsejanitor_gen_proc_c,
-  bse__builtin_init_bseobject_gen_proc_c,
   bse__builtin_init_bsepart_gen_proc_c,
+  bse__builtin_init_bseparasite_gen_proc_c,
   bse__builtin_init_bseprocedure_gen_proc_c,
   bse__builtin_init_bseproject_gen_proc_c,
   bse__builtin_init_bsescripthelper_gen_proc_c,
