@@ -44,6 +44,7 @@ static gboolean   cats_need_sort = FALSE;
 static guint      global_category_id = 1;
 static SfiUStore *category_ustore = NULL;
 
+
 /* --- functions --- */
 void
 _bse_init_categories (void)
@@ -66,26 +67,46 @@ centry_find (GQuark quark)
 }
 
 static inline guint
-category_strip_toplevels (const gchar *category)
+category_strip_toplevels (const gchar *category,
+                          GType        type)
 {
+  static const struct { guint length; const gchar *prefix; } scripts[] = {
+    {  9, "/Project/", },
+    {  6, "/SNet/", },
+    {  6, "/Song/", },
+    {  6, "/Part/", },
+    {  8, "/CSynth/", },
+    {  6, "/Wave/", },
+    { 10, "/WaveRepo/", },
+    {  6, "/Proc/", },
+  };
   guint l = strlen (category);
   
-  if (l > 10 && strncmp (category, "/Method/", 8) == 0)
+  if (l > 10 && strncmp (category, "/Methods/", 8) == 0)
     {
       const gchar *p = category + 8;
-      
+
+      if (!BSE_TYPE_IS_PROCEDURE (type))
+        return 0;
       p = strchr (p, '/');
       if (p && p[1])
 	return p - category + 1;
     }
   else if (l > 8 && strncmp (category, "/Modules/", 9) == 0)
-    return 9;
-  else if (l > 8 && strncmp (category, "/Scripts/", 9) == 0)
-    return 9;
-  else if (l > 8 && strncmp (category, "/Effect/", 8) == 0)
-    return 8;
-  else if (l > 6 && strncmp (category, "/Proc/", 6) == 0)
-    return 6;
+    {
+      if (!G_TYPE_IS_OBJECT (type))
+        return 0;
+      return 9;
+    }
+
+  if (BSE_TYPE_IS_PROCEDURE (type))
+    {
+      guint i;
+      for (i = 0; i < G_N_ELEMENTS (scripts); i++)
+        if (l > scripts[i].length &&
+            strncmp (category, scripts[i].prefix, scripts[i].length) == 0)
+          return scripts[i].length;
+    }
   
   return 0;
 }
@@ -109,14 +130,15 @@ leaf_index (const gchar *string)
 
 static inline CEntry*
 centry_new (const gchar *caller,
-	    const gchar *category)
+	    const gchar *category,
+            GType        type)
 {
   static GTrashStack *free_entries = NULL;
   CEntry *centry;
   GQuark quark;
   guint mindex;
   
-  mindex = category_strip_toplevels (category);
+  mindex = category_strip_toplevels (category, type);
   if (!mindex)
     {
       g_warning ("%s(): refusing to add non-conforming category `%s'", caller, category);
@@ -169,19 +191,23 @@ check_type (GType type)
 }
 
 void
-bse_categories_register (const gchar *category,
-			 GType        type)
+bse_categories_register (const gchar  *category,
+			 GType         type,
+                         const guint8 *pixstream)
 {
   CEntry *centry;
   
   g_return_if_fail (category != NULL);
   
-  centry = centry_new (G_GNUC_PRETTY_FUNCTION, category);
+  centry = centry_new (G_GNUC_PRETTY_FUNCTION, category, type);
   check_type (type);
   if (centry)
     {
       centry->type = type;
-      centry->icon = NULL;
+      if (pixstream)
+        centry->icon = bse_icon_from_pixstream (pixstream);
+      else
+        centry->icon = NULL;
     }
 }
 
@@ -195,7 +221,7 @@ bse_categories_register_icon (const gchar      *category,
   g_return_if_fail (category != NULL);
   g_return_if_fail (pixdata != NULL);
   
-  centry = centry_new (G_GNUC_PRETTY_FUNCTION, category);
+  centry = centry_new (G_GNUC_PRETTY_FUNCTION, category, type);
   check_type (type);
   if (centry)
     {
@@ -248,8 +274,10 @@ cats_sort (void)
 }
 
 static inline BseCategorySeq*
-categories_match (const gchar *pattern,
-		  GType        base_type)
+categories_match (const gchar      *pattern,
+		  GType             base_type,
+                  BseCategoryCheck  check,
+                  gpointer          data)
 {
   BseCategorySeq *cseq = bse_category_seq_new ();
   GPatternSpec *pspec = g_pattern_spec_new (pattern);
@@ -264,13 +292,14 @@ categories_match (const gchar *pattern,
 	{
 	  BseCategory cat = { 0, };
 	  
-	  cat.category = g_strdup (category);
+	  cat.category = category;
 	  cat.category_id = centry->category_id;
 	  cat.mindex = centry->mindex;
 	  cat.lindex = centry->lindex;
-	  cat.type = g_strdup (g_type_name (centry->type));
-	  cat.icon = centry->icon ? bse_icon_copy_shallow (centry->icon) : bse_icon_new ();
-	  bse_category_seq_append (cseq, &cat);
+	  cat.type = g_type_name (centry->type);
+	  cat.icon = centry->icon ? centry->icon : NULL;
+          if (!check || check (&cat, data))
+            bse_category_seq_append (cseq, &cat);
 	}
     }
   g_pattern_spec_free (pspec);
@@ -279,13 +308,16 @@ categories_match (const gchar *pattern,
 }
 
 BseCategorySeq*
-bse_categories_match (const gchar *pattern)
+bse_categories_match (const gchar      *pattern,
+                      GType             base_type,
+                      BseCategoryCheck  check,
+                      gpointer          data)
 {
   g_return_val_if_fail (pattern != NULL, NULL);
   
   cats_sort ();
   
-  return categories_match (pattern, 0);
+  return categories_match (pattern, 0, check, data);
 }
 
 BseCategorySeq*
@@ -293,11 +325,10 @@ bse_categories_match_typed (const gchar *pattern,
 			    GType        base_type)
 {
   g_return_val_if_fail (pattern != NULL, NULL);
-  g_return_val_if_fail (base_type > G_TYPE_NONE, NULL);
   
   cats_sort ();
   
-  return categories_match (pattern, base_type);
+  return categories_match (pattern, base_type, NULL, NULL);
 }
 
 BseCategorySeq*
@@ -311,12 +342,12 @@ bse_categories_from_type (GType type)
       {
 	BseCategory cat = { 0, };
 	
-	cat.category = g_strdup (g_quark_to_string (centry->category));
+	cat.category = g_quark_to_string (centry->category);
 	cat.category_id = centry->category_id;
 	cat.mindex = centry->mindex;
 	cat.lindex = centry->lindex;
-	cat.type = g_strdup (g_type_name (centry->type));
-	cat.icon = centry->icon ? bse_icon_copy_shallow (centry->icon) : bse_icon_new ();
+	cat.type = g_type_name (centry->type);
+	cat.icon = centry->icon ? centry->icon : NULL;
 	bse_category_seq_append (cseq, &cat);
       }
   return cseq;
@@ -333,12 +364,16 @@ bse_category_from_id (guint id)
   if (centry)
     {
       BseCategory *cat = bse_category_new ();
+      g_free (cat->category);
       cat->category = g_strdup (g_quark_to_string (centry->category));
       cat->category_id = centry->category_id;
       cat->mindex = centry->mindex;
       cat->lindex = centry->lindex;
+      g_free (cat->type);
       cat->type = g_strdup (g_type_name (centry->type));
-      cat->icon = centry->icon ? bse_icon_copy_shallow (centry->icon) : bse_icon_new ();
+      if (cat->icon)
+        bse_icon_free (cat->icon);
+      cat->icon = centry->icon ? bse_icon_copy_shallow (centry->icon) : NULL;
       return cat;
     }
   return NULL;
