@@ -108,41 +108,43 @@ bse_constant_class_init (BseConstantClass *class)
   
   for (i = 1; i <= BSE_CONSTANT_N_OUTPUTS; i++)
     {
-      gchar *string, *name, *group = g_strdup_printf ("Constant Output %u", i);
+      gchar *ident, *label, *blurb, *group = g_strdup_printf (_("Constant Output %u"), i);
       
-      string = g_strdup_printf ("value_%u", i);
-      name = g_strdup_printf ("Value [float]");
+      ident = g_strdup_printf ("value_%u", i);
+      label = g_strdup_printf (_("Value [float]"));
       bse_object_class_add_param (object_class, group, PARAM_VALUE + (i - 1) * 3,
-				  sfi_pspec_real (string, name, NULL,
+				  sfi_pspec_real (ident, label, NULL,
 						  1.0, -1.0, 1.0, 0.01,
 						  SFI_PARAM_STANDARD ":dial"));
-      g_free (string);
-      g_free (name);
-      string = g_strdup_printf ("frequency_%u", i);
-      name = g_strdup_printf ("Frequency");
+      g_free (ident);
+      g_free (label);
+      ident = g_strdup_printf ("frequency_%u", i);
+      label = g_strdup_printf (_("Frequency"));
       bse_object_class_add_param (object_class, group, PARAM_FREQ + (i - 1) * 3,
-				  sfi_pspec_log_scale (string, name, NULL,
+				  sfi_pspec_log_scale (ident, label, NULL,
 						       BSE_MAX_FREQUENCY_f,
 						       0, BSE_MAX_FREQUENCY_f,
 						       10.0,
 						       BSE_KAMMER_FREQUENCY_f * 2, 2, 4,
 						       SFI_PARAM_GUI ":dial"));
-      g_free (string);
-      g_free (name);
-      string = g_strdup_printf ("note_%u", i);
-      name = g_strdup_printf ("Note");
+      g_free (ident);
+      g_free (label);
+      ident = g_strdup_printf ("note_%u", i);
+      label = g_strdup_printf (_("Note"));
       bse_object_class_add_param (object_class, group, PARAM_NOTE + (i - 1) * 3,
-				  sfi_pspec_note (string, name, NULL,
+				  sfi_pspec_note (ident, label, NULL,
 						  SFI_KAMMER_NOTE, SFI_MIN_NOTE, SFI_MAX_NOTE,
 						  TRUE, SFI_PARAM_GUI));
-      g_free (string);
-      g_free (name);
-      string = g_strdup_printf ("Const Out%u", i);
-      name = g_strdup_printf ("Constant Output %u", i);
-      ochannel = bse_source_class_add_ochannel (source_class, string, name);
+      g_free (ident);
+      g_free (label);
+      ident = g_strdup_printf ("const-out%u", i);
+      label = g_strdup_printf (_("Const Out%u"), i);
+      blurb = g_strdup_printf (_("Constant Output %u"), i);
+      ochannel = bse_source_class_add_ochannel (source_class, ident, label, blurb);
       g_assert (ochannel == i - 1);
-      g_free (string);
-      g_free (name);
+      g_free (ident);
+      g_free (label);
+      g_free (blurb);
       g_free (group);
     }
 }
