@@ -19,7 +19,7 @@ list_items_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
  {
 #line 30 "bsecontainer.proc"
   *(in_pspecs++) = bse_param_spec_object ("container", NULL, NULL, BSE_TYPE_CONTAINER, SFI_PARAM_STANDARD);
-  *(out_pspecs++) = bse_param_spec_boxed ("item_list", "Item List", NULL, BSE_TYPE_PROXY_SEQ, SFI_PARAM_STANDARD);
+  *(out_pspecs++) = bse_param_spec_boxed ("item_list", "Item List", NULL, BSE_TYPE_ITEM_SEQ, SFI_PARAM_STANDARD);
 #line 32 "bsecontainer.proc"
 }  }
 static BseErrorType
