@@ -1,5 +1,5 @@
 /* BSE - Bedevilled Sound Engine
- * Copyright (C) 2002 Tim Janik
+ * Copyright (C) 2002-2003 Tim Janik
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,10 +43,13 @@ static void	    bse_data_pocket_class_init		(BseDataPocketClass	*class);
 static void	    bse_data_pocket_class_finalize	(BseDataPocketClass	*class);
 static void	    bse_data_pocket_dispose		(GObject		*object);
 static void	    bse_data_pocket_finalize		(GObject		*object);
+static gboolean     bse_data_pocket_needs_storage       (BseItem                *item,
+                                                         BseStorage             *storage);
 static void	    bse_data_pocket_do_store_private	(BseObject		*object,
 							 BseStorage		*storage);
-static BseTokenType bse_data_pocket_restore_private	(BseObject		*object,
-							 BseStorage		*storage);
+static SfiTokenType bse_data_pocket_restore_private	(BseObject		*object,
+							 BseStorage		*storage,
+                                                         GScanner               *scanner);
 
 
 /* --- variables --- */
@@ -86,6 +89,7 @@ bse_data_pocket_class_init (BseDataPocketClass *class)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (class);
   BseObjectClass *object_class = BSE_OBJECT_CLASS (class);
+  BseItemClass *item_class = BSE_ITEM_CLASS (class);
   
   parent_class = g_type_class_peek_parent (class);
   quark_set_data = g_quark_from_static_string ("set-data");
@@ -96,6 +100,8 @@ bse_data_pocket_class_init (BseDataPocketClass *class)
   object_class->store_private = bse_data_pocket_do_store_private;
   object_class->restore_private = bse_data_pocket_restore_private;
   
+  item_class->needs_storage = bse_data_pocket_needs_storage;
+
   signal_entry_added = bse_object_class_add_signal (object_class, "entry-added",
 						    G_TYPE_NONE, 1, G_TYPE_INT);
   signal_entry_removed = bse_object_class_add_signal (object_class, "entry-removed",
@@ -117,7 +123,6 @@ bse_data_pocket_init (BseDataPocket *pocket)
   pocket->entries = NULL;
   pocket->need_store = 0;
   pocket->cr_items = NULL;
-  BSE_OBJECT_SET_FLAGS (pocket, BSE_ITEM_FLAG_AGGREGATE);
 }
 
 static void
@@ -334,11 +339,6 @@ _bse_data_pocket_delete_entry (BseDataPocket *pocket,
   if (i < pocket->n_entries)
     pocket->entries[i] = pocket->entries[pocket->n_entries];
   
-  if (pocket->need_store)
-    BSE_OBJECT_UNSET_FLAGS (pocket, BSE_ITEM_FLAG_AGGREGATE);
-  else
-    BSE_OBJECT_SET_FLAGS (pocket, BSE_ITEM_FLAG_AGGREGATE);
-  
   while (cr_del)
     {
       GSList *tmp = cr_del;
@@ -429,11 +429,6 @@ _bse_data_pocket_entry_set (BseDataPocket     *pocket,
 	add_cross_ref (pocket, value.v_object);
     }
   
-  if (pocket->need_store)
-    BSE_OBJECT_UNSET_FLAGS (pocket, BSE_ITEM_FLAG_AGGREGATE);
-  else
-    BSE_OBJECT_SET_FLAGS (pocket, BSE_ITEM_FLAG_AGGREGATE);
-  
   changed_notify_add (pocket, entry->id);
   
   return TRUE;
@@ -472,6 +467,14 @@ _bse_data_pocket_entry_get (BseDataPocket      *pocket,
   return entry->items[n].type;
 }
 
+static gboolean
+bse_data_pocket_needs_storage (BseItem    *item,
+                               BseStorage *storage)
+{
+  BseDataPocket *self = BSE_DATA_POCKET (item);
+  return self->need_store > 0;
+}
+
 static void
 bse_data_pocket_do_store_private (BseObject  *object,
 				  BseStorage *storage)
@@ -492,7 +495,6 @@ bse_data_pocket_do_store_private (BseObject  *object,
       
       bse_storage_break (storage);
       bse_storage_printf (storage, "(create-entry");
-      bse_storage_needs_break (storage);
       bse_storage_push_level (storage);
       
       for (j = 0; j < entry->n_items; j++)
@@ -559,16 +561,16 @@ object_entry_resolved (gpointer        data,
   g_free (oentry);
 }
 
-static BseTokenType
+static SfiTokenType
 parse_set_data (BseDataPocket *pocket,
 		guint	       id,
-		BseStorage    *storage)
+		BseStorage    *storage,
+                GScanner      *scanner)
 {
-  GScanner *scanner = storage->scanner;
   BseDataPocketValue value;
   ObjectEntry *oentry = NULL;
   GQuark quark;
-  guint type;
+  guint ttype;
   gboolean char_2_token;
   
   parse_or_return (scanner, G_TOKEN_STRING);
@@ -580,15 +582,15 @@ parse_set_data (BseDataPocket *pocket,
   scanner->config->char_2_token = char_2_token;
   if (scanner->token != G_TOKEN_CHAR)
     return G_TOKEN_CHAR;
-  type = scanner->value.v_char;
+  ttype = scanner->value.v_char;
   
-  switch (type)
+  switch (ttype)
     {
       GTokenType token;
       gboolean negate;
     case BSE_DATA_POCKET_INT:
       parse_or_return (scanner, G_TOKEN_INT);
-      value.v_int = scanner->value.v_int;
+      value.v_int = scanner->value.v_int64;
       break;
     case BSE_DATA_POCKET_FLOAT:
       negate = g_scanner_peek_next_token (scanner) == '-';
@@ -600,10 +602,10 @@ parse_set_data (BseDataPocket *pocket,
     case BSE_DATA_POCKET_INT64:
       parse_or_return (scanner, G_TOKEN_INT);
       peek_or_return (scanner, G_TOKEN_INT);
-      value.v_int64 = scanner->value.v_int;
+      value.v_int64 = scanner->value.v_int64;
       value.v_int64 <<= 32;
       g_scanner_get_next_token (scanner); /* read next int */
-      value.v_int64 |= scanner->value.v_int & 0xffffffff;
+      value.v_int64 |= scanner->value.v_int64 & 0xffffffff;
       break;
     case BSE_DATA_POCKET_STRING:
       parse_or_return (scanner, G_TOKEN_STRING);
@@ -626,26 +628,26 @@ parse_set_data (BseDataPocket *pocket,
       /* unmatched data type */
       return bse_storage_warn_skip (storage,
 				    "invalid data type specification `%c' for \"%s\"",
-				    type,
+				    ttype,
 				    g_quark_to_string (quark));
     }
   peek_or_return (scanner, ')');
   
   /* caution, value might still point to scanner->value.v_string */
   if (!oentry)
-    _bse_data_pocket_entry_set (pocket, id, quark, type, value);
+    _bse_data_pocket_entry_set (pocket, id, quark, ttype, value);
   
   g_scanner_get_next_token (scanner); /* eat ')' */
   
   return G_TOKEN_NONE;
 }
 
-static BseTokenType
+static SfiTokenType
 bse_data_pocket_restore_private (BseObject  *object,
-				 BseStorage *storage)
+				 BseStorage *storage,
+                                 GScanner   *scanner)
 {
   BseDataPocket *pocket = BSE_DATA_POCKET (object);
-  GScanner *scanner = storage->scanner;
   GTokenType expected_token;
   
   /* support storage commands */
@@ -664,7 +666,7 @@ bse_data_pocket_restore_private (BseObject  *object,
 	      parse_or_return (scanner, G_TOKEN_IDENTIFIER);
 	      if (g_quark_try_string (scanner->value.v_identifier) == quark_set_data)
 		{
-		  expected_token = parse_set_data (pocket, id, storage);
+		  expected_token = parse_set_data (pocket, id, storage, scanner);
 		  if (expected_token != G_TOKEN_NONE)
 		    return expected_token;
 		}
@@ -678,7 +680,7 @@ bse_data_pocket_restore_private (BseObject  *object,
       expected_token = G_TOKEN_NONE;
     }
   else /* chain parent class' handler */
-    expected_token = BSE_OBJECT_CLASS (parent_class)->restore_private (object, storage);
+    expected_token = BSE_OBJECT_CLASS (parent_class)->restore_private (object, storage, scanner);
 
   return expected_token;
 }
