@@ -202,26 +202,9 @@ extern GType bse_type_builtin_id_BseMidiInput;
 /*-------- begin ../sfi/sfidl generated code --------*/
 
 
-typedef struct _BseIntSeq BseIntSeq;
-typedef struct _BseNoteSeq BseNoteSeq;
-typedef struct _BseStringSeq BseStringSeq;
-typedef struct _BseProxySeq BseProxySeq;
-typedef struct _BsePartNoteSeq BsePartNoteSeq;
-typedef struct _BsePartControlSeq BsePartControlSeq;
-typedef struct _BseCategorySeq BseCategorySeq;
-typedef struct _BseDotSeq BseDotSeq;
-typedef struct _BseTrackPartSeq BseTrackPartSeq;
-typedef struct _BsePartNote BsePartNote;
-typedef struct _BsePartControl BsePartControl;
-typedef struct _BseNoteDescription BseNoteDescription;
-typedef struct _BseNoteSequence BseNoteSequence;
-typedef struct _BseIcon BseIcon;
-typedef struct _BseCategory BseCategory;
-typedef struct _BseDot BseDot;
-typedef struct _BseTrackPart BseTrackPart;
-typedef struct _BseSongTiming BseSongTiming;
-typedef struct _BseSampleFileInfo BseSampleFileInfo;
-typedef struct _BseGConfig BseGConfig;
+
+
+/* enums */
 
 typedef enum {
   BSE_MIDI_SIGNAL_PROGRAM = 1,
@@ -400,6 +383,34 @@ typedef enum {
 const gchar* bse_midi_signal_type_to_choice (BseMidiSignalType value);
 BseMidiSignalType bse_midi_signal_type_from_choice (const gchar *choice);
 
+
+/* record typedefs */
+typedef struct _BsePartNote BsePartNote;
+typedef struct _BsePartControl BsePartControl;
+typedef struct _BseNoteDescription BseNoteDescription;
+typedef struct _BseNoteSequence BseNoteSequence;
+typedef struct _BseIcon BseIcon;
+typedef struct _BseCategory BseCategory;
+typedef struct _BseDot BseDot;
+typedef struct _BseTrackPart BseTrackPart;
+typedef struct _BseSongTiming BseSongTiming;
+typedef struct _BseSampleFileInfo BseSampleFileInfo;
+typedef struct _BseGConfig BseGConfig;
+
+
+/* sequence typedefs */
+typedef struct _BseIntSeq BseIntSeq;
+typedef struct _BseNoteSeq BseNoteSeq;
+typedef struct _BseStringSeq BseStringSeq;
+typedef struct _BseItemSeq BseItemSeq;
+typedef struct _BsePartNoteSeq BsePartNoteSeq;
+typedef struct _BsePartControlSeq BsePartControlSeq;
+typedef struct _BseCategorySeq BseCategorySeq;
+typedef struct _BseDotSeq BseDotSeq;
+typedef struct _BseTrackPartSeq BseTrackPartSeq;
+
+
+/* sequences */
 struct _BseIntSeq {
   guint n_ints;
   SfiInt* ints;
@@ -412,9 +423,9 @@ struct _BseStringSeq {
   guint n_strings;
   gchar** strings;
 };
-struct _BseProxySeq {
-  guint n_proxies;
-  SfiProxy* proxies;
+struct _BseItemSeq {
+  guint n_items;
+  SfiProxy* items;
 };
 struct _BsePartNoteSeq {
   guint n_pnotes;
@@ -436,8 +447,12 @@ struct _BseTrackPartSeq {
   guint n_tparts;
   BseTrackPart** tparts;
 };
+
+
+/* records */
 struct _BsePartNote {
   SfiInt id;
+  SfiInt channel;
   SfiInt tick;
   SfiInt duration;
   SfiInt note;
@@ -488,7 +503,7 @@ struct _BseDot {
 };
 struct _BseTrackPart {
   SfiInt tick;
-  SfiProxy part;
+  BsePart* part;
   SfiInt duration;
 };
 struct _BseSongTiming {
@@ -514,13 +529,97 @@ struct _BseGConfig {
   gchar* script_path;
   gchar* plugin_path;
   gchar* ladspa_path;
-  SfiInt synth_block_size;
+  SfiInt synth_latency;
   SfiInt synth_mixing_freq;
+  SfiInt synth_control_freq;
   SfiBool invert_sustain;
   SfiReal step_volume_dB;
   SfiInt step_bpm;
 };
 
+
+/* record functions */
+SfiRecFields bse_part_note_get_fields (void);
+BsePartNote* bse_part_note_new (void);
+BsePartNote* bse_part_note_copy_shallow (BsePartNote* rec);
+BsePartNote* bse_part_note_from_rec (SfiRec *sfi_rec);
+SfiRec *bse_part_note_to_rec (BsePartNote* rec);
+void bse_part_note_free (BsePartNote* rec);
+
+SfiRecFields bse_part_control_get_fields (void);
+BsePartControl* bse_part_control_new (void);
+BsePartControl* bse_part_control_copy_shallow (BsePartControl* rec);
+BsePartControl* bse_part_control_from_rec (SfiRec *sfi_rec);
+SfiRec *bse_part_control_to_rec (BsePartControl* rec);
+void bse_part_control_free (BsePartControl* rec);
+
+SfiRecFields bse_note_description_get_fields (void);
+BseNoteDescription* bse_note_description_new (void);
+BseNoteDescription* bse_note_description_copy_shallow (BseNoteDescription* rec);
+BseNoteDescription* bse_note_description_from_rec (SfiRec *sfi_rec);
+SfiRec *bse_note_description_to_rec (BseNoteDescription* rec);
+void bse_note_description_free (BseNoteDescription* rec);
+
+SfiRecFields bse_note_sequence_get_fields (void);
+BseNoteSequence* bse_note_sequence_new (void);
+BseNoteSequence* bse_note_sequence_copy_shallow (BseNoteSequence* rec);
+BseNoteSequence* bse_note_sequence_from_rec (SfiRec *sfi_rec);
+SfiRec *bse_note_sequence_to_rec (BseNoteSequence* rec);
+void bse_note_sequence_free (BseNoteSequence* rec);
+
+SfiRecFields bse_icon_get_fields (void);
+BseIcon* bse_icon_new (void);
+BseIcon* bse_icon_copy_shallow (BseIcon* rec);
+BseIcon* bse_icon_from_rec (SfiRec *sfi_rec);
+SfiRec *bse_icon_to_rec (BseIcon* rec);
+void bse_icon_free (BseIcon* rec);
+
+SfiRecFields bse_category_get_fields (void);
+BseCategory* bse_category_new (void);
+BseCategory* bse_category_copy_shallow (BseCategory* rec);
+BseCategory* bse_category_from_rec (SfiRec *sfi_rec);
+SfiRec *bse_category_to_rec (BseCategory* rec);
+void bse_category_free (BseCategory* rec);
+
+SfiRecFields bse_dot_get_fields (void);
+BseDot* bse_dot_new (void);
+BseDot* bse_dot_copy_shallow (BseDot* rec);
+BseDot* bse_dot_from_rec (SfiRec *sfi_rec);
+SfiRec *bse_dot_to_rec (BseDot* rec);
+void bse_dot_free (BseDot* rec);
+
+SfiRecFields bse_track_part_get_fields (void);
+BseTrackPart* bse_track_part_new (void);
+BseTrackPart* bse_track_part_copy_shallow (BseTrackPart* rec);
+BseTrackPart* bse_track_part_from_rec (SfiRec *sfi_rec);
+SfiRec *bse_track_part_to_rec (BseTrackPart* rec);
+void bse_track_part_free (BseTrackPart* rec);
+
+SfiRecFields bse_song_timing_get_fields (void);
+BseSongTiming* bse_song_timing_new (void);
+BseSongTiming* bse_song_timing_copy_shallow (BseSongTiming* rec);
+BseSongTiming* bse_song_timing_from_rec (SfiRec *sfi_rec);
+SfiRec *bse_song_timing_to_rec (BseSongTiming* rec);
+void bse_song_timing_free (BseSongTiming* rec);
+
+SfiRecFields bse_sample_file_info_get_fields (void);
+BseSampleFileInfo* bse_sample_file_info_new (void);
+BseSampleFileInfo* bse_sample_file_info_copy_shallow (BseSampleFileInfo* rec);
+BseSampleFileInfo* bse_sample_file_info_from_rec (SfiRec *sfi_rec);
+SfiRec *bse_sample_file_info_to_rec (BseSampleFileInfo* rec);
+void bse_sample_file_info_free (BseSampleFileInfo* rec);
+
+SfiRecFields bse_gconfig_get_fields (void);
+BseGConfig* bse_gconfig_new (void);
+BseGConfig* bse_gconfig_copy_shallow (BseGConfig* rec);
+BseGConfig* bse_gconfig_from_rec (SfiRec *sfi_rec);
+SfiRec *bse_gconfig_to_rec (BseGConfig* rec);
+void bse_gconfig_free (BseGConfig* rec);
+
+
+
+/* sequence functions */
+GParamSpec* bse_int_seq_get_element (void);
 BseIntSeq* bse_int_seq_new (void);
 void bse_int_seq_append (BseIntSeq* seq, SfiInt element);
 BseIntSeq* bse_int_seq_copy_shallow (BseIntSeq* seq);
@@ -529,6 +628,7 @@ SfiSeq *bse_int_seq_to_seq (BseIntSeq* seq);
 void bse_int_seq_resize (BseIntSeq* seq, guint new_size);
 void bse_int_seq_free (BseIntSeq* seq);
 
+GParamSpec* bse_note_seq_get_element (void);
 BseNoteSeq* bse_note_seq_new (void);
 void bse_note_seq_append (BseNoteSeq* seq, SfiInt element);
 BseNoteSeq* bse_note_seq_copy_shallow (BseNoteSeq* seq);
@@ -537,22 +637,25 @@ SfiSeq *bse_note_seq_to_seq (BseNoteSeq* seq);
 void bse_note_seq_resize (BseNoteSeq* seq, guint new_size);
 void bse_note_seq_free (BseNoteSeq* seq);
 
+GParamSpec* bse_string_seq_get_element (void);
 BseStringSeq* bse_string_seq_new (void);
-void bse_string_seq_append (BseStringSeq* seq, const gchar* element);
+void bse_string_seq_append (BseStringSeq* seq, const char* element);
 BseStringSeq* bse_string_seq_copy_shallow (BseStringSeq* seq);
 BseStringSeq* bse_string_seq_from_seq (SfiSeq *sfi_seq);
 SfiSeq *bse_string_seq_to_seq (BseStringSeq* seq);
 void bse_string_seq_resize (BseStringSeq* seq, guint new_size);
 void bse_string_seq_free (BseStringSeq* seq);
 
-BseProxySeq* bse_proxy_seq_new (void);
-void bse_proxy_seq_append (BseProxySeq* seq, SfiProxy element);
-BseProxySeq* bse_proxy_seq_copy_shallow (BseProxySeq* seq);
-BseProxySeq* bse_proxy_seq_from_seq (SfiSeq *sfi_seq);
-SfiSeq *bse_proxy_seq_to_seq (BseProxySeq* seq);
-void bse_proxy_seq_resize (BseProxySeq* seq, guint new_size);
-void bse_proxy_seq_free (BseProxySeq* seq);
+GParamSpec* bse_item_seq_get_element (void);
+BseItemSeq* bse_item_seq_new (void);
+void bse_item_seq_append (BseItemSeq* seq, BseItem* element);
+BseItemSeq* bse_item_seq_copy_shallow (BseItemSeq* seq);
+BseItemSeq* bse_item_seq_from_seq (SfiSeq *sfi_seq);
+SfiSeq *bse_item_seq_to_seq (BseItemSeq* seq);
+void bse_item_seq_resize (BseItemSeq* seq, guint new_size);
+void bse_item_seq_free (BseItemSeq* seq);
 
+GParamSpec* bse_part_note_seq_get_element (void);
 BsePartNoteSeq* bse_part_note_seq_new (void);
 void bse_part_note_seq_append (BsePartNoteSeq* seq, BsePartNote* element);
 BsePartNoteSeq* bse_part_note_seq_copy_shallow (BsePartNoteSeq* seq);
@@ -561,6 +664,7 @@ SfiSeq *bse_part_note_seq_to_seq (BsePartNoteSeq* seq);
 void bse_part_note_seq_resize (BsePartNoteSeq* seq, guint new_size);
 void bse_part_note_seq_free (BsePartNoteSeq* seq);
 
+GParamSpec* bse_part_control_seq_get_element (void);
 BsePartControlSeq* bse_part_control_seq_new (void);
 void bse_part_control_seq_append (BsePartControlSeq* seq, BsePartControl* element);
 BsePartControlSeq* bse_part_control_seq_copy_shallow (BsePartControlSeq* seq);
@@ -569,6 +673,7 @@ SfiSeq *bse_part_control_seq_to_seq (BsePartControlSeq* seq);
 void bse_part_control_seq_resize (BsePartControlSeq* seq, guint new_size);
 void bse_part_control_seq_free (BsePartControlSeq* seq);
 
+GParamSpec* bse_category_seq_get_element (void);
 BseCategorySeq* bse_category_seq_new (void);
 void bse_category_seq_append (BseCategorySeq* seq, BseCategory* element);
 BseCategorySeq* bse_category_seq_copy_shallow (BseCategorySeq* seq);
@@ -577,6 +682,7 @@ SfiSeq *bse_category_seq_to_seq (BseCategorySeq* seq);
 void bse_category_seq_resize (BseCategorySeq* seq, guint new_size);
 void bse_category_seq_free (BseCategorySeq* seq);
 
+GParamSpec* bse_dot_seq_get_element (void);
 BseDotSeq* bse_dot_seq_new (void);
 void bse_dot_seq_append (BseDotSeq* seq, BseDot* element);
 BseDotSeq* bse_dot_seq_copy_shallow (BseDotSeq* seq);
@@ -585,6 +691,7 @@ SfiSeq *bse_dot_seq_to_seq (BseDotSeq* seq);
 void bse_dot_seq_resize (BseDotSeq* seq, guint new_size);
 void bse_dot_seq_free (BseDotSeq* seq);
 
+GParamSpec* bse_track_part_seq_get_element (void);
 BseTrackPartSeq* bse_track_part_seq_new (void);
 void bse_track_part_seq_append (BseTrackPartSeq* seq, BseTrackPart* element);
 BseTrackPartSeq* bse_track_part_seq_copy_shallow (BseTrackPartSeq* seq);
@@ -593,108 +700,75 @@ SfiSeq *bse_track_part_seq_to_seq (BseTrackPartSeq* seq);
 void bse_track_part_seq_resize (BseTrackPartSeq* seq, guint new_size);
 void bse_track_part_seq_free (BseTrackPartSeq* seq);
 
-BsePartNote* bse_part_note_new (void);
-BsePartNote* bse_part_note_copy_shallow (BsePartNote* rec);
-BsePartNote* bse_part_note_from_rec (SfiRec *sfi_rec);
-SfiRec *bse_part_note_to_rec (BsePartNote* rec);
-void bse_part_note_free (BsePartNote* rec);
-
-BsePartControl* bse_part_control_new (void);
-BsePartControl* bse_part_control_copy_shallow (BsePartControl* rec);
-BsePartControl* bse_part_control_from_rec (SfiRec *sfi_rec);
-SfiRec *bse_part_control_to_rec (BsePartControl* rec);
-void bse_part_control_free (BsePartControl* rec);
-
-BseNoteDescription* bse_note_description_new (void);
-BseNoteDescription* bse_note_description_copy_shallow (BseNoteDescription* rec);
-BseNoteDescription* bse_note_description_from_rec (SfiRec *sfi_rec);
-SfiRec *bse_note_description_to_rec (BseNoteDescription* rec);
-void bse_note_description_free (BseNoteDescription* rec);
-
-BseNoteSequence* bse_note_sequence_new (void);
-BseNoteSequence* bse_note_sequence_copy_shallow (BseNoteSequence* rec);
-BseNoteSequence* bse_note_sequence_from_rec (SfiRec *sfi_rec);
-SfiRec *bse_note_sequence_to_rec (BseNoteSequence* rec);
-void bse_note_sequence_free (BseNoteSequence* rec);
-
-BseIcon* bse_icon_new (void);
-BseIcon* bse_icon_copy_shallow (BseIcon* rec);
-BseIcon* bse_icon_from_rec (SfiRec *sfi_rec);
-SfiRec *bse_icon_to_rec (BseIcon* rec);
-void bse_icon_free (BseIcon* rec);
-
-BseCategory* bse_category_new (void);
-BseCategory* bse_category_copy_shallow (BseCategory* rec);
-BseCategory* bse_category_from_rec (SfiRec *sfi_rec);
-SfiRec *bse_category_to_rec (BseCategory* rec);
-void bse_category_free (BseCategory* rec);
-
-BseDot* bse_dot_new (void);
-BseDot* bse_dot_copy_shallow (BseDot* rec);
-BseDot* bse_dot_from_rec (SfiRec *sfi_rec);
-SfiRec *bse_dot_to_rec (BseDot* rec);
-void bse_dot_free (BseDot* rec);
-
-BseTrackPart* bse_track_part_new (void);
-BseTrackPart* bse_track_part_copy_shallow (BseTrackPart* rec);
-BseTrackPart* bse_track_part_from_rec (SfiRec *sfi_rec);
-SfiRec *bse_track_part_to_rec (BseTrackPart* rec);
-void bse_track_part_free (BseTrackPart* rec);
-
-BseSongTiming* bse_song_timing_new (void);
-BseSongTiming* bse_song_timing_copy_shallow (BseSongTiming* rec);
-BseSongTiming* bse_song_timing_from_rec (SfiRec *sfi_rec);
-SfiRec *bse_song_timing_to_rec (BseSongTiming* rec);
-void bse_song_timing_free (BseSongTiming* rec);
-
-BseSampleFileInfo* bse_sample_file_info_new (void);
-BseSampleFileInfo* bse_sample_file_info_copy_shallow (BseSampleFileInfo* rec);
-BseSampleFileInfo* bse_sample_file_info_from_rec (SfiRec *sfi_rec);
-SfiRec *bse_sample_file_info_to_rec (BseSampleFileInfo* rec);
-void bse_sample_file_info_free (BseSampleFileInfo* rec);
-
-BseGConfig* bse_gconfig_new (void);
-BseGConfig* bse_gconfig_copy_shallow (BseGConfig* rec);
-BseGConfig* bse_gconfig_from_rec (SfiRec *sfi_rec);
-SfiRec *bse_gconfig_to_rec (BseGConfig* rec);
-void bse_gconfig_free (BseGConfig* rec);
 
 
-extern SfiChoiceValues bse_midi_signal_type_values;
-extern GType BSE_TYPE_MIDI_SIGNAL_TYPE;
-extern SfiRecFields bse_part_note_fields;
-extern GType BSE_TYPE_PART_NOTE;
-extern SfiRecFields bse_part_control_fields;
-extern GType BSE_TYPE_PART_CONTROL;
-extern SfiRecFields bse_note_description_fields;
-extern GType BSE_TYPE_NOTE_DESCRIPTION;
-extern SfiRecFields bse_note_sequence_fields;
-extern GType BSE_TYPE_NOTE_SEQUENCE;
-extern SfiRecFields bse_icon_fields;
-extern GType BSE_TYPE_ICON;
-extern SfiRecFields bse_category_fields;
-extern GType BSE_TYPE_CATEGORY;
-extern SfiRecFields bse_dot_fields;
-extern GType BSE_TYPE_DOT;
-extern SfiRecFields bse_track_part_fields;
-extern GType BSE_TYPE_TRACK_PART;
-extern SfiRecFields bse_song_timing_fields;
-extern GType BSE_TYPE_SONG_TIMING;
-extern SfiRecFields bse_sample_file_info_fields;
-extern GType BSE_TYPE_SAMPLE_FILE_INFO;
-extern SfiRecFields bse_gconfig_fields;
-extern GType BSE_TYPE_GCONFIG;
-extern GType BSE_TYPE_INT_SEQ;
-extern GType BSE_TYPE_NOTE_SEQ;
-extern GType BSE_TYPE_STRING_SEQ;
-extern GType BSE_TYPE_PROXY_SEQ;
-extern GType BSE_TYPE_PART_NOTE_SEQ;
-extern GType BSE_TYPE_PART_CONTROL_SEQ;
-extern GType BSE_TYPE_CATEGORY_SEQ;
-extern GType BSE_TYPE_DOT_SEQ;
-extern GType BSE_TYPE_TRACK_PART_SEQ;
+/* enum functions */
+const SfiChoiceValues bse_midi_signal_type_get_values (void);
 
 
+/* enum type ids */
+extern GType bse__type_id__midi_signal_type;
+
+
+/* record type ids */
+extern GType bse__type_id__part_note;
+extern GType bse__type_id__part_control;
+extern GType bse__type_id__note_description;
+extern GType bse__type_id__note_sequence;
+extern GType bse__type_id__icon;
+extern GType bse__type_id__category;
+extern GType bse__type_id__dot;
+extern GType bse__type_id__track_part;
+extern GType bse__type_id__song_timing;
+extern GType bse__type_id__sample_file_info;
+extern GType bse__type_id__gconfig;
+
+
+/* sequence type ids */
+extern GType bse__type_id__int_seq;
+extern GType bse__type_id__note_seq;
+extern GType bse__type_id__string_seq;
+extern GType bse__type_id__item_seq;
+extern GType bse__type_id__part_note_seq;
+extern GType bse__type_id__part_control_seq;
+extern GType bse__type_id__category_seq;
+extern GType bse__type_id__dot_seq;
+extern GType bse__type_id__track_part_seq;
+
+#ifndef __cplusplus
+
+
+/* enum type macros */
+#define BSE_TYPE_MIDI_SIGNAL_TYPE		(bse__type_id__midi_signal_type)
+
+
+/* record type macros */
+#define BSE_TYPE_PART_NOTE		(bse__type_id__part_note)
+#define BSE_TYPE_PART_CONTROL		(bse__type_id__part_control)
+#define BSE_TYPE_NOTE_DESCRIPTION		(bse__type_id__note_description)
+#define BSE_TYPE_NOTE_SEQUENCE		(bse__type_id__note_sequence)
+#define BSE_TYPE_ICON		(bse__type_id__icon)
+#define BSE_TYPE_CATEGORY		(bse__type_id__category)
+#define BSE_TYPE_DOT		(bse__type_id__dot)
+#define BSE_TYPE_TRACK_PART		(bse__type_id__track_part)
+#define BSE_TYPE_SONG_TIMING		(bse__type_id__song_timing)
+#define BSE_TYPE_SAMPLE_FILE_INFO		(bse__type_id__sample_file_info)
+#define BSE_TYPE_GCONFIG		(bse__type_id__gconfig)
+
+
+/* sequence type macros */
+#define BSE_TYPE_INT_SEQ		(bse__type_id__int_seq)
+#define BSE_TYPE_NOTE_SEQ		(bse__type_id__note_seq)
+#define BSE_TYPE_STRING_SEQ		(bse__type_id__string_seq)
+#define BSE_TYPE_ITEM_SEQ		(bse__type_id__item_seq)
+#define BSE_TYPE_PART_NOTE_SEQ		(bse__type_id__part_note_seq)
+#define BSE_TYPE_PART_CONTROL_SEQ		(bse__type_id__part_control_seq)
+#define BSE_TYPE_CATEGORY_SEQ		(bse__type_id__category_seq)
+#define BSE_TYPE_DOT_SEQ		(bse__type_id__dot_seq)
+#define BSE_TYPE_TRACK_PART_SEQ		(bse__type_id__track_part_seq)
+
+#endif
+
 /*-------- end ../sfi/sfidl generated code --------*/
 
 
