@@ -644,22 +644,22 @@ check_is_a_exec (BseProcedureClass *proc,
   return BSE_ERROR_NONE;
 }
 
-/* --- list-proxies --- */
+/* --- list-items --- */
 static void
-list_proxies_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+list_items_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 456 "bseitem.proc"
  {
 #line 458 "bseitem.proc"
   *(in_pspecs++) = bse_param_spec_object ("item", NULL, NULL,
 				 BSE_TYPE_ITEM, SFI_PARAM_STANDARD);
-  *(in_pspecs++) = sfi_pspec_string ("property_name", NULL, "Proxy property name",
+  *(in_pspecs++) = sfi_pspec_string ("property_name", NULL, "Item property name",
 			    NULL, SFI_PARAM_STANDARD);
-  *(out_pspecs++) = bse_param_spec_boxed ("proxy_list", "Proxy List", NULL, BSE_TYPE_PROXY_SEQ, SFI_PARAM_STANDARD);
+  *(out_pspecs++) = bse_param_spec_boxed ("item_list", "Item List", NULL, BSE_TYPE_ITEM_SEQ, SFI_PARAM_STANDARD);
 #line 463 "bseitem.proc"
 }  }
 static BseErrorType
 #line 463 "bseitem.proc"
-list_proxies_exec (BseProcedureClass *proc,
+list_items_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
 #line 466 "bseitem.proc"
@@ -676,7 +676,7 @@ list_proxies_exec (BseProcedureClass *proc,
   
 #line 475 "bseitem.proc"
   
-  bse_value_take_boxed (out_values++, bse_item_list_proxies (self, property));
+  bse_value_take_boxed (out_values++, bse_item_list_items (self, property));
   
   return BSE_ERROR_NONE;
 }
@@ -1234,19 +1234,19 @@ static BseExportNodeProc __enode_check_is_a = {
   },
   0, check_is_a_setup, check_is_a_exec, 
 };
-static BseExportNodeProc __enode_list_proxies = {
+static BseExportNodeProc __enode_list_items = {
   { (BseExportNode*) &__enode_check_is_a, BSE_EXPORT_NODE_PROC,
-    "BseItem+list-proxies", 
+    "BseItem+list-items", 
     NULL,
-    "/Methods/BseItem/General/List Proxies",
-    "List possible values for a proxy property of an item.",
+    "/Methods/BseItem/General/List Items",
+    "List possible values for an item property of an item.",
     "Tim Janik <timj@gtk.org>",
     "GNU Lesser General Public License",
   },
-  0, list_proxies_setup, list_proxies_exec, 
+  0, list_items_setup, list_items_exec, 
 };
 static BseExportNodeProc __enode_get_icon = {
-  { (BseExportNode*) &__enode_list_proxies, BSE_EXPORT_NODE_PROC,
+  { (BseExportNode*) &__enode_list_items, BSE_EXPORT_NODE_PROC,
     "BseItem+get-icon", 
     NULL,
     "/Methods/BseItem/General/Get Icon",
