@@ -28,6 +28,8 @@
 #include <string.h>
 #include <stdlib.h>
 #include <sys/time.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 
 /* --- prototypes --- */
@@ -38,11 +40,6 @@ static void	bse_async_parse_args	(gint	       *argc_p,
 
 
 /* --- variables --- */
-GMainContext            *bse_main_context = NULL;
-SfiMutex	         bse_main_sequencer_mutex = { 0, };
-gboolean	         bse_main_debug_extensions = FALSE;
-SfiThread               *bse_main_thread = NULL;
-static volatile gboolean bse_initialization_stage = 0;
 /* from bse.h */
 const guint		 bse_major_version = BSE_MAJOR_VERSION;
 const guint		 bse_minor_version = BSE_MINOR_VERSION;
@@ -50,9 +47,26 @@ const guint		 bse_micro_version = BSE_MICRO_VERSION;
 const guint		 bse_interface_age = BSE_INTERFACE_AGE;
 const guint		 bse_binary_age = BSE_BINARY_AGE;
 const gchar		*bse_version = BSE_VERSION;
+GMainContext            *bse_main_context = NULL;
+SfiMutex	         bse_main_sequencer_mutex = { 0, };
+gboolean	         bse_main_debug_extensions = FALSE;
+SfiThread               *bse_main_thread = NULL;
+static volatile gboolean bse_initialization_stage = 0;
+static gboolean          textdomain_setup = FALSE;
 
 
 /* --- functions --- */
+const gchar*
+bse_gettext (const gchar *text)
+{
+#if 0
+  g_assert (textdomain_setup == TRUE);
+  if (textdomain_setup != TRUE)
+    g_warning ("assertion failed: %s", "textdomain_setup == TRUE");
+#endif
+  return dgettext (BSE_GETTEXT_DOMAIN, text);
+}
+
 void
 bse_init_async (gint    *argc,
 		gchar ***argv,
@@ -68,7 +82,8 @@ bse_init_async (gint    *argc,
 
   bindtextdomain (BSE_GETTEXT_DOMAIN, BST_PATH_LOCALE);
   bind_textdomain_codeset (BSE_GETTEXT_DOMAIN, "UTF-8");
-  
+  textdomain_setup = TRUE;
+
   /* this function is running in the user thread and needs to start the main BSE thread */
   
   /* initialize submodules */
@@ -217,6 +232,9 @@ bse_init_core (void)
   /* remaining BSE components */
   _bse_midi_init ();
   bse_plugin_init_builtins ();
+  /* initialize C wrappers around C++ generated types */
+  _bse_init_c_wrappers ();
+
   /* make sure the server is alive */
   bse_server_get ();
 }
@@ -235,7 +253,8 @@ bse_init_intern (gint    *argc,
 
   bindtextdomain (BSE_GETTEXT_DOMAIN, BST_PATH_LOCALE);
   bind_textdomain_codeset (BSE_GETTEXT_DOMAIN, "UTF-8");
-
+  textdomain_setup = TRUE;
+  
   /* initialize submodules */
   sfi_init ();
   if (!config)
@@ -277,9 +296,9 @@ bse_main_loop (gpointer data)
   bse_main_thread = sfi_thread_self ();
 
   bse_init_core ();
-  
+
   /* notify client about completion */
-  bse_initialization_stage++;
+  bse_initialization_stage++;   /* =2 */
   sfi_thread_wakeup (client);
 
   /* start other threads */
@@ -294,6 +313,15 @@ bse_main_loop (gpointer data)
   while (!sfi_thread_aborted ());
 }
 
+guint
+bse_main_getpid (void)
+{
+  if (bse_initialization_stage >= 2)
+    return sfi_thread_self_pid ();
+  else
+    return 0;
+}
+
 static void
 bse_async_parse_args (gint    *argc_p,
 		      gchar ***argv_p,
