@@ -113,39 +113,39 @@ bse_midi_controller_class_init (BseMidiControllerClass *class)
                               sfi_pspec_int ("midi_channel", "MIDI Channel",
                                              "Input MIDI channel, 0 uses network's default channel",
                                              0, 0, BSE_MIDI_MAX_CHANNELS, 1,
-					     SFI_PARAM_GUI SFI_PARAM_STORAGE ":scale"));
+					     SFI_PARAM_GUI SFI_PARAM_STORAGE ":scale:skip-default"));
   bse_object_class_add_param (object_class, "MIDI Controls",
 			      PROP_CONTROL_1,
 			      bse_param_spec_genum ("control_1", "Signal 1", NULL,
 						    BSE_TYPE_MIDI_SIGNAL_TYPE,
 						    BSE_MIDI_SIGNAL_PITCH_BEND,
-						    SFI_PARAM_DEFAULT));
+						    SFI_PARAM_STANDARD));
   bse_object_class_add_param (object_class, "MIDI Controls",
 			      PROP_CONTROL_2,
 			      bse_param_spec_genum ("control_2", "Signal 2", NULL,
 						    BSE_TYPE_MIDI_SIGNAL_TYPE,
 						    BSE_MIDI_SIGNAL_CONTINUOUS_1,
-						    SFI_PARAM_DEFAULT));
+						    SFI_PARAM_STANDARD));
   bse_object_class_add_param (object_class, "MIDI Controls",
 			      PROP_CONTROL_3,
 			      bse_param_spec_genum ("control_3", "Signal 3", NULL,
 						    BSE_TYPE_MIDI_SIGNAL_TYPE,
 						    BSE_MIDI_SIGNAL_CONTINUOUS_7,
-						    SFI_PARAM_DEFAULT));
+						    SFI_PARAM_STANDARD));
   bse_object_class_add_param (object_class, "MIDI Controls",
 			      PROP_CONTROL_4,
 			      bse_param_spec_genum ("control_4", "Signal 4", NULL,
 						    BSE_TYPE_MIDI_SIGNAL_TYPE,
 						    BSE_MIDI_SIGNAL_PRESSURE,
-						    SFI_PARAM_DEFAULT));
+						    SFI_PARAM_STANDARD));
   
-  ochannel_id = bse_source_class_add_ochannel (source_class, "Ctrl Out1", "MIDI Signal 1");
+  ochannel_id = bse_source_class_add_ochannel (source_class, "ctrl-out1", _("Ctrl Out1"), _("MIDI Signal 1"));
   g_assert (ochannel_id == BSE_MIDI_CONTROLLER_OCHANNEL_CONTROL1);
-  ochannel_id = bse_source_class_add_ochannel (source_class, "Ctrl Out2", "MIDI Signal 2");
+  ochannel_id = bse_source_class_add_ochannel (source_class, "ctrl-out2", _("Ctrl Out2"), _("MIDI Signal 2"));
   g_assert (ochannel_id == BSE_MIDI_CONTROLLER_OCHANNEL_CONTROL2);
-  ochannel_id = bse_source_class_add_ochannel (source_class, "Ctrl Out3", "MIDI Signal 3");
+  ochannel_id = bse_source_class_add_ochannel (source_class, "ctrl-out3", _("Ctrl Out3"), _("MIDI Signal 3"));
   g_assert (ochannel_id == BSE_MIDI_CONTROLLER_OCHANNEL_CONTROL3);
-  ochannel_id = bse_source_class_add_ochannel (source_class, "Ctrl Out4", "MIDI Signal 4");
+  ochannel_id = bse_source_class_add_ochannel (source_class, "ctrl-out4", _("Ctrl Out4"), _("MIDI Signal 4"));
   g_assert (ochannel_id == BSE_MIDI_CONTROLLER_OCHANNEL_CONTROL4);
 }
 
