@@ -19,16 +19,10 @@ current_time_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 29 "bsemidinotifier.proc"
   *(in_pspecs++) = bse_param_spec_object ("midi_notifier", "Midi Notifier", NULL,
-				 BSE_TYPE_MIDI_NOTIFIER, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_MIDI_NOTIFIER, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_int ("msec_time", "Time [ms]", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
 }
-#line 28 "bsemidinotifier.proc"
-  proc->help = "Test";
-#line 23 "bsemidinotifier.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsemidinotifier.proc"
-  proc->license = "GNU General Public License";
 #line 34 "bsemidinotifier.proc"
  }
 static BseErrorType
@@ -63,7 +57,13 @@ current_time_exec (BseProcedureClass *proc,
 /* --- Export to BSE --- */
 static BseExportNodeProc __enode_current_time = {
   { NULL, BSE_EXPORT_NODE_PROC,
-    "BseMidiNotifier+current-time", "/Methods/BseMidiNotifier/General/Current Time", NULL },
+    "BseMidiNotifier+current-time", 
+    NULL,
+    "/Methods/BseMidiNotifier/General/Current Time",
+    "Test",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, current_time_setup, current_time_exec, 
 };
 BseExportNode* bse__builtin_init_bsemidinotifier_gen_proc_c (void);
