@@ -323,7 +323,7 @@ change_midi_control_modules (GSList           *modules,
 					       tick_stamp,
 					       midi_control_module_access,
 					       adata,
-					       slist->next ? NULL : g_free));
+					       slist->next ? NULL : (GslReplyFunc) g_free));
 }
 
 static gboolean
@@ -516,7 +516,7 @@ change_voice_input (VoiceInput      *vinput,
   
   gsl_trans_add (trans, gsl_job_flow_access (vinput->fmodule, tick_stamp,
 					     voice_input_module_access,
-					     g_memdup (&mdata, sizeof (mdata)), g_free));
+					     g_memdup (&mdata, sizeof (mdata)), (GslReplyFunc) g_free));
   switch (mdata.vtype)
     {
     case VOICE_ON:
@@ -525,9 +525,11 @@ change_voice_input (VoiceInput      *vinput,
           g_assert (vinput->iter == table->end());
           vinput->next = (*table)[freq_value];
           vinput->iter = table->find (freq_value);
+          g_assert (vinput->iter != table->end());
           vinput->iter->second = vinput;
         }
       vinput->queue_state = VSTATE_BUSY;
+      break;
     case VOICE_PRESSURE:
       if (table)
         g_assert (vinput->iter != table->end());
@@ -696,8 +698,8 @@ voice_switch_module_free (gpointer        data,
 {
   VoiceSwitch *voice = (VoiceSwitch*) data;
   
-  g_free (voice);
   g_free (voice->vinputs);
+  g_free (voice);
 }
 
 static VoiceSwitch*
