@@ -407,6 +407,7 @@ queue_control_update (BsePart *self,
 
 void
 bse_part_select_notes (BsePart *self,
+                       guint    match_channel,
                        guint    tick,
                        guint    duration,
                        gint     min_note,
@@ -421,8 +422,11 @@ bse_part_select_notes (BsePart *self,
   max_note = BSE_NOTE_CLAMP (max_note);
   for (channel = 0; channel < self->n_channels; channel++)
     {
-      BsePartEventNote *note = bse_part_note_channel_lookup_ge (&self->channels[channel], tick);
-      BsePartEventNote *last = bse_part_note_channel_lookup_lt (&self->channels[channel], tick + duration);
+      BsePartEventNote *note, *last;
+      if (channel != match_channel && match_channel != ~0)
+        continue;
+      note = bse_part_note_channel_lookup_ge (&self->channels[channel], tick);
+      last = bse_part_note_channel_lookup_lt (&self->channels[channel], tick + duration);
       if (!note)
         continue;
       while (note <= last)
@@ -452,7 +456,7 @@ bse_part_select_controls (BsePart          *self,
 
   if (BSE_PART_NOTE_CONTROL (ctype))
     {
-      bse_part_select_notes (self, tick, duration, BSE_MIN_NOTE, BSE_MAX_NOTE, selected);
+      bse_part_select_notes (self, ~0, tick, duration, BSE_MIN_NOTE, BSE_MAX_NOTE, selected);
       return;
     }
 
@@ -475,6 +479,7 @@ bse_part_select_controls (BsePart          *self,
 
 void
 bse_part_select_notes_exclusive (BsePart *self,
+                                 guint    match_channel,
                                  guint    tick,
                                  guint    duration,
                                  gint     min_note,
@@ -493,7 +498,8 @@ bse_part_select_notes_exclusive (BsePart *self,
       while (note < nbound)
         {
           gboolean selected = (note->tick >= tick && note->tick < tick + duration &&
-                               note->note >= min_note && note->note <= max_note);
+                               note->note >= min_note && note->note <= max_note &&
+                               (channel == match_channel || match_channel == ~0));
           if (note->selected != selected)
             {
               bse_part_note_channel_change_note (&self->channels[channel], note, note->id, selected,
@@ -534,11 +540,11 @@ bse_part_select_controls_exclusive (BsePart           *self,
 
   if (BSE_PART_NOTE_CONTROL (ctype))
     {
-      bse_part_select_notes_exclusive (self, tick, duration, BSE_MIN_NOTE, BSE_MAX_NOTE);
+      bse_part_select_notes_exclusive (self, ~0, tick, duration, BSE_MIN_NOTE, BSE_MAX_NOTE);
       return;
     }
 
-  bse_part_select_notes (self, 0, BSE_PART_MAX_TICK, BSE_MIN_NOTE, BSE_MAX_NOTE, FALSE);
+  bse_part_select_notes (self, ~0, 0, BSE_PART_MAX_TICK, BSE_MIN_NOTE, BSE_MAX_NOTE, FALSE);
 
   node = bse_part_controls_lookup_ge (&self->controls, 0);
   if (!node)
@@ -684,8 +690,10 @@ bse_part_insert_note (BsePart *self,
   g_return_val_if_fail (BSE_IS_PART (self), BSE_ERROR_INTERNAL);
   if (use_any_channel)
     channel = 0;
+  else if (channel >= self->n_channels)
+    g_object_set (self, "n_channels", channel + 1, NULL);
 
-  if (!(BSE_NOTE_IS_VALID (note) && channel < self->n_channels &&
+  if (!(BSE_NOTE_IS_VALID (note) &&
 	BSE_FINE_TUNE_IS_VALID (fine_tune) &&
 	tick < BSE_PART_MAX_TICK &&
 	duration > 0 &&
@@ -1029,9 +1037,11 @@ bse_part_query_event (BsePart           *self,
 
 static void
 part_note_seq_append (BsePartNoteSeq   *pseq,
+                      guint             channel,
                       BsePartEventNote *note)
 {
   BsePartNote *pnote = bse_part_note (note->id,
+                                      channel,
                                       note->tick,
                                       note->duration,
                                       note->note,
@@ -1055,11 +1065,13 @@ part_control_seq_append_note (BsePartControlSeq *cseq,
 }
 
 BsePartNoteSeq*
-bse_part_list_notes_crossing (BsePart *self,
-                              guint    tick,
-                              guint    duration,
-                              gint     min_note,
-                              gint     max_note)
+bse_part_list_notes (BsePart *self,
+                     guint    match_channel,
+                     guint    tick,
+                     guint    duration,
+                     gint     min_note,
+                     gint     max_note,
+                     gboolean include_crossings)
 {
   BsePartEventNote *bound, *note;
   BsePartNoteSeq *pseq;
@@ -1073,9 +1085,12 @@ bse_part_list_notes_crossing (BsePart *self,
   pseq = bse_part_note_seq_new ();
   for (channel = 0; channel < self->n_channels; channel++)
     {
-      SfiUPool *tickpool = sfi_upool_new ();
+      SfiUPool *tickpool;
+      if (channel != match_channel && match_channel != ~0)
+        continue;
+      tickpool = sfi_upool_new ();
       /* gather notes spanning across tick */
-      note = bse_part_note_channel_lookup_le (&self->channels[channel], tick);
+      note = include_crossings ? bse_part_note_channel_lookup_lt (&self->channels[channel], tick) : NULL;
       if (note)
         for (j = 0; j < BSE_PART_NOTE_N_CROSSINGS (note); j++)
           {
@@ -1085,7 +1100,7 @@ bse_part_list_notes_crossing (BsePart *self,
                 xnote->note >= min_note && xnote->note <= max_note)
               sfi_upool_set (tickpool, xnote->tick);
           }
-      if (note && note->tick + note->duration > tick &&
+      if (note && note->tick + note->duration > tick && include_crossings &&
           note->note >= min_note && note->note <= max_note)
         sfi_upool_set (tickpool, note->tick);
       /* gather notes starting during duration */
@@ -1099,19 +1114,20 @@ bse_part_list_notes_crossing (BsePart *self,
         }
       /* add notes to sequence */
       ids = sfi_upool_list (tickpool, &n);
+      sfi_upool_destroy (tickpool);
       for (j = 0; j < n; j++)
         {
           note = bse_part_note_channel_lookup (&self->channels[channel], ids[j]);
-          part_note_seq_append (pseq, note);
+          part_note_seq_append (pseq, channel, note);
         }
       g_free (ids);
-      sfi_upool_destroy (tickpool);
     }
   return pseq;
 }
 
 BsePartControlSeq*
 bse_part_list_controls (BsePart          *self,
+                        guint             match_channel, /* for note events */
                         guint             tick,
                         guint             duration,
                         BseMidiSignalType ctype)
@@ -1132,6 +1148,8 @@ bse_part_list_controls (BsePart          *self,
           BsePartEventNote *last = bse_part_note_channel_lookup_lt (&self->channels[channel], tick + duration);
           if (!note)
             continue;
+          if (channel != match_channel && match_channel != ~0)
+            continue;
           while (note <= last)
             {
               part_control_seq_append_note (cseq, note, ctype);
@@ -1217,7 +1235,7 @@ bse_part_list_selected_notes (BsePart *self)
       while (note < bound)
         {
           if (note->selected)
-            part_note_seq_append (pseq, note);
+            part_note_seq_append (pseq, channel, note);
           note++;
         }
     }
@@ -1369,7 +1387,7 @@ bse_part_restore_private (BseObject  *object,
       guint channel;
       parse_or_return (scanner, G_TOKEN_IDENTIFIER);	/* eat identifier */
       parse_or_return (scanner, G_TOKEN_INT);           /* channel */
-      channel = scanner->value.v_int;
+      channel = scanner->value.v_int64;
       if (channel >= self->n_channels)
         return bse_storage_warn_skip (storage, "ignoring notes with invalid channel: %u", channel);
       while (g_scanner_peek_next_token (scanner) != ')')
@@ -1379,16 +1397,16 @@ bse_part_restore_private (BseObject  *object,
           gboolean negate;
           parse_or_return (scanner, '(');
           parse_or_return (scanner, G_TOKEN_INT);       /* tick */
-          tick = scanner->value.v_int;
+          tick = scanner->value.v_int64;
           parse_or_return (scanner, G_TOKEN_INT);       /* duration */
-          duration = scanner->value.v_int;
+          duration = scanner->value.v_int64;
           parse_or_return (scanner, G_TOKEN_INT);       /* note */
-          note = scanner->value.v_int;
+          note = scanner->value.v_int64;
           negate = bse_storage_check_parse_negate (storage);
           if (g_scanner_peek_next_token (scanner) == G_TOKEN_INT)
             {
               g_scanner_get_next_token (scanner);       /* fine_tune */
-              fine_tune = negate ? -scanner->value.v_int : scanner->value.v_int;
+              fine_tune = negate ? -scanner->value.v_int64 : scanner->value.v_int64;
               negate = bse_storage_check_parse_negate (storage);
               if (g_scanner_peek_next_token (scanner) == G_TOKEN_FLOAT)
                 {
@@ -1415,14 +1433,14 @@ bse_part_restore_private (BseObject  *object,
           GError *error = NULL;
           parse_or_return (scanner, '(');
           parse_or_return (scanner, G_TOKEN_INT);       /* tick */
-          tick = scanner->value.v_int;
+          tick = scanner->value.v_int64;
           parse_or_return (scanner, G_TOKEN_IDENTIFIER); /* type */
           ctype = sfi_choice2enum_checked (scanner->value.v_identifier, BSE_TYPE_MIDI_SIGNAL_TYPE, &error);
           negate = bse_storage_check_parse_negate (storage);
           if (g_scanner_peek_next_token (scanner) == G_TOKEN_INT)
             {
               g_scanner_get_next_token (scanner);       /* value as int */
-              value = negate ? -scanner->value.v_int : scanner->value.v_int;
+              value = negate ? -scanner->value.v_int64 : scanner->value.v_int64;
             }
           else if (g_scanner_peek_next_token (scanner) == G_TOKEN_FLOAT)
             {
@@ -1454,16 +1472,16 @@ bse_part_restore_private (BseObject  *object,
 
       parse_or_return (scanner, G_TOKEN_IDENTIFIER);	/* eat identifier */
       parse_or_return (scanner, G_TOKEN_INT);
-      tick = scanner->value.v_int;
+      tick = scanner->value.v_int64;
       parse_or_return (scanner, G_TOKEN_INT);
-      duration = scanner->value.v_int;
+      duration = scanner->value.v_int64;
       parse_or_return (scanner, G_TOKEN_INT);
-      note = scanner->value.v_int;
+      note = scanner->value.v_int64;
       negate = bse_storage_check_parse_negate (storage);
       if (g_scanner_peek_next_token (scanner) == G_TOKEN_INT)
 	{
 	  g_scanner_get_next_token (scanner);		/* eat int */
-	  fine_tune = negate ? -scanner->value.v_int : scanner->value.v_int;
+	  fine_tune = negate ? -scanner->value.v_int64 : scanner->value.v_int64;
           negate = bse_storage_check_parse_negate (storage);
 	  if (g_scanner_peek_next_token (scanner) == G_TOKEN_FLOAT)
 	    {
@@ -1486,14 +1504,14 @@ bse_part_restore_private (BseObject  *object,
 
       parse_or_return (scanner, G_TOKEN_IDENTIFIER);	/* eat identifier */
       parse_or_return (scanner, G_TOKEN_INT);
-      tick = scanner->value.v_int;
+      tick = scanner->value.v_int64;
       parse_or_return (scanner, G_TOKEN_IDENTIFIER);
       ctype = sfi_choice2enum (scanner->value.v_identifier, BSE_TYPE_MIDI_SIGNAL_TYPE);
       negate = bse_storage_check_parse_negate (storage);
       if (g_scanner_peek_next_token (scanner) == G_TOKEN_INT)
 	{
 	  g_scanner_get_next_token (scanner);		/* eat int */
-	  value = negate ? -scanner->value.v_int : scanner->value.v_int;
+	  value = negate ? -scanner->value.v_int64 : scanner->value.v_int64;
         }
       else if (g_scanner_peek_next_token (scanner) == G_TOKEN_FLOAT)
         {
