@@ -507,7 +507,52 @@ list_notes_crossing_exec (BseProcedureClass *proc,
   
 #line 418 "bsepart.proc"
   
-  bse_value_take_boxed (out_values++, bse_part_list_notes_crossing (self, tick, duration, BSE_MIN_NOTE, BSE_MAX_NOTE));
+  bse_value_take_boxed (out_values++, bse_part_list_notes (self, ~0, tick, duration, BSE_MIN_NOTE, BSE_MAX_NOTE, TRUE));
+  
+  return BSE_ERROR_NONE;
+}
+
+/* --- list-notes-within --- */
+static void
+list_notes_within_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 424 "bsepart.proc"
+ {
+#line 426 "bsepart.proc"
+  *(in_pspecs++) = bse_param_spec_object ("part", "Part", NULL,
+				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
+  *(in_pspecs++) = sfi_pspec_int ("channel", "Channel", NULL,
+			 0, 0, BSE_PART_MAX_CHANNELS, 4, SFI_PARAM_STANDARD);
+  *(in_pspecs++) = sfi_pspec_int ("tick", "Start Tick", NULL,
+			 0, 0, BSE_PART_MAX_TICK - 1, 384, SFI_PARAM_STANDARD);
+  *(in_pspecs++) = sfi_pspec_int ("duration", "Tick Duration", NULL,
+			 1, 1, BSE_PART_MAX_TICK, 384, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = bse_param_spec_boxed ("note_list", "Note List", NULL,
+				BSE_TYPE_PART_NOTE_SEQ, SFI_PARAM_STANDARD);
+}
+#line 437 "bsepart.proc"
+ }
+static BseErrorType
+#line 437 "bsepart.proc"
+list_notes_within_exec (BseProcedureClass *proc,
+      const GValue      *in_values,
+      GValue            *out_values)
+#line 440 "bsepart.proc"
+{
+#line 441 "bsepart.proc"
+  
+  BsePart *self     = bse_value_get_object (in_values++);
+  guint    channel  = sfi_value_get_int (in_values++);
+  guint    tick	    = sfi_value_get_int (in_values++);
+  guint    duration = sfi_value_get_int (in_values++);
+  
+#line 447 "bsepart.proc"
+  
+  if (!BSE_IS_PART (self))
+    return BSE_ERROR_PROC_PARAM_INVAL;
+  
+#line 451 "bsepart.proc"
+  
+  bse_value_take_boxed (out_values++, bse_part_list_notes (self, channel, tick, duration, BSE_MIN_NOTE, BSE_MAX_NOTE, FALSE));
   
   return BSE_ERROR_NONE;
 }
@@ -515,9 +560,9 @@ list_notes_crossing_exec (BseProcedureClass *proc,
 /* --- list-controls --- */
 static void
 list_controls_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 424 "bsepart.proc"
+#line 457 "bsepart.proc"
  {
-#line 426 "bsepart.proc"
+#line 459 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("tick", "Start Tick", NULL,
@@ -530,30 +575,30 @@ list_controls_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
   *(out_pspecs++)   = bse_param_spec_boxed ("control_list", "Control List", NULL,
                                 BSE_TYPE_PART_CONTROL_SEQ, SFI_PARAM_STANDARD);
 }
-#line 438 "bsepart.proc"
+#line 471 "bsepart.proc"
  }
 static BseErrorType
-#line 438 "bsepart.proc"
+#line 471 "bsepart.proc"
 list_controls_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 441 "bsepart.proc"
+#line 474 "bsepart.proc"
 {
-#line 442 "bsepart.proc"
+#line 475 "bsepart.proc"
   
   BsePart *self      = bse_value_get_object (in_values++);
   guint    tick	     = sfi_value_get_int (in_values++);
   guint    duration  = sfi_value_get_int (in_values++);
   guint    ctype     = g_value_get_enum (in_values++);
   
-#line 448 "bsepart.proc"
+#line 481 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 452 "bsepart.proc"
+#line 485 "bsepart.proc"
   
-  bse_value_take_boxed (out_values++, bse_part_list_controls (self, tick, duration, ctype));
+  bse_value_take_boxed (out_values++, bse_part_list_controls (self, ~0, tick, duration, ctype));
   
   return BSE_ERROR_NONE;
 }
@@ -561,9 +606,9 @@ list_controls_exec (BseProcedureClass *proc,
 /* --- queue-notes --- */
 static void
 queue_notes_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 458 "bsepart.proc"
+#line 491 "bsepart.proc"
  {
-#line 460 "bsepart.proc"
+#line 493 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("tick", "Start Tick", NULL,
@@ -575,16 +620,16 @@ queue_notes_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec *
   *(in_pspecs++) = bse_pspec_note_simple ("max_note", "Maximum Note", NULL,
 				 SFI_PARAM_STANDARD);
 }
-#line 471 "bsepart.proc"
+#line 504 "bsepart.proc"
  }
 static BseErrorType
-#line 471 "bsepart.proc"
+#line 504 "bsepart.proc"
 queue_notes_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 474 "bsepart.proc"
+#line 507 "bsepart.proc"
 {
-#line 475 "bsepart.proc"
+#line 508 "bsepart.proc"
   
   BsePart *self     = bse_value_get_object (in_values++);
   guint    tick	    = sfi_value_get_int (in_values++);
@@ -592,12 +637,12 @@ queue_notes_exec (BseProcedureClass *proc,
   gint     min_note = sfi_value_get_note (in_values++);
   gint     max_note = sfi_value_get_note (in_values++);
   
-#line 482 "bsepart.proc"
+#line 515 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 486 "bsepart.proc"
+#line 519 "bsepart.proc"
   
   bse_part_queue_notes_within (self, tick, duration, min_note, max_note);
   
@@ -607,9 +652,9 @@ queue_notes_exec (BseProcedureClass *proc,
 /* --- queue-controls --- */
 static void
 queue_controls_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 492 "bsepart.proc"
+#line 525 "bsepart.proc"
  {
-#line 494 "bsepart.proc"
+#line 527 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("tick", "Start Tick", NULL,
@@ -617,27 +662,27 @@ queue_controls_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
   *(in_pspecs++) = sfi_pspec_int ("duration", "Tick Duration", NULL,
 			 1, 1, BSE_PART_MAX_TICK, 384, SFI_PARAM_STANDARD);
 }
-#line 501 "bsepart.proc"
+#line 534 "bsepart.proc"
  }
 static BseErrorType
-#line 501 "bsepart.proc"
+#line 534 "bsepart.proc"
 queue_controls_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 504 "bsepart.proc"
+#line 537 "bsepart.proc"
 {
-#line 505 "bsepart.proc"
+#line 538 "bsepart.proc"
   
   BsePart *self     = bse_value_get_object (in_values++);
   guint    tick	    = sfi_value_get_int (in_values++);
   guint    duration = sfi_value_get_int (in_values++);
   
-#line 510 "bsepart.proc"
+#line 543 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 514 "bsepart.proc"
+#line 547 "bsepart.proc"
   
   bse_part_queue_controls (self, tick, duration);
   
@@ -647,33 +692,33 @@ queue_controls_exec (BseProcedureClass *proc,
 /* --- list-selected-notes --- */
 static void
 list_selected_notes_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 520 "bsepart.proc"
+#line 553 "bsepart.proc"
  {
-#line 522 "bsepart.proc"
+#line 555 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_boxed ("note_list", "Note List", NULL,
 				BSE_TYPE_PART_NOTE_SEQ, SFI_PARAM_STANDARD);
 }
-#line 527 "bsepart.proc"
+#line 560 "bsepart.proc"
  }
 static BseErrorType
-#line 527 "bsepart.proc"
+#line 560 "bsepart.proc"
 list_selected_notes_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 530 "bsepart.proc"
+#line 563 "bsepart.proc"
 {
-#line 531 "bsepart.proc"
+#line 564 "bsepart.proc"
   
   BsePart *self     = bse_value_get_object (in_values++);
   
-#line 534 "bsepart.proc"
+#line 567 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 538 "bsepart.proc"
+#line 571 "bsepart.proc"
   
   bse_value_take_boxed (out_values++, bse_part_list_selected_notes (self));
   
@@ -683,9 +728,9 @@ list_selected_notes_exec (BseProcedureClass *proc,
 /* --- list-selected-controls --- */
 static void
 list_selected_controls_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 544 "bsepart.proc"
+#line 577 "bsepart.proc"
  {
-#line 546 "bsepart.proc"
+#line 579 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_param_spec_genum ("control_type", "Control Type", NULL,
@@ -694,26 +739,26 @@ list_selected_controls_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, G
   *(out_pspecs++)   = bse_param_spec_boxed ("control_list", "Control List", NULL,
                                 BSE_TYPE_PART_CONTROL_SEQ, SFI_PARAM_STANDARD);
 }
-#line 554 "bsepart.proc"
+#line 587 "bsepart.proc"
  }
 static BseErrorType
-#line 554 "bsepart.proc"
+#line 587 "bsepart.proc"
 list_selected_controls_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 557 "bsepart.proc"
+#line 590 "bsepart.proc"
 {
-#line 558 "bsepart.proc"
+#line 591 "bsepart.proc"
   
   BsePart *self     = bse_value_get_object (in_values++);
   guint    ctype    = g_value_get_enum (in_values++);
   
-#line 562 "bsepart.proc"
+#line 595 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 566 "bsepart.proc"
+#line 599 "bsepart.proc"
   
   bse_value_take_boxed (out_values++, bse_part_list_selected_controls (self, ctype));
   
@@ -723,9 +768,9 @@ list_selected_controls_exec (BseProcedureClass *proc,
 /* --- check-overlap --- */
 static void
 check_overlap_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 572 "bsepart.proc"
+#line 605 "bsepart.proc"
  {
-#line 574 "bsepart.proc"
+#line 607 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("tick", "Start Tick", NULL,
@@ -736,30 +781,30 @@ check_overlap_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
   *(out_pspecs++)   = bse_param_spec_boxed ("note_list", "Note List", NULL,
 				BSE_TYPE_PART_NOTE_SEQ, SFI_PARAM_STANDARD);
 }
-#line 584 "bsepart.proc"
+#line 617 "bsepart.proc"
  }
 static BseErrorType
-#line 584 "bsepart.proc"
+#line 617 "bsepart.proc"
 check_overlap_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 587 "bsepart.proc"
+#line 620 "bsepart.proc"
 {
-#line 588 "bsepart.proc"
+#line 621 "bsepart.proc"
   
   BsePart *self     = bse_value_get_object (in_values++);
   guint    tick	    = sfi_value_get_int (in_values++);
   guint    duration = sfi_value_get_int (in_values++);
   gint     note     = sfi_value_get_note (in_values++);
   
-#line 594 "bsepart.proc"
+#line 627 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 598 "bsepart.proc"
+#line 631 "bsepart.proc"
   
-  bse_value_take_boxed (out_values++, bse_part_list_notes_crossing (self, tick, duration, note, note));
+  bse_value_take_boxed (out_values++, bse_part_list_notes (self, ~0, tick, duration, note, note, TRUE));
   
   return BSE_ERROR_NONE;
 }
@@ -767,9 +812,9 @@ check_overlap_exec (BseProcedureClass *proc,
 /* --- get-notes --- */
 static void
 get_notes_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 604 "bsepart.proc"
+#line 637 "bsepart.proc"
  {
-#line 606 "bsepart.proc"
+#line 639 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("tick", "Tick", NULL,
@@ -779,29 +824,29 @@ get_notes_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **o
   *(out_pspecs++)   = bse_param_spec_boxed ("note_list", "Note List", NULL,
 				BSE_TYPE_PART_NOTE_SEQ, SFI_PARAM_STANDARD);
 }
-#line 615 "bsepart.proc"
+#line 648 "bsepart.proc"
  }
 static BseErrorType
-#line 615 "bsepart.proc"
+#line 648 "bsepart.proc"
 get_notes_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 618 "bsepart.proc"
+#line 651 "bsepart.proc"
 {
-#line 619 "bsepart.proc"
+#line 652 "bsepart.proc"
   
   BsePart *self     = bse_value_get_object (in_values++);
   guint    tick	    = sfi_value_get_int (in_values++);
   gint     note     = sfi_value_get_note (in_values++);
   
-#line 624 "bsepart.proc"
+#line 657 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 628 "bsepart.proc"
+#line 661 "bsepart.proc"
   
-  bse_value_take_boxed (out_values++, bse_part_list_notes_crossing (self, tick, 1, note, note));
+  bse_value_take_boxed (out_values++, bse_part_list_notes (self, ~0, tick, 1, note, note, TRUE));
   
   return BSE_ERROR_NONE;
 }
@@ -809,9 +854,9 @@ get_notes_exec (BseProcedureClass *proc,
 /* --- get-controls --- */
 static void
 get_controls_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 634 "bsepart.proc"
+#line 667 "bsepart.proc"
  {
-#line 636 "bsepart.proc"
+#line 669 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("tick", "Tick", NULL,
@@ -822,41 +867,43 @@ get_controls_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
   *(out_pspecs++)   = bse_param_spec_boxed ("control_list", "Control List", NULL,
                                 BSE_TYPE_PART_CONTROL_SEQ, SFI_PARAM_STANDARD);
 }
-#line 646 "bsepart.proc"
+#line 679 "bsepart.proc"
  }
 static BseErrorType
-#line 646 "bsepart.proc"
+#line 679 "bsepart.proc"
 get_controls_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 649 "bsepart.proc"
+#line 682 "bsepart.proc"
 {
-#line 650 "bsepart.proc"
+#line 683 "bsepart.proc"
   
   BsePart *self     = bse_value_get_object (in_values++);
   guint    tick	    = sfi_value_get_int (in_values++);
   guint    ctype    = g_value_get_enum (in_values++);
   
-#line 655 "bsepart.proc"
+#line 688 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 659 "bsepart.proc"
+#line 692 "bsepart.proc"
   
-  bse_value_take_boxed (out_values++, bse_part_list_controls (self, tick, 1, ctype));
+  bse_value_take_boxed (out_values++, bse_part_list_controls (self, ~0, tick, 1, ctype));
   
   return BSE_ERROR_NONE;
 }
 
-/* --- get-range-controls --- */
+/* --- get-channel-controls --- */
 static void
-get_range_controls_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 665 "bsepart.proc"
+get_channel_controls_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 698 "bsepart.proc"
  {
-#line 667 "bsepart.proc"
+#line 700 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
+  *(in_pspecs++) = sfi_pspec_int ("channel", "Channel", NULL,
+			 0, 0, BSE_PART_MAX_CHANNELS, 4, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("tick", "Tick", NULL,
 			 0, 0, BSE_PART_MAX_TICK - 1, 384, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_int ("duration", "Tick Duration", NULL,
@@ -867,30 +914,31 @@ get_range_controls_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPara
   *(out_pspecs++)   = bse_param_spec_boxed ("control_list", "Control List", NULL,
                                 BSE_TYPE_PART_CONTROL_SEQ, SFI_PARAM_STANDARD);
 }
-#line 679 "bsepart.proc"
+#line 714 "bsepart.proc"
  }
 static BseErrorType
-#line 679 "bsepart.proc"
-get_range_controls_exec (BseProcedureClass *proc,
+#line 714 "bsepart.proc"
+get_channel_controls_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 682 "bsepart.proc"
+#line 717 "bsepart.proc"
 {
-#line 683 "bsepart.proc"
+#line 718 "bsepart.proc"
   
   BsePart *self     = bse_value_get_object (in_values++);
+  guint    channel  = sfi_value_get_int (in_values++);
   guint    tick	    = sfi_value_get_int (in_values++);
   guint    duration = sfi_value_get_int (in_values++);
   guint    ctype    = g_value_get_enum (in_values++);
   
-#line 689 "bsepart.proc"
+#line 725 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 693 "bsepart.proc"
+#line 729 "bsepart.proc"
   
-  bse_value_take_boxed (out_values++, bse_part_list_controls (self, tick, duration, ctype));
+  bse_value_take_boxed (out_values++, bse_part_list_controls (self, channel, tick, duration, ctype));
   
   return BSE_ERROR_NONE;
 }
@@ -898,33 +946,33 @@ get_range_controls_exec (BseProcedureClass *proc,
 /* --- get-min-note --- */
 static void
 get_min_note_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 699 "bsepart.proc"
+#line 735 "bsepart.proc"
  {
-#line 701 "bsepart.proc"
+#line 737 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(out_pspecs++) = bse_pspec_note_simple ("note", "Note", NULL,
 				 SFI_PARAM_STANDARD);
 }
-#line 706 "bsepart.proc"
+#line 742 "bsepart.proc"
  }
 static BseErrorType
-#line 706 "bsepart.proc"
+#line 742 "bsepart.proc"
 get_min_note_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 709 "bsepart.proc"
+#line 745 "bsepart.proc"
 {
-#line 710 "bsepart.proc"
+#line 746 "bsepart.proc"
   
   BsePart *self     = bse_value_get_object (in_values++);
   
-#line 713 "bsepart.proc"
+#line 749 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 717 "bsepart.proc"
+#line 753 "bsepart.proc"
   
   sfi_value_set_int (out_values++, BSE_MIN_NOTE);
   
@@ -934,81 +982,45 @@ get_min_note_exec (BseProcedureClass *proc,
 /* --- get-max-note --- */
 static void
 get_max_note_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 723 "bsepart.proc"
+#line 759 "bsepart.proc"
  {
-#line 725 "bsepart.proc"
+#line 761 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(out_pspecs++) = bse_pspec_note_simple ("note", "Note", NULL,
 				 SFI_PARAM_STANDARD);
 }
-#line 730 "bsepart.proc"
+#line 766 "bsepart.proc"
  }
 static BseErrorType
-#line 730 "bsepart.proc"
+#line 766 "bsepart.proc"
 get_max_note_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 733 "bsepart.proc"
+#line 769 "bsepart.proc"
 {
-#line 734 "bsepart.proc"
+#line 770 "bsepart.proc"
   
   BsePart *self     = bse_value_get_object (in_values++);
   
-#line 737 "bsepart.proc"
+#line 773 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 741 "bsepart.proc"
+#line 777 "bsepart.proc"
   
   sfi_value_set_int (out_values++, BSE_MAX_NOTE);
   
   return BSE_ERROR_NONE;
 }
 
-/* --- get-max-tick --- */
-static void
-get_max_tick_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 747 "bsepart.proc"
- {
-#line 749 "bsepart.proc"
-  *(in_pspecs++) = bse_param_spec_object ("part", "Part", NULL,
-				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
-  *(out_pspecs++) = sfi_pspec_int ("tick", "Tick", "Maximum Tick",
-			 0, 0, BSE_PART_MAX_TICK, 384, SFI_PARAM_STANDARD);
-}
-#line 754 "bsepart.proc"
- }
-static BseErrorType
-#line 754 "bsepart.proc"
-get_max_tick_exec (BseProcedureClass *proc,
-      const GValue      *in_values,
-      GValue            *out_values)
-#line 757 "bsepart.proc"
-{
-#line 758 "bsepart.proc"
-  
-  BsePart *self     = bse_value_get_object (in_values++);
-  
-#line 761 "bsepart.proc"
-  
-  if (!BSE_IS_PART (self))
-    return BSE_ERROR_PROC_PARAM_INVAL;
-  
-#line 765 "bsepart.proc"
-  
-  sfi_value_set_int (out_values++, BSE_PART_MAX_TICK);
-  
-  return BSE_ERROR_NONE;
-}
-
 /* --- select-notes-exclusive --- */
 static void
 select_notes_exclusive_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 771 "bsepart.proc"
+#line 783 "bsepart.proc"
  {
-#line 773 "bsepart.proc"
+#line 785 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", "Part",
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("tick", "Tick", "Selection Tick",
@@ -1020,16 +1032,16 @@ select_notes_exclusive_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, G
   *(in_pspecs++) = bse_pspec_note_simple ("max_note", "Maximum Selection Note", NULL,
 				 SFI_PARAM_STANDARD);
 }
-#line 784 "bsepart.proc"
+#line 796 "bsepart.proc"
  }
 static BseErrorType
-#line 784 "bsepart.proc"
+#line 796 "bsepart.proc"
 select_notes_exclusive_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 787 "bsepart.proc"
+#line 799 "bsepart.proc"
 {
-#line 788 "bsepart.proc"
+#line 800 "bsepart.proc"
   
   BsePart *self   = bse_value_get_object (in_values++);
   guint tick      = sfi_value_get_int (in_values++);
@@ -1037,12 +1049,12 @@ select_notes_exclusive_exec (BseProcedureClass *proc,
   gint  min_note  = sfi_value_get_note (in_values++);
   gint  max_note  = sfi_value_get_note (in_values++);
   
-#line 795 "bsepart.proc"
+#line 807 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-  bse_part_select_notes_exclusive (self, tick, duration, min_note, max_note);
+  bse_part_select_notes_exclusive (self, ~0, tick, duration, min_note, max_note);
   
   return BSE_ERROR_NONE;
 }
@@ -1050,9 +1062,9 @@ select_notes_exclusive_exec (BseProcedureClass *proc,
 /* --- select-controls-exclusive --- */
 static void
 select_controls_exclusive_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 804 "bsepart.proc"
+#line 816 "bsepart.proc"
  {
-#line 806 "bsepart.proc"
+#line 818 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", "Part",
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("tick", "Tick", "Selection Tick",
@@ -1063,23 +1075,23 @@ select_controls_exclusive_setup (BseProcedureClass *proc, GParamSpec **in_pspecs
                                 BSE_TYPE_MIDI_SIGNAL_TYPE, BSE_MIDI_SIGNAL_PITCH_BEND,
                                 SFI_PARAM_STANDARD);
 }
-#line 816 "bsepart.proc"
+#line 828 "bsepart.proc"
  }
 static BseErrorType
-#line 816 "bsepart.proc"
+#line 828 "bsepart.proc"
 select_controls_exclusive_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 819 "bsepart.proc"
+#line 831 "bsepart.proc"
 {
-#line 820 "bsepart.proc"
+#line 832 "bsepart.proc"
   
   BsePart *self   = bse_value_get_object (in_values++);
   guint tick      = sfi_value_get_int (in_values++);
   guint duration  = sfi_value_get_int (in_values++);
   guint ctype     = g_value_get_enum (in_values++);
   
-#line 826 "bsepart.proc"
+#line 838 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -1092,9 +1104,9 @@ select_controls_exclusive_exec (BseProcedureClass *proc,
 /* --- select-notes --- */
 static void
 select_notes_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 835 "bsepart.proc"
+#line 847 "bsepart.proc"
  {
-#line 837 "bsepart.proc"
+#line 849 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", "Part",
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("tick", "Tick", "Selection Tick",
@@ -1106,16 +1118,16 @@ select_notes_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
   *(in_pspecs++) = bse_pspec_note_simple ("max_note", "Maximum Selection Note", NULL,
 				 SFI_PARAM_STANDARD);
 }
-#line 848 "bsepart.proc"
+#line 860 "bsepart.proc"
  }
 static BseErrorType
-#line 848 "bsepart.proc"
+#line 860 "bsepart.proc"
 select_notes_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 851 "bsepart.proc"
+#line 863 "bsepart.proc"
 {
-#line 852 "bsepart.proc"
+#line 864 "bsepart.proc"
   
   BsePart *self   = bse_value_get_object (in_values++);
   guint tick      = sfi_value_get_int (in_values++);
@@ -1123,12 +1135,12 @@ select_notes_exec (BseProcedureClass *proc,
   gint  min_note  = sfi_value_get_note (in_values++);
   gint  max_note  = sfi_value_get_note (in_values++);
   
-#line 859 "bsepart.proc"
+#line 871 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-  bse_part_select_notes (self, tick, duration, min_note, max_note, TRUE);
+  bse_part_select_notes (self, ~0, tick, duration, min_note, max_note, TRUE);
   
   return BSE_ERROR_NONE;
 }
@@ -1136,9 +1148,9 @@ select_notes_exec (BseProcedureClass *proc,
 /* --- deselect-notes --- */
 static void
 deselect_notes_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 868 "bsepart.proc"
+#line 880 "bsepart.proc"
  {
-#line 870 "bsepart.proc"
+#line 882 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", "Part",
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("tick", "Tick", "Selection Tick",
@@ -1150,16 +1162,16 @@ deselect_notes_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
   *(in_pspecs++) = bse_pspec_note_simple ("max_note", "Maximum Selection Note", NULL,
 				 SFI_PARAM_STANDARD);
 }
-#line 881 "bsepart.proc"
+#line 893 "bsepart.proc"
  }
 static BseErrorType
-#line 881 "bsepart.proc"
+#line 893 "bsepart.proc"
 deselect_notes_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 884 "bsepart.proc"
+#line 896 "bsepart.proc"
 {
-#line 885 "bsepart.proc"
+#line 897 "bsepart.proc"
   
   BsePart *self   = bse_value_get_object (in_values++);
   guint tick      = sfi_value_get_int (in_values++);
@@ -1167,12 +1179,12 @@ deselect_notes_exec (BseProcedureClass *proc,
   gint  min_note  = sfi_value_get_note (in_values++);
   gint  max_note  = sfi_value_get_note (in_values++);
   
-#line 892 "bsepart.proc"
+#line 904 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-  bse_part_select_notes (self, tick, duration, min_note, max_note, FALSE);
+  bse_part_select_notes (self, ~0, tick, duration, min_note, max_note, FALSE);
   
   return BSE_ERROR_NONE;
 }
@@ -1180,9 +1192,9 @@ deselect_notes_exec (BseProcedureClass *proc,
 /* --- deselect-controls --- */
 static void
 deselect_controls_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 901 "bsepart.proc"
+#line 913 "bsepart.proc"
  {
-#line 903 "bsepart.proc"
+#line 915 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", "Part",
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("tick", "Tick", "Selection Tick",
@@ -1193,23 +1205,23 @@ deselect_controls_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParam
                                 BSE_TYPE_MIDI_SIGNAL_TYPE, BSE_MIDI_SIGNAL_PITCH_BEND,
                                 SFI_PARAM_STANDARD);
 }
-#line 913 "bsepart.proc"
+#line 925 "bsepart.proc"
  }
 static BseErrorType
-#line 913 "bsepart.proc"
+#line 925 "bsepart.proc"
 deselect_controls_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 916 "bsepart.proc"
+#line 928 "bsepart.proc"
 {
-#line 917 "bsepart.proc"
+#line 929 "bsepart.proc"
   
   BsePart *self   = bse_value_get_object (in_values++);
   guint tick      = sfi_value_get_int (in_values++);
   guint duration  = sfi_value_get_int (in_values++);
   guint ctype     = g_value_get_enum (in_values++);
   
-#line 923 "bsepart.proc"
+#line 935 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -1222,35 +1234,35 @@ deselect_controls_exec (BseProcedureClass *proc,
 /* --- select-event --- */
 static void
 select_event_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 932 "bsepart.proc"
+#line 944 "bsepart.proc"
  {
-#line 934 "bsepart.proc"
+#line 946 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("id", "ID", NULL,
 			 0, 0, BSE_PART_MAX_TICK, 1, SFI_PARAM_STANDARD);
 }
-#line 939 "bsepart.proc"
+#line 951 "bsepart.proc"
  }
 static BseErrorType
-#line 939 "bsepart.proc"
+#line 951 "bsepart.proc"
 select_event_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 942 "bsepart.proc"
+#line 954 "bsepart.proc"
 {
-#line 943 "bsepart.proc"
+#line 955 "bsepart.proc"
   
   BsePart *self     = bse_value_get_object (in_values++);
   guint    id	    = sfi_value_get_int (in_values++);
   BsePartQueryEvent equery;
   
-#line 948 "bsepart.proc"
+#line 960 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 952 "bsepart.proc"
+#line 964 "bsepart.proc"
   
   bse_part_query_event (self, id, &equery);
   if (equery.event_type == BSE_PART_EVENT_CONTROL)
@@ -1265,35 +1277,35 @@ select_event_exec (BseProcedureClass *proc,
 /* --- deselect-event --- */
 static void
 deselect_event_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 963 "bsepart.proc"
+#line 975 "bsepart.proc"
  {
-#line 965 "bsepart.proc"
+#line 977 "bsepart.proc"
   *(in_pspecs++) = bse_param_spec_object ("part", "Part", NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("id", "ID", NULL,
 			 0, 0, BSE_PART_MAX_TICK, 1, SFI_PARAM_STANDARD);
 }
-#line 970 "bsepart.proc"
+#line 982 "bsepart.proc"
  }
 static BseErrorType
-#line 970 "bsepart.proc"
+#line 982 "bsepart.proc"
 deselect_event_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 973 "bsepart.proc"
+#line 985 "bsepart.proc"
 {
-#line 974 "bsepart.proc"
+#line 986 "bsepart.proc"
   
   BsePart *self     = bse_value_get_object (in_values++);
   guint    id	    = sfi_value_get_int (in_values++);
   BsePartQueryEvent equery;
   
-#line 979 "bsepart.proc"
+#line 991 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 983 "bsepart.proc"
+#line 995 "bsepart.proc"
   
   bse_part_query_event (self, id, &equery);
   if (equery.event_type == BSE_PART_EVENT_CONTROL)
@@ -1308,34 +1320,34 @@ deselect_event_exec (BseProcedureClass *proc,
 /* --- get-timing --- */
 static void
 get_timing_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 994 "bsepart.proc"
+#line 1006 "bsepart.proc"
  {
-#line 996 "bsepart.proc"
+#line 1008 "bsepart.proc"
   *(in_pspecs++)    = bse_param_spec_object ("part", "Part", NULL, BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_int ("tick", "Tick", "Tick to retrieve timing info about", 0, 0, G_MAXINT, 384, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_boxed ("timing", "Timing", "Song Timing", BSE_TYPE_SONG_TIMING, SFI_PARAM_STANDARD);
-#line 999 "bsepart.proc"
+#line 1011 "bsepart.proc"
 }  }
 static BseErrorType
-#line 999 "bsepart.proc"
+#line 1011 "bsepart.proc"
 get_timing_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 1002 "bsepart.proc"
+#line 1014 "bsepart.proc"
 {
-#line 1003 "bsepart.proc"
+#line 1015 "bsepart.proc"
   
   BsePart *self = bse_value_get_object (in_values++);
   SfiInt   tick = sfi_value_get_int (in_values++);
   BseItem *parent;
   BseSongTiming timing = { 0, };
 
-#line 1009 "bsepart.proc"
+#line 1021 "bsepart.proc"
   
   if (!BSE_IS_PART (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
 
-#line 1013 "bsepart.proc"
+#line 1025 "bsepart.proc"
   
   parent = BSE_ITEM (self)->parent;
   if (BSE_IS_SONG (parent))
@@ -1343,7 +1355,7 @@ get_timing_exec (BseProcedureClass *proc,
   else
     bse_song_timing_get_default (&timing);
 
-#line 1020 "bsepart.proc"
+#line 1032 "bsepart.proc"
   
   bse_value_set_boxed (out_values++, &timing);
 
@@ -1439,8 +1451,19 @@ static BseExportNodeProc __enode_list_notes_crossing = {
   },
   0, list_notes_crossing_setup, list_notes_crossing_exec, 
 };
-static BseExportNodeProc __enode_list_controls = {
+static BseExportNodeProc __enode_list_notes_within = {
   { (BseExportNode*) &__enode_list_notes_crossing, BSE_EXPORT_NODE_PROC,
+    "BsePart+list-notes-within", 
+    NULL,
+    "/Methods/BsePart/General/List Notes Within",
+    "List all notes within a tick range.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
+  0, list_notes_within_setup, list_notes_within_exec, 
+};
+static BseExportNodeProc __enode_list_controls = {
+  { (BseExportNode*) &__enode_list_notes_within, BSE_EXPORT_NODE_PROC,
     "BsePart+list-controls", 
     NULL,
     "/Methods/BsePart/General/List Controls",
@@ -1510,7 +1533,7 @@ static BseExportNodeProc __enode_get_notes = {
     "BsePart+get-notes", 
     NULL,
     "/Methods/BsePart/General/Get Notes",
-    "Retrieve all notes of specific frequency at a specific tick.",
+    "Retrieve all notes of specific frequency at or crossing a specific tick.",
     "Tim Janik <timj@gtk.org>",
     "GNU General Public License",
   },
@@ -1527,19 +1550,19 @@ static BseExportNodeProc __enode_get_controls = {
   },
   0, get_controls_setup, get_controls_exec, 
 };
-static BseExportNodeProc __enode_get_range_controls = {
+static BseExportNodeProc __enode_get_channel_controls = {
   { (BseExportNode*) &__enode_get_controls, BSE_EXPORT_NODE_PROC,
-    "BsePart+get-range-controls", 
+    "BsePart+get-channel-controls", 
     NULL,
-    "/Methods/BsePart/General/Get Range Controls",
-    "Retrieve all control events of a specific type within range.",
+    "/Methods/BsePart/General/Get Channel Controls",
+    "Retrieve all control events of a specific type within range of a channel.",
     "Tim Janik <timj@gtk.org>",
     "GNU General Public License",
   },
-  0, get_range_controls_setup, get_range_controls_exec, 
+  0, get_channel_controls_setup, get_channel_controls_exec, 
 };
 static BseExportNodeProc __enode_get_min_note = {
-  { (BseExportNode*) &__enode_get_range_controls, BSE_EXPORT_NODE_PROC,
+  { (BseExportNode*) &__enode_get_channel_controls, BSE_EXPORT_NODE_PROC,
     "BsePart+get-min-note", 
     NULL,
     "/Methods/BsePart/General/Get Min Note",
@@ -1560,19 +1583,8 @@ static BseExportNodeProc __enode_get_max_note = {
   },
   0, get_max_note_setup, get_max_note_exec, 
 };
-static BseExportNodeProc __enode_get_max_tick = {
-  { (BseExportNode*) &__enode_get_max_note, BSE_EXPORT_NODE_PROC,
-    "BsePart+get-max-tick", 
-    NULL,
-    "/Methods/BsePart/General/Get Max Tick",
-    "Retrieve the maximum tick count represented in a part.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
-  },
-  0, get_max_tick_setup, get_max_tick_exec, 
-};
 static BseExportNodeProc __enode_select_notes_exclusive = {
-  { (BseExportNode*) &__enode_get_max_tick, BSE_EXPORT_NODE_PROC,
+  { (BseExportNode*) &__enode_get_max_note, BSE_EXPORT_NODE_PROC,
     "BsePart+select-notes-exclusive", 
     NULL,
     "/Methods/BsePart/General/Select Notes Exclusive",
