@@ -23,11 +23,7 @@
 #include <bse/bseitem.h>
 #include <bse/gsldefs.h>
 
-
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
+G_BEGIN_DECLS
 
 /* --- object type macros --- */
 #define BSE_TYPE_PCM_DEVICE              (BSE_TYPE_ID (BsePcmDevice))
@@ -92,6 +88,7 @@ struct _BsePcmHandle
   guint			 n_channels;
   gfloat		 mix_freq;
   guint			 playback_watermark;
+  guint			 minimum_watermark;
   SfiMutex		 mutex;
   gsize	(*read)		(BsePcmHandle		*handle,
 			 gsize			 n_values,
@@ -124,6 +121,9 @@ struct _BsePcmDeviceClass
 
 
 /* --- prototypes --- */
+void		bse_pcm_device_request		(BsePcmDevice		*pdev,
+						 guint			 n_channels,
+						 BsePcmFreqMode		 freq_mode);
 BseErrorType	bse_pcm_device_open		(BsePcmDevice		*pdev);
 void		bse_pcm_device_suspend		(BsePcmDevice		*pdev);
 BsePcmHandle*	bse_pcm_device_get_handle	(BsePcmDevice		*pdev);
@@ -144,8 +144,6 @@ gfloat		bse_pcm_freq_from_freq_mode	(BsePcmFreqMode	freq_mode);
 BsePcmFreqMode	bse_pcm_freq_mode_from_freq	(gfloat		freq);
      
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* __BSE_PCM_DEVICE_H__ */
