@@ -642,7 +642,7 @@ match_items_by_uname_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPa
                             NULL, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("uname", NULL, NULL,
                             NULL, SFI_PARAM_STANDARD);
-  *(out_pspecs++)   = bse_param_spec_boxed ("item_list", "Item List", NULL, BSE_TYPE_PROXY_SEQ, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = bse_param_spec_boxed ("item_list", "Item List", NULL, BSE_TYPE_ITEM_SEQ, SFI_PARAM_STANDARD);
 #line 487 "bseproject.proc"
 }  }
 static BseErrorType
@@ -659,7 +659,7 @@ match_items_by_uname_exec (BseProcedureClass *proc,
   const gchar *string = sfi_value_get_string (in_values++);
   GType type          = tname ? g_type_from_name (tname) : 0;
   GList *list, *free_list;
-  BseProxySeq *pseq;
+  BseItemSeq *iseq;
   
 #line 499 "bseproject.proc"
   
@@ -668,19 +668,19 @@ match_items_by_uname_exec (BseProcedureClass *proc,
   
 #line 503 "bseproject.proc"
   
-  pseq = bse_proxy_seq_new ();
+  iseq = bse_item_seq_new ();
   free_list = bse_objects_list_by_uname (type, string);
   for (list = free_list; list; list = list->next)
     if (bse_item_get_project (list->data) == project)
       {
-        bse_proxy_seq_append (pseq, BSE_OBJECT_ID (list->data));
+        bse_item_seq_append (iseq, list->data);
         break;
       }
   g_list_free (free_list);
   
 #line 514 "bseproject.proc"
   
-  bse_value_take_boxed (out_values++, pseq);
+  bse_value_take_boxed (out_values++, iseq);
   
   return BSE_ERROR_NONE;
 }
@@ -693,7 +693,7 @@ get_supers_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
 #line 522 "bseproject.proc"
   *(in_pspecs++)    = bse_param_spec_object ("project", NULL, NULL,
                                  BSE_TYPE_PROJECT, SFI_PARAM_STANDARD);
-  *(out_pspecs++)   = bse_param_spec_boxed ("super_list", NULL, NULL, BSE_TYPE_PROXY_SEQ, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = bse_param_spec_boxed ("super_list", NULL, NULL, BSE_TYPE_ITEM_SEQ, SFI_PARAM_STANDARD);
 #line 525 "bseproject.proc"
 }  }
 static BseErrorType
@@ -706,7 +706,7 @@ get_supers_exec (BseProcedureClass *proc,
 #line 529 "bseproject.proc"
   
   BseProject *project = bse_value_get_object (in_values++);
-  BseProxySeq *pseq;
+  BseItemSeq *iseq;
   GSList *slist;
   
 #line 534 "bseproject.proc"
@@ -716,13 +716,13 @@ get_supers_exec (BseProcedureClass *proc,
   
 #line 538 "bseproject.proc"
   
-  pseq = bse_proxy_seq_new ();
+  iseq = bse_item_seq_new ();
   for (slist = project->supers; slist; slist = slist->next)
-    bse_proxy_seq_append (pseq, BSE_OBJECT_ID (slist->data));
+    bse_item_seq_append (iseq, slist->data);
   
 #line 543 "bseproject.proc"
   
-  bse_value_take_boxed (out_values++, pseq);
+  bse_value_take_boxed (out_values++, iseq);
   
   return BSE_ERROR_NONE;
 }
