@@ -19,15 +19,11 @@ bse_proxy_check_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSp
  {
 #line 30 "bsescripthelper.proc"
   *(in_pspecs++) = bse_param_spec_object ("item", "Item", "The Item",
-				 BSE_TYPE_ITEM, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_ITEM, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("type_name", "Type Name", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_bool ("is_a", NULL, NULL,
-			  FALSE, SFI_PARAM_DEFAULT);
-#line 24 "bsescripthelper.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 25 "bsescripthelper.proc"
-  proc->license = "GNU Lesser General Public License";
+			  FALSE, SFI_PARAM_STANDARD);
 #line 36 "bsescripthelper.proc"
 }  }
 static BseErrorType
@@ -64,7 +60,13 @@ bse_proxy_check_exec (BseProcedureClass *proc,
 /* --- Export to BSE --- */
 static BseExportNodeProc __enode_bse_proxy_check = {
   { NULL, BSE_EXPORT_NODE_PROC,
-    "bse-proxy-check", "/Proc/Proxy Check", "Check whether a proxy has a certain type." },
+    "bse-proxy-check", 
+    NULL,
+    "/Proc/Proxy Check",
+    "Check whether a proxy has a certain type.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, bse_proxy_check_setup, bse_proxy_check_exec, 
 };
 BseExportNode* bse__builtin_init_bsescripthelper_gen_proc_c (void);
