@@ -10,57 +10,52 @@
 #include <bse/bsepart.h>
 #include <bse/bsetrack.h>
 #include "bsemidireceiver.h"
+#include "bseundostack.h"
 #include "bseproject.h"
 #include "gslcommon.h"
 #include "gslengine.h"
 
-#line 31 "bsesong.proc"
+#line 32 "bsesong.proc"
 
 
 /* --- create-part --- */
 static void
 create_part_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 33 "bsesong.proc"
- {
-#line 35 "bsesong.proc"
-  *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
-				 BSE_TYPE_SONG, SFI_PARAM_DEFAULT);
-  *(out_pspecs++)   = bse_param_spec_object ("part", "Part", NULL,
-				 BSE_TYPE_PART, SFI_PARAM_DEFAULT);
 #line 34 "bsesong.proc"
-  proc->help = "Create a new Part in a Song";
-#line 29 "bsesong.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 30 "bsesong.proc"
-  proc->license = "GNU Lesser General Public License";
-#line 39 "bsesong.proc"
+ {
+#line 36 "bsesong.proc"
+  *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
+				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = bse_param_spec_object ("part", "Part", NULL,
+				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
+#line 40 "bsesong.proc"
 }  }
 static BseErrorType
-#line 39 "bsesong.proc"
+#line 40 "bsesong.proc"
 create_part_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 42 "bsesong.proc"
-{
 #line 43 "bsesong.proc"
+{
+#line 44 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   BseUndoStack *ustack;
   BseItem *child;
 
-#line 48 "bsesong.proc"
+#line 49 "bsesong.proc"
   
   if (!BSE_IS_SONG (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 52 "bsesong.proc"
+#line 53 "bsesong.proc"
   
   ustack = bse_item_undo_open (self, "create-part");
   child = bse_container_new_child (BSE_CONTAINER (self), BSE_TYPE_PART, NULL);
   bse_item_push_undo_proc (self, "remove-part", child);
   bse_item_undo_close (ustack);
   
-#line 58 "bsesong.proc"
+#line 59 "bsesong.proc"
   
   bse_value_set_object (out_values++, child);
   
@@ -70,56 +65,50 @@ create_part_exec (BseProcedureClass *proc,
 /* --- remove-part --- */
 static void
 remove_part_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 64 "bsesong.proc"
- {
-#line 66 "bsesong.proc"
-  *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
-				 BSE_TYPE_SONG, SFI_PARAM_DEFAULT);
-  *(in_pspecs++)    = bse_param_spec_object ("part", "Part", NULL,
-				 BSE_TYPE_PART, SFI_PARAM_DEFAULT);
 #line 65 "bsesong.proc"
-  proc->help = "Delete a Part from a Song";
-#line 29 "bsesong.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 30 "bsesong.proc"
-  proc->license = "GNU Lesser General Public License";
-#line 70 "bsesong.proc"
+ {
+#line 67 "bsesong.proc"
+  *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
+				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = bse_param_spec_object ("part", "Part", NULL,
+				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
+#line 71 "bsesong.proc"
 }  }
 static BseErrorType
-#line 70 "bsesong.proc"
+#line 71 "bsesong.proc"
 remove_part_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 73 "bsesong.proc"
-{
 #line 74 "bsesong.proc"
+{
+#line 75 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   BseItem *child = bse_value_get_object (in_values++);
   BseErrorType error = BSE_ERROR_NONE;
   
-#line 79 "bsesong.proc"
+#line 80 "bsesong.proc"
   
   if (!BSE_IS_SONG (self) || !BSE_IS_PART (child) || BSE_ITEM (child)->parent != BSE_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 83 "bsesong.proc"
+#line 84 "bsesong.proc"
   
   if (BSE_SOURCE_PREPARED (self))
     error = BSE_ERROR_SOURCE_BUSY;
   else
     {
       BseUndoStack *ustack = bse_item_undo_open (self, "remove-child %s", bse_object_debug_name (child));
-#line 89 "bsesong.proc"
+#line 90 "bsesong.proc"
       
       bse_container_uncross_undoable (BSE_CONTAINER (self), child);
-#line 91 "bsesong.proc"
+#line 92 "bsesong.proc"
       
       bse_item_push_redo_proc (self, "remove-part", child);
-#line 93 "bsesong.proc"
+#line 94 "bsesong.proc"
       
       bse_container_remove_backedup (BSE_CONTAINER (self), child, ustack);
-#line 95 "bsesong.proc"
+#line 96 "bsesong.proc"
       
       bse_item_undo_close (ustack);
     }
@@ -130,40 +119,34 @@ remove_part_exec (BseProcedureClass *proc,
 /* --- create-track --- */
 static void
 create_track_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 102 "bsesong.proc"
- {
-#line 104 "bsesong.proc"
-  *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
-				 BSE_TYPE_SONG, SFI_PARAM_DEFAULT);
-  *(out_pspecs++)   = bse_param_spec_object ("track", "Track", NULL,
-				 BSE_TYPE_TRACK, SFI_PARAM_DEFAULT);
 #line 103 "bsesong.proc"
-  proc->help = "Create a new Track for a Song";
-#line 29 "bsesong.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 30 "bsesong.proc"
-  proc->license = "GNU Lesser General Public License";
-#line 108 "bsesong.proc"
+ {
+#line 105 "bsesong.proc"
+  *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
+				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = bse_param_spec_object ("track", "Track", NULL,
+				 BSE_TYPE_TRACK, SFI_PARAM_STANDARD);
+#line 109 "bsesong.proc"
 }  }
 static BseErrorType
-#line 108 "bsesong.proc"
+#line 109 "bsesong.proc"
 create_track_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 111 "bsesong.proc"
-{
 #line 112 "bsesong.proc"
+{
+#line 113 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   BseErrorType error = BSE_ERROR_NONE;
   BseItem *child = NULL;
 
-#line 117 "bsesong.proc"
+#line 118 "bsesong.proc"
   
   if (!BSE_IS_SONG (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 121 "bsesong.proc"
+#line 122 "bsesong.proc"
   
   if (BSE_SOURCE_PREPARED (self))
     error = BSE_ERROR_SOURCE_BUSY;
@@ -175,7 +158,7 @@ create_track_exec (BseProcedureClass *proc,
       bse_item_undo_close (ustack);
     }
 
-#line 132 "bsesong.proc"
+#line 133 "bsesong.proc"
   
   bse_value_set_object (out_values++, child);
   
@@ -185,57 +168,51 @@ create_track_exec (BseProcedureClass *proc,
 /* --- remove-track --- */
 static void
 remove_track_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 138 "bsesong.proc"
- {
-#line 140 "bsesong.proc"
-  *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
-				 BSE_TYPE_SONG, SFI_PARAM_DEFAULT);
-  *(in_pspecs++)    = bse_param_spec_object ("track", "Track", NULL,
-				 BSE_TYPE_TRACK, SFI_PARAM_DEFAULT);
 #line 139 "bsesong.proc"
-  proc->help = "Delete a Track from a Song";
-#line 29 "bsesong.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 30 "bsesong.proc"
-  proc->license = "GNU Lesser General Public License";
-#line 144 "bsesong.proc"
+ {
+#line 141 "bsesong.proc"
+  *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
+				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = bse_param_spec_object ("track", "Track", NULL,
+				 BSE_TYPE_TRACK, SFI_PARAM_STANDARD);
+#line 145 "bsesong.proc"
 }  }
 static BseErrorType
-#line 144 "bsesong.proc"
+#line 145 "bsesong.proc"
 remove_track_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 147 "bsesong.proc"
-{
 #line 148 "bsesong.proc"
+{
+#line 149 "bsesong.proc"
   
   BseSong *self  = bse_value_get_object (in_values++);
   BseItem *child = bse_value_get_object (in_values++);
   BseErrorType error = BSE_ERROR_NONE;
   
-#line 153 "bsesong.proc"
+#line 154 "bsesong.proc"
   
   if (!BSE_IS_SONG (self) || !BSE_IS_TRACK (child) ||
       BSE_ITEM (child)->parent != BSE_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 158 "bsesong.proc"
+#line 159 "bsesong.proc"
   
   if (BSE_SOURCE_PREPARED (self))
     error = BSE_ERROR_SOURCE_BUSY;
   else
     {
       BseUndoStack *ustack = bse_item_undo_open (self, "remove-child %s", bse_object_debug_name (child));
-#line 164 "bsesong.proc"
+#line 165 "bsesong.proc"
       
       bse_container_uncross_undoable (BSE_CONTAINER (self), child);
-#line 166 "bsesong.proc"
+#line 167 "bsesong.proc"
       
       bse_item_push_redo_proc (self, "remove-track", child);
-#line 168 "bsesong.proc"
+#line 169 "bsesong.proc"
       
       bse_container_remove_backedup (BSE_CONTAINER (self), child, ustack);
-#line 170 "bsesong.proc"
+#line 171 "bsesong.proc"
       
       bse_item_undo_close (ustack);
     }
@@ -246,31 +223,25 @@ remove_track_exec (BseProcedureClass *proc,
 /* --- find-track-for-part --- */
 static void
 find_track_for_part_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 177 "bsesong.proc"
- {
-#line 179 "bsesong.proc"
-  *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
-				 BSE_TYPE_SONG, SFI_PARAM_DEFAULT);
-  *(in_pspecs++)    = bse_param_spec_object ("part", "Part", NULL,
-				 BSE_TYPE_PART, SFI_PARAM_DEFAULT);
-  *(out_pspecs++)   = bse_param_spec_object ("track", "Track", NULL,
-				 BSE_TYPE_TRACK, SFI_PARAM_DEFAULT);
 #line 178 "bsesong.proc"
-  proc->help = "Find a track suitable for playing notes of a given part.";
-#line 29 "bsesong.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 30 "bsesong.proc"
-  proc->license = "GNU Lesser General Public License";
-#line 185 "bsesong.proc"
+ {
+#line 180 "bsesong.proc"
+  *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
+				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = bse_param_spec_object ("part", "Part", NULL,
+				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = bse_param_spec_object ("track", "Track", NULL,
+				 BSE_TYPE_TRACK, SFI_PARAM_STANDARD);
+#line 186 "bsesong.proc"
 }  }
 static BseErrorType
-#line 185 "bsesong.proc"
+#line 186 "bsesong.proc"
 find_track_for_part_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 188 "bsesong.proc"
-{
 #line 189 "bsesong.proc"
+{
+#line 190 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   BsePart *part = bse_value_get_object (in_values++);
@@ -278,13 +249,13 @@ find_track_for_part_exec (BseProcedureClass *proc,
   guint tick = 0;
   SfiRing *ring;
 
-#line 196 "bsesong.proc"
+#line 197 "bsesong.proc"
   
   if (!BSE_IS_SONG (self) || !BSE_IS_PART (part) ||
       BSE_ITEM (part)->parent != BSE_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
 
-#line 201 "bsesong.proc"
+#line 202 "bsesong.proc"
   
   for (ring = self->tracks_SL; ring; ring = sfi_ring_walk (ring, self->tracks_SL))
     {
@@ -300,7 +271,7 @@ find_track_for_part_exec (BseProcedureClass *proc,
   if (!track)
     track = self->tracks_SL ? self->tracks_SL->data : NULL;
 
-#line 216 "bsesong.proc"
+#line 217 "bsesong.proc"
   
   bse_value_set_object (out_values++, track);
   
@@ -310,37 +281,31 @@ find_track_for_part_exec (BseProcedureClass *proc,
 /* --- synthesize-note --- */
 static void
 synthesize_note_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 222 "bsesong.proc"
+#line 223 "bsesong.proc"
  {
-#line 224 "bsesong.proc"
+#line 225 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
-				 BSE_TYPE_SONG, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_param_spec_object ("track", "Track", NULL,
-				 BSE_TYPE_TRACK, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_TRACK, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_int ("duration", "Tick Duration", NULL,
-			 1, 1, BSE_PART_MAX_TICK, 384, SFI_PARAM_DEFAULT);
+			 1, 1, BSE_PART_MAX_TICK, 384, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_pspec_note_simple ("note", "Note", NULL,
-				 SFI_PARAM_DEFAULT);
+				 SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_param_spec_fine_tune ("fine_tune", "Fine Tune", "Fine tune in cents per semitone");
   *(in_pspecs++)    = sfi_pspec_real ("velocity", "Velocity", NULL,
 			  1.0, 0, 1.0, 0.01,
-			  SFI_PARAM_DEFAULT ":scale");
-#line 223 "bsesong.proc"
-  proc->help = "Synthesize a note on a song of an active project.";
-#line 29 "bsesong.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 30 "bsesong.proc"
-  proc->license = "GNU Lesser General Public License";
-#line 236 "bsesong.proc"
+			  SFI_PARAM_STANDARD ":scale");
+#line 237 "bsesong.proc"
 }  }
 static BseErrorType
-#line 236 "bsesong.proc"
+#line 237 "bsesong.proc"
 synthesize_note_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 239 "bsesong.proc"
-{
 #line 240 "bsesong.proc"
+{
+#line 241 "bsesong.proc"
   
   BseSong *self      = bse_value_get_object (in_values++);
   BseTrack *track    = bse_value_get_object (in_values++);
@@ -349,13 +314,13 @@ synthesize_note_exec (BseProcedureClass *proc,
   gint     fine_tune = sfi_value_get_int (in_values++);
   gfloat   velocity  = sfi_value_get_real (in_values++);
   
-#line 248 "bsesong.proc"
+#line 249 "bsesong.proc"
   
   if (!BSE_IS_SONG (self) || !BSE_IS_TRACK (track) ||
       BSE_ITEM (track)->parent != BSE_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 253 "bsesong.proc"
+#line 254 "bsesong.proc"
   
   if (BSE_SOURCE_PREPARED (self) && self->midi_receiver_SL)
     {
@@ -378,43 +343,37 @@ synthesize_note_exec (BseProcedureClass *proc,
 /* --- get-timing --- */
 static void
 get_timing_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 272 "bsesong.proc"
- {
-#line 274 "bsesong.proc"
-  *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL, BSE_TYPE_SONG, SFI_PARAM_DEFAULT);
-  *(in_pspecs++)    = sfi_pspec_int ("tick", "Tick", "Tick to retrieve timing info about", 0, 0, G_MAXINT, 384, SFI_PARAM_DEFAULT);
-  *(out_pspecs++)   = bse_param_spec_boxed ("timing", "Timing", "Song Timing", BSE_TYPE_SONG_TIMING, SFI_PARAM_DEFAULT);
 #line 273 "bsesong.proc"
-  proc->help = "Retrieve song timing information at a specific tick.";
-#line 29 "bsesong.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 30 "bsesong.proc"
-  proc->license = "GNU Lesser General Public License";
-#line 277 "bsesong.proc"
+ {
+#line 275 "bsesong.proc"
+  *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL, BSE_TYPE_SONG, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = sfi_pspec_int ("tick", "Tick", "Tick to retrieve timing info about", 0, 0, G_MAXINT, 384, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = bse_param_spec_boxed ("timing", "Timing", "Song Timing", BSE_TYPE_SONG_TIMING, SFI_PARAM_STANDARD);
+#line 278 "bsesong.proc"
 }  }
 static BseErrorType
-#line 277 "bsesong.proc"
+#line 278 "bsesong.proc"
 get_timing_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 280 "bsesong.proc"
-{
 #line 281 "bsesong.proc"
+{
+#line 282 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   SfiInt   tick = sfi_value_get_int (in_values++);
   BseSongTiming timing = { 0, };
 
-#line 286 "bsesong.proc"
+#line 287 "bsesong.proc"
   
   if (!BSE_IS_SONG (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
 
-#line 290 "bsesong.proc"
+#line 291 "bsesong.proc"
   
   bse_song_get_timing (self, tick, &timing);
 
-#line 293 "bsesong.proc"
+#line 294 "bsesong.proc"
   
   bse_value_set_boxed (out_values++, &timing);
   
@@ -424,37 +383,79 @@ get_timing_exec (BseProcedureClass *proc,
 /* --- Export to BSE --- */
 static BseExportNodeProc __enode_create_part = {
   { NULL, BSE_EXPORT_NODE_PROC,
-    "BseSong+create-part", "/Methods/BseSong/General/Create Part", NULL },
+    "BseSong+create-part", 
+    NULL,
+    "/Methods/BseSong/General/Create Part",
+    "Create a new Part in a Song",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, create_part_setup, create_part_exec, 
 };
 static BseExportNodeProc __enode_remove_part = {
   { (BseExportNode*) &__enode_create_part, BSE_EXPORT_NODE_PROC,
-    "BseSong+remove-part", "/Methods/BseSong/General/Remove Part", NULL },
+    "BseSong+remove-part", 
+    NULL,
+    "/Methods/BseSong/General/Remove Part",
+    "Delete a Part from a Song",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, remove_part_setup, remove_part_exec, 
 };
 static BseExportNodeProc __enode_create_track = {
   { (BseExportNode*) &__enode_remove_part, BSE_EXPORT_NODE_PROC,
-    "BseSong+create-track", "/Methods/BseSong/General/Create Track", NULL },
+    "BseSong+create-track", 
+    NULL,
+    "/Methods/BseSong/General/Create Track",
+    "Create a new Track for a Song",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, create_track_setup, create_track_exec, 
 };
 static BseExportNodeProc __enode_remove_track = {
   { (BseExportNode*) &__enode_create_track, BSE_EXPORT_NODE_PROC,
-    "BseSong+remove-track", "/Methods/BseSong/General/Remove Track", NULL },
+    "BseSong+remove-track", 
+    NULL,
+    "/Methods/BseSong/General/Remove Track",
+    "Delete a Track from a Song",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, remove_track_setup, remove_track_exec, 
 };
 static BseExportNodeProc __enode_find_track_for_part = {
   { (BseExportNode*) &__enode_remove_track, BSE_EXPORT_NODE_PROC,
-    "BseSong+find-track-for-part", "/Methods/BseSong/General/Find Track For Part", NULL },
+    "BseSong+find-track-for-part", 
+    NULL,
+    "/Methods/BseSong/General/Find Track For Part",
+    "Find a track suitable for playing notes of a given part.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, find_track_for_part_setup, find_track_for_part_exec, 
 };
 static BseExportNodeProc __enode_synthesize_note = {
   { (BseExportNode*) &__enode_find_track_for_part, BSE_EXPORT_NODE_PROC,
-    "BseSong+synthesize-note", "/Methods/BseSong/General/Synthesize Note", NULL },
+    "BseSong+synthesize-note", 
+    NULL,
+    "/Methods/BseSong/General/Synthesize Note",
+    "Synthesize a note on a song of an active project.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, synthesize_note_setup, synthesize_note_exec, 
 };
 static BseExportNodeProc __enode_get_timing = {
   { (BseExportNode*) &__enode_synthesize_note, BSE_EXPORT_NODE_PROC,
-    "BseSong+get-timing", "/Methods/BseSong/General/Get Timing", NULL },
+    "BseSong+get-timing", 
+    NULL,
+    "/Methods/BseSong/General/Get Timing",
+    "Retrieve song timing information at a specific tick.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, get_timing_setup, get_timing_exec, 
 };
 BseExportNode* bse__builtin_init_bsesong_gen_proc_c (void);
