@@ -97,9 +97,9 @@ set_input_exec (BseProcedureClass *proc,
 #line 88 "bsesource.proc"
   
   BseSource *isource   = bse_value_get_object (in_values++);
-  gchar *ichannel_name = sfi_value_get_string (in_values++);
+  gchar *ichannel_ident = sfi_value_get_string (in_values++);
   BseSource *osource   = bse_value_get_object (in_values++);
-  gchar *ochannel_name = sfi_value_get_string (in_values++);
+  gchar *ochannel_ident = sfi_value_get_string (in_values++);
   guint ichannel, ochannel;
   BseErrorType error;
   
@@ -107,13 +107,13 @@ set_input_exec (BseProcedureClass *proc,
   
   if (!BSE_IS_SOURCE (isource) || !BSE_IS_SOURCE (osource) ||
       BSE_ITEM (isource)->parent != BSE_ITEM (osource)->parent ||
-      !ichannel_name || !ochannel_name)
+      !ichannel_ident || !ochannel_ident)
     return BSE_ERROR_PROC_PARAM_INVAL;
   
 #line 102 "bsesource.proc"
   
-  ichannel = bse_source_find_ichannel (isource, ichannel_name);
-  ochannel = bse_source_find_ochannel (osource, ochannel_name);
+  ichannel = bse_source_find_ichannel (isource, ichannel_ident);
+  ochannel = bse_source_find_ochannel (osource, ochannel_ident);
   error = bse_source_set_input (isource, ichannel, osource, ochannel);
   if (error == BSE_ERROR_NONE)
     bse_item_push_undo_proc (isource, "unset-input-by-id", ichannel, osource, ochannel);
@@ -214,22 +214,22 @@ unset_input_exec (BseProcedureClass *proc,
 #line 179 "bsesource.proc"
   
   BseSource *isource   = bse_value_get_object (in_values++);
-  gchar *ichannel_name = sfi_value_get_string (in_values++);
+  gchar *ichannel_ident = sfi_value_get_string (in_values++);
   BseSource *osource   = bse_value_get_object (in_values++);
-  gchar *ochannel_name = sfi_value_get_string (in_values++);
+  gchar *ochannel_ident = sfi_value_get_string (in_values++);
   guint ichannel, ochannel;
   BseErrorType error = BSE_ERROR_NONE;
   
 #line 187 "bsesource.proc"
   
   if (!BSE_IS_SOURCE (isource) || !BSE_IS_SOURCE (osource) ||
-      !ichannel_name || !ochannel_name)
+      !ichannel_ident || !ochannel_ident)
     return BSE_ERROR_PROC_PARAM_INVAL;
   
 #line 192 "bsesource.proc"
   
-  ichannel = bse_source_find_ichannel (isource, ichannel_name);
-  ochannel = bse_source_find_ochannel (osource, ochannel_name);
+  ichannel = bse_source_find_ichannel (isource, ichannel_ident);
+  ochannel = bse_source_find_ochannel (osource, ochannel_ident);
   error = bse_source_check_input (isource, ichannel, osource, ochannel);
   if (error == BSE_ERROR_NONE)
     {
@@ -397,9 +397,9 @@ n_ichannels_exec (BseProcedureClass *proc,
   return BSE_ERROR_NONE;
 }
 
-/* --- ichannel-name --- */
+/* --- ichannel-label --- */
 static void
-ichannel_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+ichannel_label_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 313 "bsesource.proc"
  {
 #line 315 "bsesource.proc"
@@ -407,14 +407,14 @@ ichannel_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
 			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
-  *(out_pspecs++)   = sfi_pspec_string ("channel_name", "Channel Name", NULL,
+  *(out_pspecs++)   = sfi_pspec_string ("channel_label", "Channel Name", NULL,
 			    NULL, SFI_PARAM_STANDARD);
 }
 #line 322 "bsesource.proc"
  }
 static BseErrorType
 #line 322 "bsesource.proc"
-ichannel_name_exec (BseProcedureClass *proc,
+ichannel_label_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
 #line 325 "bsesource.proc"
@@ -431,7 +431,7 @@ ichannel_name_exec (BseProcedureClass *proc,
   
 #line 334 "bsesource.proc"
   
-  sfi_value_set_string (out_values++, BSE_SOURCE_ICHANNEL_NAME (source, ichannel));
+  sfi_value_set_string (out_values++, BSE_SOURCE_ICHANNEL_LABEL (source, ichannel));
   
   return BSE_ERROR_NONE;
 }
@@ -446,7 +446,7 @@ ichannel_ident_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
 			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
-  *(out_pspecs++)   = sfi_pspec_string ("channel_name", "Channel Name", NULL,
+  *(out_pspecs++)   = sfi_pspec_string ("channel_ident", "Channel Name", NULL,
 			    NULL, SFI_PARAM_STANDARD);
 }
 #line 349 "bsesource.proc"
@@ -773,9 +773,9 @@ n_ochannels_exec (BseProcedureClass *proc,
   return BSE_ERROR_NONE;
 }
 
-/* --- ochannel-name --- */
+/* --- ochannel-label --- */
 static void
-ochannel_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+ochannel_label_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 581 "bsesource.proc"
  {
 #line 583 "bsesource.proc"
@@ -783,14 +783,14 @@ ochannel_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
 			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
-  *(out_pspecs++)   = sfi_pspec_string ("channel_name", "Channel Name", NULL,
+  *(out_pspecs++)   = sfi_pspec_string ("channel_label", "Channel Name", NULL,
 			    NULL, SFI_PARAM_STANDARD);
 }
 #line 590 "bsesource.proc"
  }
 static BseErrorType
 #line 590 "bsesource.proc"
-ochannel_name_exec (BseProcedureClass *proc,
+ochannel_label_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
 #line 593 "bsesource.proc"
@@ -807,7 +807,7 @@ ochannel_name_exec (BseProcedureClass *proc,
   
 #line 602 "bsesource.proc"
   
-  sfi_value_set_string (out_values++, BSE_SOURCE_OCHANNEL_NAME (source, ochannel));
+  sfi_value_set_string (out_values++, BSE_SOURCE_OCHANNEL_LABEL (source, ochannel));
   
   return BSE_ERROR_NONE;
 }
@@ -822,7 +822,7 @@ ochannel_ident_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
 				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
 			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
-  *(out_pspecs++)   = sfi_pspec_string ("channel_name", "Channel Name", NULL,
+  *(out_pspecs++)   = sfi_pspec_string ("channel_ident", "Channel Name", NULL,
 			    NULL, SFI_PARAM_STANDARD);
 }
 #line 617 "bsesource.proc"
@@ -1030,19 +1030,19 @@ static BseExportNodeProc __enode_n_ichannels = {
   },
   0, n_ichannels_setup, n_ichannels_exec, 
 };
-static BseExportNodeProc __enode_ichannel_name = {
+static BseExportNodeProc __enode_ichannel_label = {
   { (BseExportNode*) &__enode_n_ichannels, BSE_EXPORT_NODE_PROC,
-    "BseSource+ichannel-name", 
+    "BseSource+ichannel-label", 
     NULL,
-    "/Methods/BseSource/General/Ichannel Name",
+    "/Methods/BseSource/General/Ichannel Label",
     "Get input channel name.",
     "Tim Janik <timj@gtk.org>",
     "GNU Lesser General Public License",
   },
-  0, ichannel_name_setup, ichannel_name_exec, 
+  0, ichannel_label_setup, ichannel_label_exec, 
 };
 static BseExportNodeProc __enode_ichannel_ident = {
-  { (BseExportNode*) &__enode_ichannel_name, BSE_EXPORT_NODE_PROC,
+  { (BseExportNode*) &__enode_ichannel_label, BSE_EXPORT_NODE_PROC,
     "BseSource+ichannel-ident", 
     NULL,
     "/Methods/BseSource/General/Ichannel Ident",
@@ -1129,19 +1129,19 @@ static BseExportNodeProc __enode_n_ochannels = {
   },
   0, n_ochannels_setup, n_ochannels_exec, 
 };
-static BseExportNodeProc __enode_ochannel_name = {
+static BseExportNodeProc __enode_ochannel_label = {
   { (BseExportNode*) &__enode_n_ochannels, BSE_EXPORT_NODE_PROC,
-    "BseSource+ochannel-name", 
+    "BseSource+ochannel-label", 
     NULL,
-    "/Methods/BseSource/General/Ochannel Name",
+    "/Methods/BseSource/General/Ochannel Label",
     "Get output channel name.",
     "Tim Janik <timj@gtk.org>",
     "GNU Lesser General Public License",
   },
-  0, ochannel_name_setup, ochannel_name_exec, 
+  0, ochannel_label_setup, ochannel_label_exec, 
 };
 static BseExportNodeProc __enode_ochannel_ident = {
-  { (BseExportNode*) &__enode_ochannel_name, BSE_EXPORT_NODE_PROC,
+  { (BseExportNode*) &__enode_ochannel_label, BSE_EXPORT_NODE_PROC,
     "BseSource+ochannel-ident", 
     NULL,
     "/Methods/BseSource/General/Ochannel Ident",
