@@ -49,7 +49,7 @@ static void	 bse_sub_synth_get_property	(GObject                *object,
 						 guint                   param_id,
 						 GValue                 *value,
 						 GParamSpec             *pspec);
-static BseProxySeq* bse_sub_synth_list_proxies	(BseItem		*item,
+static BseItemSeq* bse_sub_synth_list_items	(BseItem		*item,
 						 guint			 param_id,
 						 GParamSpec		*pspec);
 static void	 bse_sub_synth_do_dispose	(GObject		*object);
@@ -118,53 +118,54 @@ bse_sub_synth_class_init (BseSubSynthClass *class)
   gobject_class->get_property = bse_sub_synth_get_property;
   gobject_class->dispose = bse_sub_synth_do_dispose;
   
-  item_class->list_proxies = bse_sub_synth_list_proxies;
+  item_class->list_items = bse_sub_synth_list_items;
   
   source_class->context_create = bse_sub_synth_context_create;
   source_class->context_connect = bse_sub_synth_context_connect;
   source_class->context_dismiss = bse_sub_synth_context_dismiss;
   
-  bse_object_class_add_param (object_class, "Assignments",
+  bse_object_class_add_param (object_class, _("Assignments"),
 			      PARAM_SNET,
-			      bse_param_spec_object ("snet", "Synthesis Network", "The synthesis network to interface to",
+			      bse_param_spec_object ("snet", _("Synthesis Network"),
+                                                     _("The synthesis network to interface to"),
 						     BSE_TYPE_CSYNTH, SFI_PARAM_STANDARD));
   for (i = 0; i < BSE_SUB_SYNTH_N_IOPORTS; i++)
     {
-      gchar *string, *name, *value;
+      gchar *ident, *label, *value;
       
-      string = g_strdup_printf ("in_port_%u", i + 1);
-      name = g_strdup_printf ("Input Port %u", i + 1);
+      ident = g_strdup_printf ("in_port_%u", i + 1);
+      label = g_strdup_printf (_("Input Port %u"), i + 1);
       value = g_strdup_printf ("synth_in_%u", i + 1);
-      bse_object_class_add_param (object_class, "Input Assignments", PARAM_IPORT_NAME + i * 2,
-				  sfi_pspec_string (string, name, "Output port name to interface from",
+      bse_object_class_add_param (object_class, _("Input Assignments"), PARAM_IPORT_NAME + i * 2,
+				  sfi_pspec_string (ident, label, _("Output port name to interface from"),
 						    value, SFI_PARAM_STANDARD ":skip-default"));
-      g_free (string);
-      g_free (name);
+      g_free (ident);
+      g_free (label);
       g_free (value);
       
-      string = g_strdup_printf ("out_port_%u", i + 1);
-      name = g_strdup_printf ("Output Port %u", i + 1);
+      ident = g_strdup_printf ("out_port_%u", i + 1);
+      label = g_strdup_printf (_("Output Port %u"), i + 1);
       value = g_strdup_printf ("synth_out_%u", i + 1);
-      bse_object_class_add_param (object_class, "Output Assignments", PARAM_OPORT_NAME + i * 2,
-				  sfi_pspec_string (string, name, "Input port name to interface to",
+      bse_object_class_add_param (object_class, _("Output Assignments"), PARAM_OPORT_NAME + i * 2,
+				  sfi_pspec_string (ident, label, _("Input port name to interface to"),
 						    value, SFI_PARAM_STANDARD ":skip-default"));
-      g_free (string);
-      g_free (name);
+      g_free (ident);
+      g_free (label);
       g_free (value);
       
-      string = g_strdup_printf ("Input %u", i + 1);
-      name = g_strdup_printf ("Virtual input %u", i + 1);
-      channel_id = bse_source_class_add_ichannel (source_class, string, name);
+      ident = g_strdup_printf ("input-%u", i + 1);
+      label = g_strdup_printf (_("Virtual input %u"), i + 1);
+      channel_id = bse_source_class_add_ichannel (source_class, ident, label, NULL);
       g_assert (channel_id == i);
-      g_free (string);
-      g_free (name);
+      g_free (ident);
+      g_free (label);
       
-      string = g_strdup_printf ("Output %u", i + 1);
-      name = g_strdup_printf ("Virtual output %u", i + 1);
-      channel_id = bse_source_class_add_ochannel (source_class, string, name);
+      ident = g_strdup_printf ("output-%u", i + 1);
+      label = g_strdup_printf (_("Virtual output %u"), i + 1);
+      channel_id = bse_source_class_add_ochannel (source_class, ident, label, NULL);
       g_assert (channel_id == i);
-      g_free (string);
-      g_free (name);
+      g_free (ident);
+      g_free (label);
     }
 }
 
@@ -175,7 +176,7 @@ bse_sub_synth_init (BseSubSynth *synth)
   
   synth->snet = NULL;
   synth->null_shortcut = FALSE;
-
+  
   for (i = 0; i < BSE_SUB_SYNTH_N_IOPORTS; i++)
     {
       synth->input_ports[i] = g_strdup_printf ("synth_in_%u", i + 1);
@@ -206,23 +207,23 @@ bse_sub_synth_do_dispose (GObject *object)
   G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
-static BseProxySeq*
-bse_sub_synth_list_proxies (BseItem    *item,
-			    guint       param_id,
-			    GParamSpec *pspec)
+static BseItemSeq*
+bse_sub_synth_list_items (BseItem    *item,
+                          guint       param_id,
+                          GParamSpec *pspec)
 {
   BseSubSynth *self = BSE_SUB_SYNTH (item);
-  BseProxySeq *pseq = bse_proxy_seq_new ();
+  BseItemSeq *iseq = bse_item_seq_new ();
   switch (param_id)
     {
     case PARAM_SNET:
-      bse_item_gather_proxies_typed (item, pseq, BSE_TYPE_CSYNTH, BSE_TYPE_PROJECT, FALSE);
+      bse_item_gather_items_typed (item, iseq, BSE_TYPE_CSYNTH, BSE_TYPE_PROJECT, FALSE);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (self, param_id, pspec);
       break;
     }
-  return pseq;
+  return iseq;
 }
 
 static gboolean
