@@ -51,7 +51,7 @@ static void     bse_wave_osc_get_property       (GObject                *object,
                                                  guint                   param_id,
                                                  GValue                 *value,
                                                  GParamSpec             *pspec);
-static BseProxySeq* bse_wave_osc_list_proxies   (BseItem                *item,
+static BseItemSeq* bse_wave_osc_list_items      (BseItem                *item,
                                                  guint                   param_id,
                                                  GParamSpec             *pspec);
 static void     bse_wave_osc_context_create     (BseSource              *source,
@@ -120,30 +120,30 @@ bse_wave_osc_class_init (BseWaveOscClass *class)
   gobject_class->finalize = bse_wave_osc_finalize;
   gobject_class->dispose = bse_wave_osc_dispose;
   
-  item_class->list_proxies = bse_wave_osc_list_proxies;
+  item_class->list_items = bse_wave_osc_list_items;
   
   source_class->context_create = bse_wave_osc_context_create;
   
-  bse_object_class_add_param (object_class, "Wave",
+  bse_object_class_add_param (object_class, _("Wave"),
                               PARAM_WAVE,
-                              bse_param_spec_object ("wave", "Wave", "Wave to play",
+                              bse_param_spec_object ("wave", _("Wave"), _("Wave to play"),
                                                      BSE_TYPE_WAVE, SFI_PARAM_STANDARD));
-  bse_object_class_add_param (object_class, "Modulation",
+  bse_object_class_add_param (object_class, _("Modulation"),
                               PARAM_FM_PERC,
-                              sfi_pspec_real ("fm_perc", "Input Modulation [%]",
-                                              "Modulation Strength for linear frequency modulation",
+                              sfi_pspec_real ("fm_perc", _("Input Modulation [%]"),
+                                              _("Modulation Strength for linear frequency modulation"),
                                               10.0, 0, 100.0,5.0,
                                               SFI_PARAM_STANDARD ":scale"));
-  bse_object_class_add_param (object_class, "Modulation",
+  bse_object_class_add_param (object_class, _("Modulation"),
                               PARAM_FM_EXP,
-                              sfi_pspec_bool ("exponential_fm", "Exponential FM",
-                                              "Perform exponential frequency modulation"
-                                              "instead of linear",
+                              sfi_pspec_bool ("exponential_fm", _("Exponential FM"),
+                                              _("Perform exponential frequency modulation"
+                                                "instead of linear"),
                                               FALSE, SFI_PARAM_STANDARD));
-  bse_object_class_add_param (object_class, "Modulation",
+  bse_object_class_add_param (object_class, _("Modulation"),
                               PARAM_FM_OCTAVES,
-                              sfi_pspec_real ("fm_n_octaves", "Octaves",
-                                              "Number of octaves to be affected by exponential frequency modulation",
+                              sfi_pspec_real ("fm_n_octaves", _("Octaves"),
+                                              _("Number of octaves to be affected by exponential frequency modulation"),
                                               1.0, 0, 3.0, 0.01,
                                               SFI_PARAM_STANDARD ":scale"));
   
@@ -152,15 +152,15 @@ bse_wave_osc_class_init (BseWaveOscClass *class)
                                                             SFI_TYPE_NUM,
                                                             G_TYPE_INT);
   
-  ichannel = bse_source_class_add_ichannel (source_class, "Freq In", "Frequency Input");
+  ichannel = bse_source_class_add_ichannel (source_class, "freq-in", _("Freq In"), _("Frequency Input"));
   g_assert (ichannel == BSE_WAVE_OSC_ICHANNEL_FREQ);
-  ichannel = bse_source_class_add_ichannel (source_class, "Sync In", "Syncronization Input");
+  ichannel = bse_source_class_add_ichannel (source_class, "sync-in", _("Sync In"), _("Syncronization Input"));
   g_assert (ichannel == BSE_WAVE_OSC_ICHANNEL_SYNC);
-  ichannel = bse_source_class_add_ichannel (source_class, "Mod In", "Modulation Input");
+  ichannel = bse_source_class_add_ichannel (source_class, "mod-in", _("Mod In"), _("Modulation Input"));
   g_assert (ichannel == BSE_WAVE_OSC_ICHANNEL_MOD);
-  ochannel = bse_source_class_add_ochannel (source_class, "Audio Out", "Wave Output");
+  ochannel = bse_source_class_add_ochannel (source_class, "audio-out", _("Audio Out"), _("Wave Output"));
   g_assert (ochannel == BSE_WAVE_OSC_OCHANNEL_WAVE);
-  ochannel = bse_source_class_add_ochannel (source_class, "Gate Out", "Gate Output");
+  ochannel = bse_source_class_add_ochannel (source_class, "gate-out", _("Gate Out"), _("Gate Output"));
   g_assert (ochannel == BSE_WAVE_OSC_OCHANNEL_GATE);
 }
 
@@ -180,13 +180,13 @@ bse_wave_osc_init (BseWaveOsc *self)
   self->config.cfreq = 440.;
 }
 
-static BseProxySeq*
-bse_wave_osc_list_proxies (BseItem    *item,
-                           guint       param_id,
-                           GParamSpec *pspec)
+static BseItemSeq*
+bse_wave_osc_list_items (BseItem    *item,
+                         guint       param_id,
+                         GParamSpec *pspec)
 {
   BseWaveOsc *self = BSE_WAVE_OSC (item);
-  BseProxySeq *pseq = bse_proxy_seq_new ();
+  BseItemSeq *iseq = bse_item_seq_new ();
   switch (param_id)
     {
       BseProject *project;
@@ -196,14 +196,14 @@ bse_wave_osc_list_proxies (BseItem    *item,
         {
           BseWaveRepo *wrepo = bse_project_get_wave_repo (project);
           
-          bse_item_gather_proxies_typed (BSE_ITEM (wrepo), pseq, BSE_TYPE_WAVE, BSE_TYPE_WAVE_REPO, FALSE);
+          bse_item_gather_items_typed (BSE_ITEM (wrepo), iseq, BSE_TYPE_WAVE, BSE_TYPE_WAVE_REPO, FALSE);
         }
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (self, param_id, pspec);
       break;
     }
-  return pseq;
+  return iseq;
 }
 
 static void
