@@ -19,13 +19,7 @@ request_pcm_position_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPa
  {
 #line 29 "bsewaveosc.proc"
   *(in_pspecs++) = bse_param_spec_object ("wosc", NULL, "Wave Oscilator",
-				 BSE_TYPE_WAVE_OSC, SFI_PARAM_DEFAULT);
-#line 28 "bsewaveosc.proc"
-  proc->help = "Request emission of the ::notify_pcm_position signal.";
-#line 23 "bsewaveosc.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsewaveosc.proc"
-  proc->license = "GNU General Public License";
+				 BSE_TYPE_WAVE_OSC, SFI_PARAM_STANDARD);
 #line 31 "bsewaveosc.proc"
 }  }
 static BseErrorType
@@ -56,16 +50,10 @@ pcm_seek_perc_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 49 "bsewaveosc.proc"
   *(in_pspecs++) = bse_param_spec_object ("wosc", NULL, "Wave Oscilator",
-				 BSE_TYPE_WAVE_OSC, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_WAVE_OSC, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_real ("pos_perc", NULL, NULL,
 			  0, 0, 100, 1,
-			  SFI_PARAM_DEFAULT);
-#line 48 "bsewaveosc.proc"
-  proc->help = "Seek oscillator to a given pcm percentage during playback.";
-#line 23 "bsewaveosc.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsewaveosc.proc"
-  proc->license = "GNU General Public License";
+			  SFI_PARAM_STANDARD);
 #line 54 "bsewaveosc.proc"
 }  }
 static BseErrorType
@@ -97,15 +85,9 @@ set_from_editable_sample_setup (BseProcedureClass *proc, GParamSpec **in_pspecs,
  {
 #line 73 "bsewaveosc.proc"
   *(in_pspecs++) = bse_param_spec_object ("wosc", NULL, "Wave Oscilator",
-				 BSE_TYPE_WAVE_OSC, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_WAVE_OSC, SFI_PARAM_STANDARD);
   *(in_pspecs++) = bse_param_spec_object ("esample", NULL, "Editable Sample",
-				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_DEFAULT);
-#line 72 "bsewaveosc.proc"
-  proc->help = "Set wave to play from editable sample, bypassing undo and storage mechanisms.";
-#line 23 "bsewaveosc.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsewaveosc.proc"
-  proc->license = "GNU General Public License";
+				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_STANDARD);
 #line 77 "bsewaveosc.proc"
 }  }
 static BseErrorType
@@ -133,17 +115,35 @@ set_from_editable_sample_exec (BseProcedureClass *proc,
 /* --- Export to BSE --- */
 static BseExportNodeProc __enode_request_pcm_position = {
   { NULL, BSE_EXPORT_NODE_PROC,
-    "BseWaveOsc+request-pcm-position", "/Methods/BseWaveOsc/General/Request Pcm Position", NULL },
+    "BseWaveOsc+request-pcm-position", 
+    NULL,
+    "/Methods/BseWaveOsc/General/Request Pcm Position",
+    "Request emission of the ::notify_pcm_position signal.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, request_pcm_position_setup, request_pcm_position_exec, 
 };
 static BseExportNodeProc __enode_pcm_seek_perc = {
   { (BseExportNode*) &__enode_request_pcm_position, BSE_EXPORT_NODE_PROC,
-    "BseWaveOsc+pcm-seek-perc", "/Methods/BseWaveOsc/General/Pcm Seek Perc", NULL },
+    "BseWaveOsc+pcm-seek-perc", 
+    NULL,
+    "/Methods/BseWaveOsc/General/Pcm Seek Perc",
+    "Seek oscillator to a given pcm percentage during playback.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, pcm_seek_perc_setup, pcm_seek_perc_exec, 
 };
 static BseExportNodeProc __enode_set_from_editable_sample = {
   { (BseExportNode*) &__enode_pcm_seek_perc, BSE_EXPORT_NODE_PROC,
-    "BseWaveOsc+set-from-editable-sample", "/Methods/BseWaveOsc/General/Set From Editable Sample", NULL },
+    "BseWaveOsc+set-from-editable-sample", 
+    NULL,
+    "/Methods/BseWaveOsc/General/Set From Editable Sample",
+    "Set wave to play from editable sample, bypassing undo and storage mechanisms.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, set_from_editable_sample_setup, set_from_editable_sample_exec, 
 };
 BseExportNode* bse__builtin_init_bsewaveosc_gen_proc_c (void);
