@@ -1,5 +1,5 @@
 /* BSE - Bedevilled Sound Engine
- * Copyright (C) 2001, 2002 Tim Janik
+ * Copyright (C) 2001-2003 Tim Janik
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,14 +22,10 @@
 #include <bse/bsewave.h>
 #include <bse/gslwaveosc.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
-
+G_BEGIN_DECLS
 
 /* --- object type macros --- */
-#define BSE_TYPE_WAVE_OSC	       (BSE_TYPE_ID (BseWaveOsc))
+#define BSE_TYPE_WAVE_OSC              (BSE_TYPE_ID (BseWaveOsc))
 #define BSE_WAVE_OSC(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), BSE_TYPE_WAVE_OSC, BseWaveOsc))
 #define BSE_WAVE_OSC_CLASS(class)      (G_TYPE_CHECK_CLASS_CAST ((class), BSE_TYPE_WAVE_OSC, BseWaveOscClass))
 #define BSE_IS_WAVE_OSC(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), BSE_TYPE_WAVE_OSC))
@@ -42,14 +38,13 @@ typedef struct _BseWaveOsc      BseWaveOsc;
 typedef struct _BseWaveOscClass BseWaveOscClass;
 struct _BseWaveOsc
 {
-  BseSource        parent_object;
+  BseSource          parent_object;
   
-  BseWave	  *wave;
-  GslWaveOscConfig config;
-  gfloat	   fm_strength;
-  gfloat	   n_octaves;
-  
-  GslWaveChunk	  *esample_wchunk;
+  BseWave           *wave;
+  GslWaveChunk      *esample_wchunk;
+  GslWaveOscConfig   config;
+  gfloat             fm_strength;
+  gfloat             n_octaves;
 };
 struct _BseWaveOscClass
 {
@@ -58,8 +53,10 @@ struct _BseWaveOscClass
 
 
 /* --- prototypes --- */
-void	bse_wave_osc_request_pcm_position	(BseWaveOsc	*self,
-						 gfloat		 perc);
+void    bse_wave_osc_request_pcm_position       (BseWaveOsc        *self,
+                                                 gfloat             perc);
+void    bse_wave_osc_set_from_esample           (BseWaveOsc        *self,
+                                                 BseEditableSample *esample);
 
 
 /* --- channels --- */
@@ -77,9 +74,6 @@ enum
   BSE_WAVE_OSC_N_OCHANNELS
 };
 
-
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* __BSE_WAVE_OSC_H__ */
