@@ -1,5 +1,5 @@
 /* GSL - Generic Sound Layer
- * Copyright (C) 2001-2002 Tim Janik and Stefan Westerfeld
+ * Copyright (C) 2001-2003 Tim Janik and Stefan Westerfeld
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -52,6 +52,7 @@ typedef struct
   GslDataHandle dhandle;
 
   /* setup data */
+  gfloat        osc_freq;
   guint		sample_rate;
   guint		frame_size;
   guint         stream_options;
@@ -346,21 +347,28 @@ dh_mad_open (GslDataHandle      *dhandle,
     }
 
   /* get n_channels, frame size and sample rate */
-  setup->bit_depth = 24;
   setup->n_channels = MAD_NCHANNELS (&handle->frame.header);
   n = MAD_NSBSAMPLES (&handle->frame.header) * 32;
   seek_invalidated |= n != handle->frame_size;
   handle->frame_size = n;
   handle->sample_rate = handle->frame.header.samplerate;
+  setup->bit_depth = 24;
+  setup->mix_freq = handle->sample_rate;
+  setup->osc_freq = handle->osc_freq;
   if (setup->n_channels < 1 ||
       setup->n_channels > MAX_CHANNELS ||
+      setup->mix_freq < 3999 ||
+      setup->osc_freq <= 0 ||
       handle->frame_size < 1 ||
       handle->sample_rate < 1)
     {
       error = GSL_ERROR_FORMAT_INVALID;
       goto OPEN_FAILED;
     }
-  
+
+  /* our code already uses dhandle->setup */
+  dhandle->setup = *setup;
+
   /* seek through the stream to collect frame positions */
   if (seek_invalidated || !handle->n_seeks)
     {
@@ -397,12 +405,15 @@ dh_mad_open (GslDataHandle      *dhandle,
       goto OPEN_FAILED;
     }
 
+  /* our code already uses dhandle->setup */
+  dhandle->setup = *setup;
+
   if (dh_mad_coarse_seek (&handle->dhandle, 0) != 0)
     {
       error = GSL_ERROR_SEEK_FAILED;
       goto OPEN_FAILED;
     }
-
+  
   return GSL_ERROR_NONE;
 
  OPEN_FAILED:
@@ -643,6 +654,7 @@ static GslDataHandleFuncs dh_mad_vtable = {
 
 static GslDataHandle*
 dh_mad_new (const gchar *file_name,
+            gfloat       osc_freq,
 	    gboolean     skip_seek_keep_open)
 {
   MadHandle *handle;
@@ -655,6 +667,7 @@ dh_mad_new (const gchar *file_name,
       GslErrorType error;
 
       handle->dhandle.vtable = &dh_mad_vtable;
+      handle->osc_freq = osc_freq;
       handle->sample_rate = 0;
       handle->frame_size = 0;
       handle->stream_options = MAD_OPTION_IGNORECRC;
@@ -691,11 +704,13 @@ dh_mad_new (const gchar *file_name,
 }
 
 GslDataHandle*
-gsl_data_handle_new_mad (const gchar *file_name)
+gsl_data_handle_new_mad (const gchar *file_name,
+                         gfloat       osc_freq)
 {
   g_return_val_if_fail (file_name != NULL, NULL);
+  g_return_val_if_fail (osc_freq > 0, NULL);
 
-  return dh_mad_new (file_name, FALSE);
+  return dh_mad_new (file_name, osc_freq, FALSE);
 }
 
 GslErrorType
@@ -708,7 +723,7 @@ gsl_data_handle_mad_testopen (const gchar *file_name,
   
   g_return_val_if_fail (file_name != NULL, GSL_ERROR_INTERNAL);
 
-  dhandle = dh_mad_new (file_name, TRUE);
+  dhandle = dh_mad_new (file_name, 439, TRUE);
   if (!dhandle)
     return GSL_ERROR_OPEN_FAILED;
 
@@ -723,22 +738,35 @@ gsl_data_handle_mad_testopen (const gchar *file_name,
   return GSL_ERROR_NONE;
 }
 
+const gchar*
+gsl_data_handle_mad_version (void)
+{
+  return MAD_VERSION;
+}
+
 #else	/* !GSL_HAVE_LIBMAD */
 
 GslDataHandle*
-gsl_data_handle_new_mad (const gchar *file_name)
+gsl_data_handle_new_mad (const gchar *file_name,
+                         gfloat       osc_freq)
 {
   return NULL;
 }
 
 GslErrorType
 gsl_data_handle_mad_testopen (const gchar *file_name,
-			      guint       *n_channels,
-			      gfloat      *mix_freq)
+                              guint       *n_channels,
+                              gfloat      *mix_freq)
 {
   return GSL_ERROR_FORMAT_UNKNOWN;
 }
 
+const gchar*
+gsl_data_handle_mad_version (void)
+{
+  return NULL;
+}
+
 #endif	/* !GSL_HAVE_LIBMAD */
 
 /* vim:set ts=8 sts=2 sw=2: */
