@@ -60,12 +60,12 @@ public:
   }
 
   /* produces an escaped version "foo" or _("foo") */
-  std::string escaped () const
+  std::string escaped (const std::string &i18n_prefix = "_") const
   {
     std::string result;
     char *x = g_strescape (c_str(), 0);
     if (i18n)
-      result = "_(\"" + std::string(x) + "\")";
+      result = i18n_prefix + "(\"" + std::string(x) + "\")";
     else
       result = "\"" + std::string(x) + "\"";
     g_free (x);
@@ -77,6 +77,16 @@ struct LineInfo {
   bool isInclude;
   int line;
   std::string filename;
+
+  // Produce a human readable location (file:line, using "stdin" where appropriate) 
+  std::string location() const
+  {
+    std::string result;
+    char *x = g_strdup_printf ("%s:%d", (filename == "-") ? "stdin" : filename.c_str(), line);
+    result = x;
+    g_free (x);
+    return result;
+  }
 };
 
 struct Constant {
@@ -86,7 +96,7 @@ struct Constant {
 
   std::string str;
   float f;
-  int i;
+  gint64 i;
 };
 
 struct Param {
@@ -103,16 +113,17 @@ struct Param {
 struct Stream {
   enum Type { IStream, JStream, OStream } type;
   std::string ident;
-  IString     name;
-  std::string file;
+  IString     label;
   IString     blurb;
+  std::string file;
   int         line;
 };
  
 struct ChoiceValue {
   std::string name;
   std::string file;
-  std::string text;
+  IString     label;
+  IString     blurb;
   
   int         value;
   int         sequentialValue;
