@@ -83,6 +83,8 @@ SfiSeq*	 sfi_seq_copy_deep	(const SfiSeq	 *seq);
 #define	 sfi_seq_copy_shallow	sfi_seq_ref
 void	 sfi_seq_append		(SfiSeq		 *seq,
 				 const GValue	 *value);
+GValue*	 sfi_seq_append_empty	(SfiSeq		 *seq,
+				 GType            value_type);
 void	 sfi_seq_clear		(SfiSeq		 *seq);
 guint	 sfi_seq_length		(const SfiSeq	 *seq);
 GValue*	 sfi_seq_get		(const SfiSeq	 *seq,
@@ -141,6 +143,7 @@ SfiProxy     sfi_seq_get_proxy	(SfiSeq		*seq,
 /* conversion convenience */
 gchar**	     sfi_seq_to_strv	(SfiSeq		*seq);
 SfiSeq*	     sfi_seq_from_strv	(gchar	       **strv);
+SfiSeq*	     sfi_seq_from_cstrv	(const gchar   **strv);
 
 
 /* --- SfiRec primitive type --- */
@@ -166,6 +169,9 @@ void       sfi_rec_set          (SfiRec          *rec,
 				 const GValue    *value);
 GValue*    sfi_rec_get          (SfiRec          *rec,
 				 const gchar     *field_name);
+GValue*    sfi_rec_forced_get   (SfiRec          *rec,
+                                 const gchar     *field_name,
+                                 GType            gtype);
 guint      sfi_rec_n_fields     (const SfiRec    *rec);
 GValue*    sfi_rec_field        (const SfiRec    *rec,
 				 guint            index);
@@ -250,6 +256,8 @@ SfiRing*        sfi_ring_prepend_uniq   (SfiRing        *head,
 					 gpointer        data);
 SfiRing*        sfi_ring_append         (SfiRing        *head,
 					 gpointer        data);
+SfiRing*        sfi_ring_append_uniq    (SfiRing        *head,
+					 gpointer        data);
 SfiRing*        sfi_ring_insert_sorted  (SfiRing        *head,
 					 gpointer        data,
 					 GCompareFunc    func);
@@ -258,6 +266,8 @@ SfiRing*        sfi_ring_remove_node    (SfiRing        *head,
 SfiRing*        sfi_ring_remove         (SfiRing        *head,
 					 gpointer        data);
 guint           sfi_ring_length         (SfiRing        *head);
+gboolean        sfi_ring_test_length    (SfiRing        *head,
+					 guint           test_length);
 SfiRing*        sfi_ring_copy           (SfiRing        *head);
 SfiRing*        sfi_ring_copy_deep      (SfiRing        *head,
 					 SfiRingDataFunc copy,
@@ -282,13 +292,12 @@ gpointer        sfi_ring_pop_head       (SfiRing       **head);
 gpointer        sfi_ring_pop_tail       (SfiRing       **head);
 #define         sfi_ring_push_head      sfi_ring_prepend
 #define         sfi_ring_push_tail      sfi_ring_append
-void            sfi_ring_free_deep      (SfiRing        *head,
-					 SfiRingDataFunc free_func,
-					 gpointer        func_data);
 void            sfi_ring_free           (SfiRing        *head);
+void            sfi_ring_free_deep      (SfiRing        *head,
+					 GDestroyNotify  data_destroy);
 #define sfi_ring_tail(head)             ((head) ? (head)->prev : NULL)
 #define sfi_ring_walk(node,head_bound)  ((node)->next != (head_bound) ? (node)->next : NULL)
-
+#define sfi_ring_next                   sfi_ring_walk
 
 G_END_DECLS
 
