@@ -8,7 +8,7 @@
 
 /* enum prototypes */
 namespace Namespace {
-#define NAMESPACE_TYPE_FUNKYNESS_TYPE (BSE_CXX_DECLARED_ENUM_TYPE (FunkynessType))
+#define NAMESPACE_TYPE_FUNKYNESS_TYPE		BSE_CXX_DECLARED_ENUM_TYPE (Namespace, FunkynessType)
 
 
 /* choice prototypes */
@@ -18,29 +18,47 @@ static inline SfiChoiceValues FunkynessType_choice_values();
 /* record prototypes */
 class TestRecord;
 typedef Sfi::RecordHandle<TestRecord> TestRecordHandle;
-#define NAMESPACE_TYPE_TEST_RECORD BSE_CXX_DECLARED_RECORD_TYPE (TestRecord)
+#define NAMESPACE_TYPE_TEST_RECORD		BSE_CXX_DECLARED_RECORD_TYPE (Namespace, TestRecord)
 
 
 /* sequence prototypes */
 class TestSequence;
-#define NAMESPACE_TYPE_TEST_SEQUENCE BSE_CXX_DECLARED_SEQUENCE_TYPE (TestSequence)
+#define NAMESPACE_TYPE_TEST_SEQUENCE		BSE_CXX_DECLARED_SEQUENCE_TYPE (Namespace, TestSequence)
 
 
 /* class prototypes */
 class TestObjectBase;
 class TestObject;
-#define NAMESPACE_TYPE_TEST_OBJECT  (BSE_CXX_DECLARED_CLASS_TYPE (TestObject))
+#define NAMESPACE_TYPE_TEST_OBJECT		BSE_CXX_DECLARED_CLASS_TYPE (Namespace, TestObject)
 #define NAMESPACE_IS_TEST_OBJECT(o) (::Bse::CxxBase::instance_is_a (o, NAMESPACE_TYPE_TEST_OBJECT))
 
 
 /* enum definitions */
 enum FunkynessType {
-  REALLY_FUNKY = 1,
-  MODERATELY_FUNKY = 2,
-  NON_FUNKY = 3,
+  REALLY_FUNKY = 0,
+  MODERATELY_FUNKY = 1,
+  NON_FUNKY = 42,
 };
 
 
+/* sequence definitions */
+class TestSequence : public Sfi::Sequence< ::Namespace::TestRecordHandle > {
+public:
+  TestSequence (unsigned int n = 0) : Sfi::Sequence< ::Namespace::TestRecordHandle > (n) {}
+  static inline ::Namespace::TestSequence from_seq (SfiSeq *seq);
+  static inline SfiSeq *to_seq (const ::Namespace::TestSequence & seq);
+  static inline ::Namespace::TestSequence value_get_boxed (const GValue *value);
+  static inline void value_set_boxed (GValue *value, const ::Namespace::TestSequence & self);
+  static inline const char* options   () { return ""; }
+  static inline const char* blurb     () { return ""; }
+  static inline const char* authors   () { return ""; }
+  static inline const char* license   () { return ""; }
+  static inline const char* type_name () { return "NamespaceTestSequence"; }
+  static inline GParamSpec* get_element ();
+};
+
+
+
 /* record definitions */
 class TestRecord : public ::Sfi::GNewable {
 public:
@@ -61,23 +79,6 @@ public:
 
 
 
-/* sequence definitions */
-class TestSequence : public Sfi::Sequence< ::Namespace::TestRecordHandle > {
-public:
-  static inline ::Namespace::TestSequence from_seq (SfiSeq *seq);
-  static inline SfiSeq *to_seq (const ::Namespace::TestSequence & seq);
-  static inline ::Namespace::TestSequence value_get_boxed (const GValue *value);
-  static inline void value_set_boxed (GValue *value, const ::Namespace::TestSequence & self);
-  static inline const char* options   () { return ""; }
-  static inline const char* blurb     () { return ""; }
-  static inline const char* authors   () { return ""; }
-  static inline const char* license   () { return ""; }
-  static inline const char* type_name () { return "NamespaceTestSequence"; }
-  static inline GParamSpec* get_element ();
-};
-
-
-
 /* class definitions */
 BSE_CXX_DECLARE_CLASS (TestObject);
 class TestObjectBase : public ::Bse::Effect {
@@ -189,41 +190,58 @@ public:
 };
 
 
+/* sequence type declarations */
+BSE_CXX_DECLARE_SEQUENCE (TestSequence);
+
+
+
+/* record type declarations */
+BSE_CXX_DECLARE_RECORD (TestRecord);
+
+
+
 /* procedure prototypes */
 namespace Procedure {
 class test_exception;
-#define NAMESPACE_TYPE_TEST_EXCEPTION (BSE_CXX_DECLARED_PROC_TYPE (test_exception))
+#define NAMESPACE_TYPE_TEST_EXCEPTION		BSE_CXX_DECLARED_PROC_TYPE (Namespace, test_exception)
 } // Procedure
 
 
 
 /* enum implementations */
 BSE_CXX_DECLARE_ENUM (FunkynessType, "NamespaceFunkynessType", 3,
-                      *v++ = ::Bse::EnumValue (1, "NAMESPACE_REALLY_FUNKY", "" );
-                      *v++ = ::Bse::EnumValue (2, "NAMESPACE_MODERATELY_FUNKY", "" );
-                      *v++ = ::Bse::EnumValue (3, "NAMESPACE_NON_FUNKY", "No Funk At All" );
-                      );
+  *v++ = ::Bse::EnumValue (REALLY_FUNKY, "NAMESPACE_REALLY_FUNKY", "namespace-really-funky" );
+  *v++ = ::Bse::EnumValue (MODERATELY_FUNKY, "NAMESPACE_MODERATELY_FUNKY", "namespace-moderately-funky" );
+  *v++ = ::Bse::EnumValue (NON_FUNKY, "NAMESPACE_NON_FUNKY", "No Funk At All" );
+);
 
 
 /* choice implementations */
 static inline SfiChoiceValues
 FunkynessType_choice_values()
 {
-  static const SfiChoiceValue values[3] = {
-    { "NAMESPACE_REALLY_FUNKY", "" },
-    { "NAMESPACE_MODERATELY_FUNKY", "" },
-    { "NAMESPACE_NON_FUNKY", "No Funk At All" },
-  };
+  static SfiChoiceValue values[3];
   static const SfiChoiceValues choice_values = {
-    sizeof (values), values,
+    G_N_ELEMENTS (values), values,
   };
+  if (!values[0].choice_ident)
+    {
+      values[0].choice_ident = "NAMESPACE_REALLY_FUNKY";
+      values[0].choice_label = "namespace-really-funky";
+      values[0].choice_blurb = "";
+      values[1].choice_ident = "NAMESPACE_MODERATELY_FUNKY";
+      values[1].choice_label = "namespace-moderately-funky";
+      values[1].choice_blurb = "";
+      values[2].choice_ident = "NAMESPACE_NON_FUNKY";
+      values[2].choice_label = "No Funk At All";
+      values[2].choice_blurb = "";
+  }
   return choice_values;
 }
 
 
 
 /* record implementations */
-BSE_CXX_DECLARE_RECORD (TestRecord);
 ::Namespace::TestRecordHandle
 TestRecord::from_rec (SfiRec *sfi_rec)
 {
@@ -259,7 +277,7 @@ TestRecord::to_rec (const ::Namespace::TestRecordHandle & rec)
   sfi_value_set_int (element, rec->i);
   element = sfi_rec_forced_get (sfi_rec, "str", SFI_TYPE_STRING);
   ::Sfi::String::value_set_string (element, rec->str);
-  element = sfi_rec_forced_get (sfi_rec, "funky", NAMESPACE_TYPE_FUNKYNESS_TYPE);
+  element = sfi_rec_forced_get (sfi_rec, "funky", SFI_TYPE_CHOICE);
   sfi_value_set_enum_auto SFI_START_ARGS() NAMESPACE_TYPE_FUNKYNESS_TYPE, SFI_END_ARGS2 (element, rec->funky);
   return sfi_rec;
 }
@@ -294,35 +312,34 @@ TestRecord::get_fields()
 
 
 /* sequence implementations */
-BSE_CXX_DECLARE_SEQUENCE (TestSequence);
 ::Namespace::TestSequence
 TestSequence::from_seq (SfiSeq *sfi_seq)
 {
-  ::Namespace::TestSequence seq;
+  ::Namespace::TestSequence cseq;
   guint i, length;
 
   if (!sfi_seq)
-    return seq;
+    return cseq;
 
   length = sfi_seq_length (sfi_seq);
-  seq.resize (length);
+  cseq.resize (length);
   for (i = 0; i < length; i++)
     {
       GValue *element = sfi_seq_get (sfi_seq, i);
-      seq[i] = ::Namespace::TestRecord::value_get_boxed (element);
+      cseq[i] = ::Namespace::TestRecord::value_get_boxed (element);
     }
-  return seq;
+  return cseq;
 }
 
 SfiSeq *
-TestSequence::to_seq (const ::Namespace::TestSequence & seq)
+TestSequence::to_seq (const ::Namespace::TestSequence & cseq)
 {
   SfiSeq *sfi_seq = sfi_seq_new ();
-  for (guint i = 0; i < seq.length(); i++)
-  {
-    GValue *element = sfi_seq_append_empty (sfi_seq, NAMESPACE_TYPE_TEST_RECORD);
-    ::Namespace::TestRecord::value_set_boxed (element, seq[i]);
-  }
+  for (guint i = 0; i < cseq.length(); i++)
+    {
+      GValue *element = sfi_seq_append_empty (sfi_seq, SFI_TYPE_REC);
+      ::Namespace::TestRecord::value_set_boxed (element, cseq[i]);
+    }
   return sfi_seq;
 }
 
@@ -416,6 +433,9 @@ public:
 };
 } // Procedure
 
+
+
+/*  type registrations */
 } // Namespace
 
 /*-------- end ../sfi/sfidl generated code --------*/
